--RaidR Main File

local flasks = {}
flasks["Flask of the Whispered Pact"] = 127847
flasks["Flask of the Seventh Demon"] = 127848
flasks["Flask of the Countless Armies"] = 127849
flasks["Flask of Ten Thousand Scars"] = 127850

local potions = {}
potions["Ancient Healing Potion"] = 127834
potions["Ancient Mana Potion"] = 127835
potions["Ancient Rejuvenation Potion"] = 127836
potions["Potion of Deadly Grace"] = 127843
potions["Potion of the Old War"] = 127844
potions["Unbending Potion"] = 127845
potions["Leytorrent Potion"] = 127846
potions["Potion of Prolonged Power"] = 142117
potions["Astral Healing Potion"] = 152615

local food = {}
food["The Hungry Magister"] = 133570
food["Azshari Salad"] = 133571
food["Nightborne Delicacy Platter"] = 133572
food["Seed-Battered Fish Plate"] = 133573
food["Fishbrul Special"] = 133574

local misc = {}
misc["Spirit Cauldron"] = 127851
misc["Lavish Suramar Feast"] = 133579
misc["Defiled Augment Rune"] = 140587

local frames = {}
local scrollFrames = {}
local buttons = {}
local dropdowns = {}
local fontStrings = {}
local editBoxes = {}
local checkButtons = {}

local flaskFrameName
local flaskCountStringName
local flaskItemIconName
local flaskNameStringName

local potionFrameName
local potionCountStringName
local potionItemIconName
local potionNameStringName

local foodFrameName
local foodCountStringName
local foodItemIconName
local foodNameStringName

local miscFrameName
local miscCountStringName
local miscItemIconName
local miscNameStringName



--main frame for initial config
frames.RaidRConfig = CreateFrame("Frame", "RaidRConfigFrame", UIParent)
frames.RaidRConfig:Hide()

--main frame for reminders config
frames.RaidRReminder = CreateFrame("Frame", "RaidRReminderFrame", UIParent)
frames.RaidRReminder:Hide()

local configCreated = false

--Returns the day of the week
local function GetDay()
	local daysoftheweek={"Sunday","Monday","Tuesday","Wednesday","Thrusday","Friday","Saturday"}
	local day=daysoftheweek[date("*t").wday]
	return day
end

--Used for determining if today is a raid day
local today = GetDay()

--Calculates a difference in time
local function TimeDiff(hour, minute, ampm, diff)
	local flip = false
	if(diff == 60) then
		if(hour == 12) then
			flip = true
		end
		hour = hour - 1
	elseif((minute - diff) < 0) then
		if(hour == 12) then
			flip = true
		end
		hour = hour - 1
		minute = 60 + (minute - diff)
	else
		minute = minute - diff
	end
	if(flip) then
		if(ampm == "AM") then
			ampm = "PM"
		else
			ampm = "AM"
		end
	end
	if(hour == 0) then
		hour = 12
	end
	if(hour == -1) then
		hour = 11
	end
	local diffTable = {}
	diffTable["Hour"] = hour
	diffTable["Minute"] = minute
	diffTable["AMPM"] = ampm
	return diffTable
end

--Returns the number of Seals of Broken Fate the character has purchased this week
local function GetSealsCount()
	local count = 0
	for i,q in ipairs({43510,43892,43893,43894,43895,43896,43897,47864,47851,47865}) do
		if(IsQuestFlaggedCompleted(q)) then
			count = count + 1
		end
	end
	return count
end

--Runs the config window
local function RunInitialConfig()
	if(frames.RaidRReminder:IsVisible() == false and configCreated == false) then
		--Setup config frame
		frames.RaidRConfig:SetBackdrop({
			bgFile="Interface\\DialogFrame\\UI-DialogBox-Background", 
			edgeFile="Interface\\DialogFrame\\UI-DialogBox-Border", 
			tile=1, tileSize=32, edgeSize=32, 
			insets={left=11, right=12, top=12, bottom=11}
		})
		frames.RaidRConfig:SetSize(350, 400)
		frames.RaidRConfig:SetPoint("CENTER", 500, 0)
		frames.RaidRConfig:EnableMouse(true)
		frames.RaidRConfig:SetMovable(true)
		frames.RaidRConfig:RegisterForDrag("LeftButton")
		frames.RaidRConfig:SetScript("OnDragStart", function(self) self:StartMoving() end)
		frames.RaidRConfig:SetScript("OnDragStop", function(self) self:StopMovingOrSizing() end)
		frames.RaidRConfig:Show()

		--Greeting Frame
		frames.greetingFrame = CreateFrame("Frame", "GreetingFrame", frames.RaidRConfig)
		frames.greetingFrame:SetSize(350,400)
		frames.greetingFrame:SetPoint("TOPLEFT")

		--Greeting Frame: String for Initial Window
		fontStrings.greetingString = frames.greetingFrame:CreateFontString("Greeting")
		fontStrings.greetingString:SetFont("Fonts\\FRIZQT__.ttf", 24, "OUTLINE")
		fontStrings.greetingString:SetText("Welcome to RaidR!\n\nLet's get started.")
		fontStrings.greetingString:SetJustifyH("CENTER")
		fontStrings.greetingString:SetPoint("CENTER", 0, 130)

		--Greeting Frame: Next Button
		buttons.greetingFrameNextButton = CreateFrame("Button", "GreetingFrameNextButton", frames.greetingFrame, "UIPanelButtonTemplate")
		buttons.greetingFrameNextButton:SetSize(100,30)
		buttons.greetingFrameNextButton:SetPoint("CENTER")
		buttons.greetingFrameNextButton:SetText("Okay!")

		--Greeting Frame: Skip Button
		buttons.greetingFrameSkipButton = CreateFrame("Button", "GreetingFrameSkipButton", frames.greetingFrame, "UIPanelButtonTemplate")
		buttons.greetingFrameSkipButton:SetSize(100,30)
		buttons.greetingFrameSkipButton:SetPoint("CENTER", 0, -40)
		buttons.greetingFrameSkipButton:SetText("Skip for now")
		buttons.greetingFrameSkipButton:SetScript("OnEnter", function(self)
			GameTooltip:SetOwner(self, "ANCHOR_CURSOR");
			GameTooltip:ClearLines()
			GameTooltip:SetText("You can re-run this initial setup at any time with the chat command '/raidr config'")
			GameTooltip:Show()
		end)
		buttons.greetingFrameSkipButton:SetScript("OnLeave", function(self)
			GameTooltip:Hide()
		end)

		local fromTop = 10

		--Flask Frame
		frames.flaskFrame = CreateFrame("Frame", "FlaskFrame", frames.RaidRConfig)
		frames.flaskFrame:SetSize(350,400)
		frames.flaskFrame:SetPoint("TOPLEFT")
		frames.flaskFrame:Hide()

		--Flask Frame: String for instructions
		fontStrings.flaskString = frames.flaskFrame:CreateFontString("FlaskInstructions")
		fontStrings.flaskString:SetFont("Fonts\\FRIZQT__.ttf", 17, "OUTLINE")
		fontStrings.flaskString:SetText("Enter the number of each flask\nyou expect to use during raid")
		fontStrings.flaskString:SetJustifyH("CENTER")
		fontStrings.flaskString:SetPoint("CENTER", 0, 150)

		--Flask Frame: Frame for making a border
		frames.flaskBorderFrame = CreateFrame("Frame", "FlaskBorderFrame", frames.flaskFrame)
		frames.flaskBorderFrame:SetBackdrop({
			bgFile="Interface\\DialogFrame\\UI-DialogBox-Background", 
			edgeFile="Interface\\DialogFrame\\UI-DialogBox-Border", 
			tile=1, tileSize=32, edgeSize=32, 
			insets={left=11, right=12, top=12, bottom=11}
		})
		frames.flaskBorderFrame:SetPoint("TOPLEFT", 20, -80)
		frames.flaskBorderFrame:SetPoint("BOTTOMRIGHT", -40, 60)

		--Flask Frame: ScrollFrame for flask list
		scrollFrames.flaskScrollFrame = CreateFrame("ScrollFrame", "FlaskScrollFrame", frames.flaskBorderFrame, "UIPanelScrollFrameTemplate")
		scrollFrames.flaskScrollFrame:SetPoint("TOPLEFT", 0, -10)
		scrollFrames.flaskScrollFrame:SetPoint("BOTTOMRIGHT", 0, 10)

		--Flask Frame: Content container for flask ScrollFrame
		frames.flaskScrollContent = CreateFrame("Frame", "FlaskScrollContent", scrollFrames.flaskScrollFrame)
		frames.flaskScrollContent:SetSize(290, 230)
		
		--Flask Display
		for key, value in pairs(flasks) do
			if(value ~= 0 and value ~= nil) then
				--Entry Frame
				flaskFrameName = "conFrame" .. flasks[key]
				frames[flaskFrameName] = CreateFrame("Frame", flaskFrameName, frames.flaskScrollContent)
				frames[flaskFrameName]:SetSize(290, 75)
				frames[flaskFrameName]:SetPoint("TOPLEFT", 0, fromTop)
				--Entry EditBox
				flaskEditBoxName = "conEditBoxes" .. flasks[key]
				editBoxes[flaskEditBoxName] = CreateFrame("EditBox", flaskEditBoxName, frames[flaskFrameName], "InputBoxTemplate")
				editBoxes[flaskEditBoxName]:SetAutoFocus(false)
				editBoxes[flaskEditBoxName]:SetSize(25,30)
				editBoxes[flaskEditBoxName]:SetPoint("CENTER", -110, 0)
				editBoxes[flaskEditBoxName]:SetNumeric(true)
				editBoxes[flaskEditBoxName]:SetMaxLetters(3)
				editBoxes[flaskEditBoxName]:SetText("0")
				editBoxes[flaskEditBoxName]:SetJustifyH("LEFT")
				editBoxes[flaskEditBoxName]:SetScript("OnEnterPressed",function(s)
					s:ClearFocus()
				end)
				editBoxes[flaskEditBoxName]:SetScript("OnEditFocusLost",function(s)
					if(s:GetText() == "") then
						s:SetNumber(0)
					end
				end)
				--Entry Item Icon
				flaskItemIconName = "conItemIcon" .. flasks[key]
				buttons[flaskFrameName] = CreateFrame("Button", flaskItemIconName, frames[flaskFrameName])
				buttons[flaskFrameName]:SetSize(40,40)
				buttons[flaskFrameName]:SetPoint("CENTER", -70, 0)
				buttons[flaskFrameName]:SetNormalTexture(GetItemIcon(flasks[key]))
				buttons[flaskFrameName]:SetScript("OnEnter", function(self)
					GameTooltip:SetOwner(self, "ANCHOR_CURSOR");
					GameTooltip:ClearLines()
					GameTooltip:SetItemByID(flasks[key])
					GameTooltip:Show()
				end)
				buttons[flaskFrameName]:SetScript("OnLeave", function(self)
					GameTooltip:Hide()
				end)
				--Entry Name
				flaskNameStringName = "conNameString" .. flasks[key]
				fontStrings[flaskFrameName] = frames[flaskFrameName]:CreateFontString(flaskNameStringName)
				fontStrings[flaskFrameName]:SetFont("Fonts\\FRIZQT__.ttf", 10)
				fontStrings[flaskFrameName]:SetText(key)
				fontStrings[flaskFrameName]:SetJustifyH("LEFT")
				fontStrings[flaskFrameName]:SetPoint("CENTER", 30, 0)
				
				fromTop = fromTop - 55
			end
		end

		scrollFrames.flaskScrollFrame:SetScrollChild(frames.flaskScrollContent)

		--Flask Frame: Previous Button
		buttons.flaskFramePreviousButton = CreateFrame("Button", "FlaskFramePreviousButton", frames.flaskFrame, "UIPanelButtonTemplate")
		buttons.flaskFramePreviousButton:SetSize(100,30)
		buttons.flaskFramePreviousButton:SetPoint("CENTER", -100, -165)
		buttons.flaskFramePreviousButton:SetText("Previous")

		--Flask Frame: Next Button
		buttons.flaskFrameNextButton = CreateFrame("Button", "FlaskFrameNextButton", frames.flaskFrame, "UIPanelButtonTemplate")
		buttons.flaskFrameNextButton:SetSize(100,30)
		buttons.flaskFrameNextButton:SetPoint("CENTER", 100, -165)
		buttons.flaskFrameNextButton:SetText("Next")



		fromTop = 10
		
		--Potion Frame
		frames.potionFrame = CreateFrame("Frame", "PotionFrame", frames.RaidRConfig)
		frames.potionFrame:SetSize(350,400)
		frames.potionFrame:SetPoint("TOPLEFT")
		frames.potionFrame:Hide()

		--Potion Frame: String for instructions
		fontStrings.potionString = frames.potionFrame:CreateFontString("PotionInstructions")
		fontStrings.potionString:SetFont("Fonts\\FRIZQT__.ttf", 17, "OUTLINE")
		fontStrings.potionString:SetText("Enter the number of each potion\nyou expect to use during raid")
		fontStrings.potionString:SetJustifyH("CENTER")
		fontStrings.potionString:SetPoint("CENTER", 0, 150)

		--Potion Frame: Frame for making a border
		frames.potionBorderFrame = CreateFrame("Frame", "PotionBorderFrame", frames.potionFrame)
		frames.potionBorderFrame:SetBackdrop({
			bgFile="Interface\\DialogFrame\\UI-DialogBox-Background", 
			edgeFile="Interface\\DialogFrame\\UI-DialogBox-Border", 
			tile=1, tileSize=32, edgeSize=32, 
			insets={left=11, right=12, top=12, bottom=11}
		})
		frames.potionBorderFrame:SetPoint("TOPLEFT", 20, -80)
		frames.potionBorderFrame:SetPoint("BOTTOMRIGHT", -40, 60)

		--Potion Frame: ScrollFrame for potion list
		scrollFrames.potionScrollFrame = CreateFrame("ScrollFrame", "PotionScrollFrame", frames.potionBorderFrame, "UIPanelScrollFrameTemplate")
		scrollFrames.potionScrollFrame:SetPoint("TOPLEFT", 0, -10)
		scrollFrames.potionScrollFrame:SetPoint("BOTTOMRIGHT", 0, 10)

		--Potion Frame: Content container for potion ScrollFrame
		frames.potionScrollContent = CreateFrame("Frame", "PotionScrollContent", scrollFrames.potionScrollFrame)
		frames.potionScrollContent:SetSize(290, 450)

		--Potion Display
		for key, value in pairs(potions) do
			if(value ~= 0 and value ~= nil) then
				--Entry Frame
				potionFrameName = "conFrame" .. potions[key]
				frames[potionFrameName] = CreateFrame("Frame", potionFrameName, frames.potionScrollContent)
				frames[potionFrameName]:SetSize(290, 75)
				frames[potionFrameName]:SetPoint("TOPLEFT", 0, fromTop)
				--Entry EditBox
				potionEditBoxName = "conEditBoxes" .. potions[key]
				editBoxes[potionEditBoxName] = CreateFrame("EditBox", potionEditBoxName, frames[potionFrameName], "InputBoxTemplate")
				editBoxes[potionEditBoxName]:SetAutoFocus(false)
				editBoxes[potionEditBoxName]:SetSize(25,30)
				editBoxes[potionEditBoxName]:SetPoint("CENTER", -110, 0)
				editBoxes[potionEditBoxName]:SetNumeric(true)
				editBoxes[potionEditBoxName]:SetMaxLetters(3)
				editBoxes[potionEditBoxName]:SetText("0")
				editBoxes[potionEditBoxName]:SetJustifyH("LEFT")
				editBoxes[potionEditBoxName]:SetScript("OnEnterPressed",function(s)
					s:ClearFocus()
				end)
				editBoxes[potionEditBoxName]:SetScript("OnEditFocusLost",function(s)
					if(s:GetText() == "") then
						s:SetNumber(0)
					end
				end)
				--Entry Item Icon
				potionItemIconName = "conItemIcon" .. potions[key]
				buttons[potionItemIconName] = CreateFrame("Button", potionItemIcon, frames[potionFrameName])
				buttons[potionItemIconName]:SetSize(40,40)
				buttons[potionItemIconName]:SetPoint("CENTER", -70, 0)
				buttons[potionItemIconName]:SetNormalTexture(GetItemIcon(potions[key]))
				buttons[potionItemIconName]:SetScript("OnEnter", function(self)
					GameTooltip:SetOwner(self, "ANCHOR_CURSOR");
					GameTooltip:ClearLines()
					GameTooltip:SetItemByID(potions[key])
					GameTooltip:Show()
				end)
				buttons[potionItemIconName]:SetScript("OnLeave", function(self)
					GameTooltip:Hide()
				end)
				--Entry Name
				potionNameStringName = "conNameString" .. potions[key]
				fontStrings[potionNameStringName] = frames[potionFrameName]:CreateFontString(potionNameStringName)
				fontStrings[potionNameStringName]:SetFont("Fonts\\FRIZQT__.ttf", 10)
				fontStrings[potionNameStringName]:SetText(key)
				fontStrings[potionNameStringName]:SetJustifyH("LEFT")
				fontStrings[potionNameStringName]:SetPoint("CENTER", 30, 0)
					
				fromTop = fromTop - 55
			end
		end

		scrollFrames.potionScrollFrame:SetScrollChild(frames.potionScrollContent)

		--Potion Frame: Previous Button
		buttons.potionFramePreviousButton = CreateFrame("Button", "PotionFramePreviousButton", frames.potionFrame, "UIPanelButtonTemplate")
		buttons.potionFramePreviousButton:SetSize(100,30)
		buttons.potionFramePreviousButton:SetPoint("CENTER", -100, -165)
		buttons.potionFramePreviousButton:SetText("Previous")

		--Potion Frame: Next Button
		buttons.potionFrameNextButton = CreateFrame("Button", "PotionFrameNextButton", frames.potionFrame, "UIPanelButtonTemplate")
		buttons.potionFrameNextButton:SetSize(100,30)
		buttons.potionFrameNextButton:SetPoint("CENTER", 100, -165)
		buttons.potionFrameNextButton:SetText("Next")



		fromTop = 10

		--Food Frame
		frames.foodFrame = CreateFrame("Frame", "FoodFrame", frames.RaidRConfig)
		frames.foodFrame:SetSize(350,400)
		frames.foodFrame:SetPoint("TOPLEFT")
		frames.foodFrame:Hide()

		--Food Frame: String for instructions
		fontStrings.foodString = frames.foodFrame:CreateFontString("FoodInstructions")
		fontStrings.foodString:SetFont("Fonts\\FRIZQT__.ttf", 17, "OUTLINE")
		fontStrings.foodString:SetText("Enter the number of each food\nyou expect to use during raid")
		fontStrings.foodString:SetJustifyH("CENTER")
		fontStrings.foodString:SetPoint("CENTER", 0, 150)

		--Food Frame: Frame for making a border
		frames.foodBorderFrame = CreateFrame("Frame", "FoodBorderFrame", frames.foodFrame)
		frames.foodBorderFrame:SetBackdrop({
			bgFile="Interface\\DialogFrame\\UI-DialogBox-Background", 
			edgeFile="Interface\\DialogFrame\\UI-DialogBox-Border", 
			tile=1, tileSize=32, edgeSize=32, 
			insets={left=11, right=12, top=12, bottom=11}
		})
		frames.foodBorderFrame:SetPoint("TOPLEFT", 20, -80)
		frames.foodBorderFrame:SetPoint("BOTTOMRIGHT", -40, 60)

		--Food Frame: ScrollFrame for food list
		scrollFrames.foodScrollFrame = CreateFrame("ScrollFrame", "FoodScrollFrame", frames.foodBorderFrame, "UIPanelScrollFrameTemplate")
		scrollFrames.foodScrollFrame:SetPoint("TOPLEFT", 0, -10)
		scrollFrames.foodScrollFrame:SetPoint("BOTTOMRIGHT", 0, 10)

		--Food Frame: Content container for food ScrollFrame
		frames.foodScrollContent = CreateFrame("Frame", "FoodScrollContent", scrollFrames.foodScrollFrame)
		frames.foodScrollContent:SetSize(290, 220)

		--Food Display
		for key, value in pairs(food) do
			if(value ~= 0 and value ~= nil) then
				--Entry Frame
				foodFrameName = "conFrame" .. food[key]
				frames[foodFrameName] = CreateFrame("Frame", foodFrameName, frames.foodScrollContent)
				frames[foodFrameName]:SetSize(290, 75)
				frames[foodFrameName]:SetPoint("TOPLEFT", 0, fromTop)
				--Entry EditBox
				foodEditBoxName = "conEditBoxes" .. food[key]
				editBoxes[foodEditBoxName] = CreateFrame("EditBox", foodEditBoxName, frames[foodFrameName], "InputBoxTemplate")
				editBoxes[foodEditBoxName]:SetAutoFocus(false)
				editBoxes[foodEditBoxName]:SetSize(25,30)
				editBoxes[foodEditBoxName]:SetPoint("CENTER", -110, 0)
				editBoxes[foodEditBoxName]:SetNumeric(true)
				editBoxes[foodEditBoxName]:SetMaxLetters(3)
				editBoxes[foodEditBoxName]:SetText("0")
				editBoxes[foodEditBoxName]:SetJustifyH("LEFT")
				editBoxes[foodEditBoxName]:SetScript("OnEnterPressed",function(s)
					s:ClearFocus()
				end)
				editBoxes[foodEditBoxName]:SetScript("OnEditFocusLost",function(s)
					if(s:GetText() == "") then
						s:SetNumber(0)
					end
				end)
				--Entry Item Icon
				foodItemIconName = "conItemIcon" .. food[key]
				buttons[foodItemIconName] = CreateFrame("Button", foodItemIcon, frames[foodFrameName])
				buttons[foodItemIconName]:SetSize(40,40)
				buttons[foodItemIconName]:SetPoint("CENTER", -70, 0)
				buttons[foodItemIconName]:SetNormalTexture(GetItemIcon(food[key]))
				buttons[foodItemIconName]:SetScript("OnEnter", function(self)
					GameTooltip:SetOwner(self, "ANCHOR_CURSOR");
					GameTooltip:ClearLines()
					GameTooltip:SetItemByID(food[key])
					GameTooltip:Show()
				end)
				buttons[foodItemIconName]:SetScript("OnLeave", function(self)
					GameTooltip:Hide()
				end)
				--Entry Name
				foodNameStringName = "conNameString" .. food[key]
				fontStrings[foodNameStringName] = frames[foodFrameName]:CreateFontString(foodNameStringName)
				fontStrings[foodNameStringName]:SetFont("Fonts\\FRIZQT__.ttf", 10)
				fontStrings[foodNameStringName]:SetText(key)
				fontStrings[foodNameStringName]:SetJustifyH("LEFT")
				fontStrings[foodNameStringName]:SetPoint("CENTER", 30, 0)
					
				fromTop = fromTop - 55
			end
		end

		scrollFrames.foodScrollFrame:SetScrollChild(frames.foodScrollContent)

		--Food Frame: Previous Button
		buttons.foodFramePreviousButton = CreateFrame("Button", "FoodFramePreviousButton", frames.foodFrame, "UIPanelButtonTemplate")
		buttons.foodFramePreviousButton:SetSize(100,30)
		buttons.foodFramePreviousButton:SetPoint("CENTER", -100, -165)
		buttons.foodFramePreviousButton:SetText("Previous")

		--Food Frame: Next Button
		buttons.foodFrameNextButton = CreateFrame("Button", "FoodFrameNextButton", frames.foodFrame, "UIPanelButtonTemplate")
		buttons.foodFrameNextButton:SetSize(100,30)
		buttons.foodFrameNextButton:SetPoint("CENTER", 100, -165)
		buttons.foodFrameNextButton:SetText("Next")



		fromTop = 10

		--Misc Frame
		frames.miscFrame = CreateFrame("Frame", "MiscFrame", frames.RaidRConfig)
		frames.miscFrame:SetSize(350,400)
		frames.miscFrame:SetPoint("TOPLEFT")
		frames.miscFrame:Hide()

		--Misc Frame: String for instructions
		fontStrings.miscString = frames.miscFrame:CreateFontString("MiscInstructions")
		fontStrings.miscString:SetFont("Fonts\\FRIZQT__.ttf", 17, "OUTLINE")
		fontStrings.miscString:SetText("Enter the number of each item\nyou expect to use during raid")
		fontStrings.miscString:SetJustifyH("CENTER")
		fontStrings.miscString:SetPoint("CENTER", 0, 150)

		--Misc Frame: Frame for making a border
		frames.miscBorderFrame = CreateFrame("Frame", "MiscBorderFrame", frames.miscFrame)
		frames.miscBorderFrame:SetBackdrop({
			bgFile="Interface\\DialogFrame\\UI-DialogBox-Background", 
			edgeFile="Interface\\DialogFrame\\UI-DialogBox-Border", 
			tile=1, tileSize=32, edgeSize=32, 
			insets={left=11, right=12, top=12, bottom=11}
		})
		frames.miscBorderFrame:SetPoint("TOPLEFT", 20, -80)
		frames.miscBorderFrame:SetPoint("BOTTOMRIGHT", -40, 60)

		--Misc Frame: ScrollFrame for misc list
		scrollFrames.miscScrollFrame = CreateFrame("ScrollFrame", "MiscScrollFrame", frames.miscBorderFrame, "UIPanelScrollFrameTemplate")
		scrollFrames.miscScrollFrame:SetPoint("TOPLEFT", 0, -10)
		scrollFrames.miscScrollFrame:SetPoint("BOTTOMRIGHT", 0, 10)

		--Misc Frame: Content container for misc ScrollFrame
		frames.miscScrollContent = CreateFrame("Frame", "MiscScrollContent", scrollFrames.miscScrollFrame)
		frames.miscScrollContent:SetSize(290, 110)

		--Misc Display
		for key, value in pairs(misc) do
			if(value ~= 0 and value ~= nil) then
				--Entry Frame
				miscFrameName = "conFrame" .. misc[key]
				frames[miscFrameName] = CreateFrame("Frame", miscFrameName, frames.miscScrollContent)
				frames[miscFrameName]:SetSize(290, 75)
				frames[miscFrameName]:SetPoint("TOPLEFT", 0, fromTop)
				--Entry EditBox
				miscEditBoxName = "conEditBoxes" .. misc[key]
				editBoxes[miscEditBoxName] = CreateFrame("EditBox", miscEditBoxName, frames[miscFrameName], "InputBoxTemplate")
				editBoxes[miscEditBoxName]:SetAutoFocus(false)
				editBoxes[miscEditBoxName]:SetSize(25,30)
				editBoxes[miscEditBoxName]:SetPoint("CENTER", -110, 0)
				editBoxes[miscEditBoxName]:SetNumeric(true)
				editBoxes[miscEditBoxName]:SetMaxLetters(3)
				editBoxes[miscEditBoxName]:SetText("0")
				editBoxes[miscEditBoxName]:SetJustifyH("LEFT")
				editBoxes[miscEditBoxName]:SetScript("OnEnterPressed",function(s)
					s:ClearFocus()
				end)
				editBoxes[miscEditBoxName]:SetScript("OnEditFocusLost",function(s)
					if(s:GetText() == "") then
						s:SetNumber(0)
					end
				end)
				--Entry Item Icon
				miscItemIconName = "conItemIcon" .. misc[key]
				buttons[miscItemIconName] = CreateFrame("Button", miscItemIcon, frames[miscFrameName])
				buttons[miscItemIconName]:SetSize(40,40)
				buttons[miscItemIconName]:SetPoint("CENTER", -70, 0)
				buttons[miscItemIconName]:SetNormalTexture(GetItemIcon(misc[key]))
				buttons[miscItemIconName]:SetScript("OnEnter", function(self)
					GameTooltip:SetOwner(self, "ANCHOR_CURSOR");
					GameTooltip:ClearLines()
					GameTooltip:SetItemByID(misc[key])
					GameTooltip:Show()
				end)
				buttons[miscItemIconName]:SetScript("OnLeave", function(self)
					GameTooltip:Hide()
				end)
				--Entry Name
				miscNameStringName = "conNameString" .. misc[key]
				fontStrings[miscNameStringName] = frames[miscFrameName]:CreateFontString(miscNameStringName)
				fontStrings[miscNameStringName]:SetFont("Fonts\\FRIZQT__.ttf", 10)
				fontStrings[miscNameStringName]:SetText(key)
				fontStrings[miscNameStringName]:SetJustifyH("LEFT")
				fontStrings[miscNameStringName]:SetPoint("CENTER", 30, 0)
					
				fromTop = fromTop - 55
			end
		end

		scrollFrames.miscScrollFrame:SetScrollChild(frames.miscScrollContent)

		--Misc Frame: Previous Button
		buttons.miscFramePreviousButton = CreateFrame("Button", "MiscFramePreviousButton", frames.miscFrame, "UIPanelButtonTemplate")
		buttons.miscFramePreviousButton:SetSize(100,30)
		buttons.miscFramePreviousButton:SetPoint("CENTER", -100, -165)
		buttons.miscFramePreviousButton:SetText("Previous")

		--Misc Frame: Next Button
		buttons.miscFrameNextButton = CreateFrame("Button", "MiscFrameNextButton", frames.miscFrame, "UIPanelButtonTemplate")
		buttons.miscFrameNextButton:SetSize(100,30)
		buttons.miscFrameNextButton:SetPoint("CENTER", 100, -165)
		buttons.miscFrameNextButton:SetText("Next")



		--RaidTime Frame
		frames.raidTimeFrame = CreateFrame("Frame", "RaidTimeFrame", frames.RaidRConfig)
		frames.raidTimeFrame:SetSize(350,400)
		frames.raidTimeFrame:SetPoint("TOPLEFT")
		frames.raidTimeFrame:Hide()

		--RaidTime Frame: String for instructions
		fontStrings.raidTimeString = frames.raidTimeFrame:CreateFontString("RaidTimeInstructions")
		fontStrings.raidTimeString:SetFont("Fonts\\FRIZQT__.ttf", 17, "OUTLINE")
		fontStrings.raidTimeString:SetText("What days/times do you raid?")
		fontStrings.raidTimeString:SetJustifyH("CENTER")
		fontStrings.raidTimeString:SetPoint("CENTER", 0, 150)

		--RaidTime Frame: Frame for making a border
		frames.raidTimeBorderFrame = CreateFrame("Frame", "RaidTimeBorderFrame", frames.raidTimeFrame)
		frames.raidTimeBorderFrame:SetBackdrop({
			bgFile="Interface\\DialogFrame\\UI-DialogBox-Background", 
			edgeFile="Interface\\DialogFrame\\UI-DialogBox-Border", 
			tile=1, tileSize=32, edgeSize=32, 
			insets={left=11, right=12, top=12, bottom=11}
		})
		frames.raidTimeBorderFrame:SetPoint("TOPLEFT", 20, -80)
		frames.raidTimeBorderFrame:SetPoint("BOTTOMRIGHT", -40, 60)

		--RaidTime Frame: ScrollFrame for raidTime list
		scrollFrames.raidTimeScrollFrame = CreateFrame("ScrollFrame", "RaidTimeScrollFrame", frames.raidTimeBorderFrame, "UIPanelScrollFrameTemplate")
		scrollFrames.raidTimeScrollFrame:SetPoint("TOPLEFT", 0, -10)
		scrollFrames.raidTimeScrollFrame:SetPoint("BOTTOMRIGHT", 0, 10)

		--RaidTime Frame: Content container for raidTime ScrollFrame
		frames.raidTimeScrollContent = CreateFrame("Frame", "RaidTimeScrollContent", scrollFrames.raidTimeScrollFrame)
		frames.raidTimeScrollContent:SetSize(290, 100)

		--Monday Frame
		frames.mondayFrame = CreateFrame("Frame", "monFrame", frames.raidTimeScrollContent)
		frames.mondayFrame:SetSize(290, 80)
		frames.mondayFrame:SetPoint("TOPLEFT", 0, 10)
		--Monday CheckButton
		checkButtons.mondayCheckButton = CreateFrame("CheckButton", "MondayCheckButton", frames.mondayFrame, "UICheckButtonTemplate")
		checkButtons.mondayCheckButton:SetPoint("CENTER", -110, 10)
		--Monday Name
		fontStrings.monString = frames.mondayFrame:CreateFontString("monName")
		fontStrings.monString:SetFont("Fonts\\FRIZQT__.ttf", 12)
		fontStrings.monString:SetText("Monday")
		fontStrings.monString:SetJustifyH("LEFT")
		fontStrings.monString:SetPoint("CENTER", -70, 11)
		--Monday Dropdowns
		local mondayHour = 1
		local mondayMinute = "00"
		local mondayAMPM = "AM"
		--Monday Hour Dropdown
		dropdowns.mondayHourDropdown = CreateFrame("Frame", "MondayHourDropdown", frames.mondayFrame, "UIDropDownMenuTemplate")
		dropdowns.mondayHourDropdown:SetPoint("CENTER", -95, -20)
		UIDropDownMenu_SetWidth(dropdowns.mondayHourDropdown, 40)
		UIDropDownMenu_SetText(dropdowns.mondayHourDropdown, mondayHour)
		UIDropDownMenu_Initialize(dropdowns.mondayHourDropdown, function(self, level, menuList)
			local info = UIDropDownMenu_CreateInfo()
			for i = 1, 12 do
				info.text = i
				info.checked = i == mondayHour
				info.func = self.SetValue
				info.arg1 = i
				UIDropDownMenu_AddButton(info, level)
			end
		end)
		function dropdowns.mondayHourDropdown:SetValue(newValue)
			mondayHour = newValue
			UIDropDownMenu_SetText(dropdowns.mondayHourDropdown, mondayHour)
			CloseDropDownMenus()
		end
		--Monday Minute Dropdown
		dropdowns.mondayMinuteDropdown = CreateFrame("Frame", "MondayMinuteDropdown", frames.mondayFrame, "UIDropDownMenuTemplate")
		dropdowns.mondayMinuteDropdown:SetPoint("CENTER", -35, -20)
		UIDropDownMenu_SetWidth(dropdowns.mondayMinuteDropdown, 40)
		UIDropDownMenu_SetText(dropdowns.mondayMinuteDropdown, mondayMinute)
		UIDropDownMenu_Initialize(dropdowns.mondayMinuteDropdown, function(self, level, menuList)
			local info = UIDropDownMenu_CreateInfo()
			for i = 0, 11 do
				info.text = string.format("%02d", (i * 5))
				info.checked = string.format("%02d", (i * 5)) == mondayMinute
				info.func = self.SetValue
				info.arg1 = string.format("%02d", (i * 5))
				UIDropDownMenu_AddButton(info, level)
			end
		end)
		function dropdowns.mondayMinuteDropdown:SetValue(newValue)
			mondayMinute = newValue
			UIDropDownMenu_SetText(dropdowns.mondayMinuteDropdown, mondayMinute)
			CloseDropDownMenus()
		end
		--Monday AMPM Dropdown
		dropdowns.mondayAMPMDropdown = CreateFrame("Frame", "MondayAMPMDropdown", frames.mondayFrame, "UIDropDownMenuTemplate")
		dropdowns.mondayAMPMDropdown:SetPoint("CENTER", 25, -20)
		UIDropDownMenu_SetWidth(dropdowns.mondayAMPMDropdown, 40)
		UIDropDownMenu_SetText(dropdowns.mondayAMPMDropdown, mondayAMPM)
		UIDropDownMenu_Initialize(dropdowns.mondayAMPMDropdown, function(self, level, menuList)
			local info = UIDropDownMenu_CreateInfo()
			info.text = "AM"
			info.checked = info.text == mondayAMPM
			info.func = self.SetValue
			info.arg1 = "AM"
			UIDropDownMenu_AddButton(info, level)
			
			info.text = "PM"
			info.checked = info.text == mondayAMPM
			info.func = self.SetValue
			info.arg1 = "PM"
			UIDropDownMenu_AddButton(info, level)
		end)
		function dropdowns.mondayAMPMDropdown:SetValue(newValue)
			mondayAMPM = newValue
			UIDropDownMenu_SetText(dropdowns.mondayAMPMDropdown, mondayAMPM)
			CloseDropDownMenus()
		end

		--Tuesday Frame
		frames.tuesdayFrame = CreateFrame("Frame", "tuesFrame", frames.raidTimeScrollContent)
		frames.tuesdayFrame:SetSize(290, 80)
		frames.tuesdayFrame:SetPoint("TOPLEFT", 0, -50)
		--Tuesday CheckButton
		checkButtons.tuesdayCheckButton = CreateFrame("CheckButton", "TuesdayCheckButton", frames.tuesdayFrame, "UICheckButtonTemplate")
		checkButtons.tuesdayCheckButton:SetPoint("CENTER", -110, 10)
		--Tuesday Name
		fontStrings.tuesString = frames.tuesdayFrame:CreateFontString("tuesName")
		fontStrings.tuesString:SetFont("Fonts\\FRIZQT__.ttf", 12)
		fontStrings.tuesString:SetText("Tuesday")
		fontStrings.tuesString:SetJustifyH("LEFT")
		fontStrings.tuesString:SetPoint("CENTER", -70, 11)
		--Tuesday Dropdowns
		local tuesdayHour = 1
		local tuesdayMinute = "00"
		local tuesdayAMPM = "AM"
		--Tuesday Hour Dropdown
		dropdowns.tuesdayHourDropdown = CreateFrame("Frame", "TuesdayHourDropdown", frames.tuesdayFrame, "UIDropDownMenuTemplate")
		dropdowns.tuesdayHourDropdown:SetPoint("CENTER", -95, -20)
		UIDropDownMenu_SetWidth(dropdowns.tuesdayHourDropdown, 40)
		UIDropDownMenu_SetText(dropdowns.tuesdayHourDropdown, tuesdayHour)
		UIDropDownMenu_Initialize(dropdowns.tuesdayHourDropdown, function(self, level, menuList)
			local info = UIDropDownMenu_CreateInfo()
			for i = 1, 12 do
				info.text = i
				info.checked = i == tuesdayHour
				info.func = self.SetValue
				info.arg1 = i
				UIDropDownMenu_AddButton(info, level)
			end
		end)
		function dropdowns.tuesdayHourDropdown:SetValue(newValue)
			tuesdayHour = newValue
			UIDropDownMenu_SetText(dropdowns.tuesdayHourDropdown, tuesdayHour)
			CloseDropDownMenus()
		end
		--Tuesday Minute Dropdown
		dropdowns.tuesdayMinuteDropdown = CreateFrame("Frame", "TuesdayMinuteDropdown", frames.tuesdayFrame, "UIDropDownMenuTemplate")
		dropdowns.tuesdayMinuteDropdown:SetPoint("CENTER", -35, -20)
		UIDropDownMenu_SetWidth(dropdowns.tuesdayMinuteDropdown, 40)
		UIDropDownMenu_SetText(dropdowns.tuesdayMinuteDropdown, tuesdayMinute)
		UIDropDownMenu_Initialize(dropdowns.tuesdayMinuteDropdown, function(self, level, menuList)
			local info = UIDropDownMenu_CreateInfo()
			for i = 0, 11 do
				info.text = string.format("%02d", (i * 5))
				info.checked = string.format("%02d", (i * 5)) == tuesdayMinute
				info.func = self.SetValue
				info.arg1 = string.format("%02d", (i * 5))
				UIDropDownMenu_AddButton(info, level)
			end
		end)
		function dropdowns.tuesdayMinuteDropdown:SetValue(newValue)
			tuesdayMinute = newValue
			UIDropDownMenu_SetText(dropdowns.tuesdayMinuteDropdown, tuesdayMinute)
			CloseDropDownMenus()
		end
		--Tuesday AMPM Dropdown
		dropdowns.tuesdayAMPMDropdown = CreateFrame("Frame", "TuesdayAMPMDropdown", frames.tuesdayFrame, "UIDropDownMenuTemplate")
		dropdowns.tuesdayAMPMDropdown:SetPoint("CENTER", 25, -20)
		UIDropDownMenu_SetWidth(dropdowns.tuesdayAMPMDropdown, 40)
		UIDropDownMenu_SetText(dropdowns.tuesdayAMPMDropdown, tuesdayAMPM)
		UIDropDownMenu_Initialize(dropdowns.tuesdayAMPMDropdown, function(self, level, menuList)
			local info = UIDropDownMenu_CreateInfo()
			info.text = "AM"
			info.checked = info.text == tuesdayAMPM
			info.func = self.SetValue
			info.arg1 = "AM"
			UIDropDownMenu_AddButton(info, level)
			
			info.text = "PM"
			info.checked = info.text == tuesdayAMPM
			info.func = self.SetValue
			info.arg1 = "PM"
			UIDropDownMenu_AddButton(info, level)
		end)
		function dropdowns.tuesdayAMPMDropdown:SetValue(newValue)
			tuesdayAMPM = newValue
			UIDropDownMenu_SetText(dropdowns.tuesdayAMPMDropdown, tuesdayAMPM)
			CloseDropDownMenus()
		end

		--Wednesday Frame
		frames.wednesdayFrame = CreateFrame("Frame", "wedFrame", frames.raidTimeScrollContent)
		frames.wednesdayFrame:SetSize(290, 80)
		frames.wednesdayFrame:SetPoint("TOPLEFT", 0, -110)
		--Wednesday CheckButton
		checkButtons.wednesdayCheckButton = CreateFrame("CheckButton", "WednesdayCheckButton", frames.wednesdayFrame, "UICheckButtonTemplate")
		checkButtons.wednesdayCheckButton:SetPoint("CENTER", -110, 10)
		--Wednesday Name
		fontStrings.wedString = frames.wednesdayFrame:CreateFontString("wedName")
		fontStrings.wedString:SetFont("Fonts\\FRIZQT__.ttf", 12)
		fontStrings.wedString:SetText("Wednesday")
		fontStrings.wedString:SetJustifyH("LEFT")
		fontStrings.wedString:SetPoint("CENTER", -60, 11)
		--Wednesday Dropdowns
		local wednesdayHour = 1
		local wednesdayMinute = "00"
		local wednesdayAMPM = "AM"
		--Wednesday Hour Dropdown
		frames.wednesdayHourDropdown = CreateFrame("Frame", "WednesdayHourDropdown", frames.wednesdayFrame, "UIDropDownMenuTemplate")
		frames.wednesdayHourDropdown:SetPoint("CENTER", -95, -20)
		UIDropDownMenu_SetWidth(frames.wednesdayHourDropdown, 40)
		UIDropDownMenu_SetText(frames.wednesdayHourDropdown, wednesdayHour)
		UIDropDownMenu_Initialize(frames.wednesdayHourDropdown, function(self, level, menuList)
			local info = UIDropDownMenu_CreateInfo()
			for i = 1, 12 do
				info.text = i
				info.checked = i == wednesdayHour
				info.func = self.SetValue
				info.arg1 = i
				UIDropDownMenu_AddButton(info, level)
			end
		end)
		function frames.wednesdayHourDropdown:SetValue(newValue)
			wednesdayHour = newValue
			UIDropDownMenu_SetText(frames.wednesdayHourDropdown, wednesdayHour)
			CloseDropDownMenus()
		end
		--Wednesday Minute Dropdown
		dropdowns.wednesdayMinuteDropdown = CreateFrame("Frame", "WednesdayMinuteDropdown", frames.wednesdayFrame, "UIDropDownMenuTemplate")
		dropdowns.wednesdayMinuteDropdown:SetPoint("CENTER", -35, -20)
		UIDropDownMenu_SetWidth(dropdowns.wednesdayMinuteDropdown, 40)
		UIDropDownMenu_SetText(dropdowns.wednesdayMinuteDropdown, wednesdayMinute)
		UIDropDownMenu_Initialize(dropdowns.wednesdayMinuteDropdown, function(self, level, menuList)
			local info = UIDropDownMenu_CreateInfo()
			for i = 0, 11 do
				info.text = string.format("%02d", (i * 5))
				info.checked = string.format("%02d", (i * 5)) == wednesdayMinute
				info.func = self.SetValue
				info.arg1 = string.format("%02d", (i * 5))
				UIDropDownMenu_AddButton(info, level)
			end
		end)
		function dropdowns.wednesdayMinuteDropdown:SetValue(newValue)
			wednesdayMinute = newValue
			UIDropDownMenu_SetText(dropdowns.wednesdayMinuteDropdown, wednesdayMinute)
			CloseDropDownMenus()
		end
		--Wednesday AMPM Dropdown
		dropdowns.wednesdayAMPMDropdown = CreateFrame("Frame", "WednesdayAMPMDropdown", frames.wednesdayFrame, "UIDropDownMenuTemplate")
		dropdowns.wednesdayAMPMDropdown:SetPoint("CENTER", 25, -20)
		UIDropDownMenu_SetWidth(dropdowns.wednesdayAMPMDropdown, 40)
		UIDropDownMenu_SetText(dropdowns.wednesdayAMPMDropdown, wednesdayAMPM)
		UIDropDownMenu_Initialize(dropdowns.wednesdayAMPMDropdown, function(self, level, menuList)
			local info = UIDropDownMenu_CreateInfo()
			info.text = "AM"
			info.checked = info.text == wednesdayAMPM
			info.func = self.SetValue
			info.arg1 = "AM"
			UIDropDownMenu_AddButton(info, level)
			
			info.text = "PM"
			info.checked = info.text == wednesdayAMPM
			info.func = self.SetValue
			info.arg1 = "PM"
			UIDropDownMenu_AddButton(info, level)
		end)
		function dropdowns.wednesdayAMPMDropdown:SetValue(newValue)
			wednesdayAMPM = newValue
			UIDropDownMenu_SetText(dropdowns.wednesdayAMPMDropdown, wednesdayAMPM)
			CloseDropDownMenus()
		end

		--Thursday Frame
		frames.thursdayFrame = CreateFrame("Frame", "thursFrame", frames.raidTimeScrollContent)
		frames.thursdayFrame:SetSize(290, 80)
		frames.thursdayFrame:SetPoint("TOPLEFT", 0, -170)
		--Thursday CheckButton
		checkButtons.thursdayCheckButton = CreateFrame("CheckButton", "ThursdayCheckButton", frames.thursdayFrame, "UICheckButtonTemplate")
		checkButtons.thursdayCheckButton:SetPoint("CENTER", -110, 10)
		--Thursday Name
		fontStrings.thursString = frames.thursdayFrame:CreateFontString("thursName")
		fontStrings.thursString:SetFont("Fonts\\FRIZQT__.ttf", 12)
		fontStrings.thursString:SetText("Thursday")
		fontStrings.thursString:SetJustifyH("LEFT")
		fontStrings.thursString:SetPoint("CENTER", -66, 11)
		--Thursday Dropdowns
		local thursdayHour = 1
		local thursdayMinute = "00"
		local thursdayAMPM = "AM"
		--Thursday Hour Dropdown
		dropdowns.thursdayHourDropdown = CreateFrame("Frame", "ThursdayHourDropdown", frames.thursdayFrame, "UIDropDownMenuTemplate")
		dropdowns.thursdayHourDropdown:SetPoint("CENTER", -95, -20)
		UIDropDownMenu_SetWidth(dropdowns.thursdayHourDropdown, 40)
		UIDropDownMenu_SetText(dropdowns.thursdayHourDropdown, thursdayHour)
		UIDropDownMenu_Initialize(dropdowns.thursdayHourDropdown, function(self, level, menuList)
			local info = UIDropDownMenu_CreateInfo()
			for i = 1, 12 do
				info.text = i
				info.checked = i == thursdayHour
				info.func = self.SetValue
				info.arg1 = i
				UIDropDownMenu_AddButton(info, level)
			end
		end)
		function dropdowns.thursdayHourDropdown:SetValue(newValue)
			thursdayHour = newValue
			UIDropDownMenu_SetText(dropdowns.thursdayHourDropdown, thursdayHour)
			CloseDropDownMenus()
		end
		--Thursday Minute Dropdown
		dropdowns.thursdayMinuteDropdown = CreateFrame("Frame", "ThursdayMinuteDropdown", frames.thursdayFrame, "UIDropDownMenuTemplate")
		dropdowns.thursdayMinuteDropdown:SetPoint("CENTER", -35, -20)
		UIDropDownMenu_SetWidth(dropdowns.thursdayMinuteDropdown, 40)
		UIDropDownMenu_SetText(dropdowns.thursdayMinuteDropdown, thursdayMinute)
		UIDropDownMenu_Initialize(dropdowns.thursdayMinuteDropdown, function(self, level, menuList)
			local info = UIDropDownMenu_CreateInfo()
			for i = 0, 11 do
				info.text = string.format("%02d", (i * 5))
				info.checked = string.format("%02d", (i * 5)) == thursdayMinute
				info.func = self.SetValue
				info.arg1 = string.format("%02d", (i * 5))
				UIDropDownMenu_AddButton(info, level)
			end
		end)
		function dropdowns.thursdayMinuteDropdown:SetValue(newValue)
			thursdayMinute = newValue
			UIDropDownMenu_SetText(dropdowns.thursdayMinuteDropdown, thursdayMinute)
			CloseDropDownMenus()
		end
		--Thursday AMPM Dropdown
		dropdowns.thursdayAMPMDropdown = CreateFrame("Frame", "ThursdayAMPMDropdown", frames.thursdayFrame, "UIDropDownMenuTemplate")
		dropdowns.thursdayAMPMDropdown:SetPoint("CENTER", 25, -20)
		UIDropDownMenu_SetWidth(dropdowns.thursdayAMPMDropdown, 40)
		UIDropDownMenu_SetText(dropdowns.thursdayAMPMDropdown, thursdayAMPM)
		UIDropDownMenu_Initialize(dropdowns.thursdayAMPMDropdown, function(self, level, menuList)
			local info = UIDropDownMenu_CreateInfo()
			info.text = "AM"
			info.checked = info.text == thursdayAMPM
			info.func = self.SetValue
			info.arg1 = "AM"
			UIDropDownMenu_AddButton(info, level)
			
			info.text = "PM"
			info.checked = info.text == thursdayAMPM
			info.func = self.SetValue
			info.arg1 = "PM"
			UIDropDownMenu_AddButton(info, level)
		end)
		function dropdowns.thursdayAMPMDropdown:SetValue(newValue)
			thursdayAMPM = newValue
			UIDropDownMenu_SetText(dropdowns.thursdayAMPMDropdown, thursdayAMPM)
			CloseDropDownMenus()
		end

		--Friday Frame
		frames.fridayFrame = CreateFrame("Frame", "friFrame", frames.raidTimeScrollContent)
		frames.fridayFrame:SetSize(290, 80)
		frames.fridayFrame:SetPoint("TOPLEFT", 0, -230)
		--Friday CheckButton
		checkButtons.fridayCheckButton = CreateFrame("CheckButton", "FridayCheckButton", frames.fridayFrame, "UICheckButtonTemplate")
		checkButtons.fridayCheckButton:SetPoint("CENTER", -110, 10)
		--Friday Name
		fontStrings.friString = frames.fridayFrame:CreateFontString("friName")
		fontStrings.friString:SetFont("Fonts\\FRIZQT__.ttf", 12)
		fontStrings.friString:SetText("Friday")
		fontStrings.friString:SetJustifyH("LEFT")
		fontStrings.friString:SetPoint("CENTER", -75, 11)
		--Friday Dropdowns
		local fridayHour = 1
		local fridayMinute = "00"
		local fridayAMPM = "AM"
		--Friday Hour Dropdown
		dropdowns.fridayHourDropdown = CreateFrame("Frame", "FridayHourDropdown", frames.fridayFrame, "UIDropDownMenuTemplate")
		dropdowns.fridayHourDropdown:SetPoint("CENTER", -95, -20)
		UIDropDownMenu_SetWidth(dropdowns.fridayHourDropdown, 40)
		UIDropDownMenu_SetText(dropdowns.fridayHourDropdown, fridayHour)
		UIDropDownMenu_Initialize(dropdowns.fridayHourDropdown, function(self, level, menuList)
			local info = UIDropDownMenu_CreateInfo()
			for i = 1, 12 do
				info.text = i
				info.checked = i == fridayHour
				info.func = self.SetValue
				info.arg1 = i
				UIDropDownMenu_AddButton(info, level)
			end
		end)
		function dropdowns.fridayHourDropdown:SetValue(newValue)
			fridayHour = newValue
			UIDropDownMenu_SetText(dropdowns.fridayHourDropdown, fridayHour)
			CloseDropDownMenus()
		end
		--Friday Minute Dropdown
		dropdowns.fridayMinuteDropdown = CreateFrame("Frame", "FridayMinuteDropdown", frames.fridayFrame, "UIDropDownMenuTemplate")
		dropdowns.fridayMinuteDropdown:SetPoint("CENTER", -35, -20)
		UIDropDownMenu_SetWidth(dropdowns.fridayMinuteDropdown, 40)
		UIDropDownMenu_SetText(dropdowns.fridayMinuteDropdown, fridayMinute)
		UIDropDownMenu_Initialize(dropdowns.fridayMinuteDropdown, function(self, level, menuList)
			local info = UIDropDownMenu_CreateInfo()
			for i = 0, 11 do
				info.text = string.format("%02d", (i * 5))
				info.checked = string.format("%02d", (i * 5)) == fridayMinute
				info.func = self.SetValue
				info.arg1 = string.format("%02d", (i * 5))
				UIDropDownMenu_AddButton(info, level)
			end
		end)
		function dropdowns.fridayMinuteDropdown:SetValue(newValue)
			fridayMinute = newValue
			UIDropDownMenu_SetText(dropdowns.fridayMinuteDropdown, fridayMinute)
			CloseDropDownMenus()
		end
		--Friday AMPM Dropdown
		dropdowns.fridayAMPMDropdown = CreateFrame("Frame", "FridayAMPMDropdown", frames.fridayFrame, "UIDropDownMenuTemplate")
		dropdowns.fridayAMPMDropdown:SetPoint("CENTER", 25, -20)
		UIDropDownMenu_SetWidth(dropdowns.fridayAMPMDropdown, 40)
		UIDropDownMenu_SetText(dropdowns.fridayAMPMDropdown, fridayAMPM)
		UIDropDownMenu_Initialize(dropdowns.fridayAMPMDropdown, function(self, level, menuList)
			local info = UIDropDownMenu_CreateInfo()
			info.text = "AM"
			info.checked = info.text == fridayAMPM
			info.func = self.SetValue
			info.arg1 = "AM"
			UIDropDownMenu_AddButton(info, level)
			
			info.text = "PM"
			info.checked = info.text == fridayAMPM
			info.func = self.SetValue
			info.arg1 = "PM"
			UIDropDownMenu_AddButton(info, level)
		end)
		function dropdowns.fridayAMPMDropdown:SetValue(newValue)
			fridayAMPM = newValue
			UIDropDownMenu_SetText(dropdowns.fridayAMPMDropdown, fridayAMPM)
			CloseDropDownMenus()
		end

		--Saturday Frame
		frames.saturdayFrame = CreateFrame("Frame", "satFrame", frames.raidTimeScrollContent)
		frames.saturdayFrame:SetSize(290, 80)
		frames.saturdayFrame:SetPoint("TOPLEFT", 0, -290)
		--Saturday CheckButton
		checkButtons.saturdayCheckButton = CreateFrame("CheckButton", "SaturdayCheckButton", frames.saturdayFrame, "UICheckButtonTemplate")
		checkButtons.saturdayCheckButton:SetPoint("CENTER", -110, 10)
		--Saturday Name
		fontStrings.satString = frames.saturdayFrame:CreateFontString("satName")
		fontStrings.satString:SetFont("Fonts\\FRIZQT__.ttf", 12)
		fontStrings.satString:SetText("Saturday")
		fontStrings.satString:SetJustifyH("LEFT")
		fontStrings.satString:SetPoint("CENTER", -67, 11)
		--Saturday Dropdowns
		local saturdayHour = 1
		local saturdayMinute = "00"
		local saturdayAMPM = "AM"
		--Saturday Hour Dropdown
		dropdowns.saturdayHourDropdown = CreateFrame("Frame", "SaturdayHourDropdown", frames.saturdayFrame, "UIDropDownMenuTemplate")
		dropdowns.saturdayHourDropdown:SetPoint("CENTER", -95, -20)
		UIDropDownMenu_SetWidth(dropdowns.saturdayHourDropdown, 40)
		UIDropDownMenu_SetText(dropdowns.saturdayHourDropdown, saturdayHour)
		UIDropDownMenu_Initialize(dropdowns.saturdayHourDropdown, function(self, level, menuList)
			local info = UIDropDownMenu_CreateInfo()
			for i = 1, 12 do
				info.text = i
				info.checked = i == saturdayHour
				info.func = self.SetValue
				info.arg1 = i
				UIDropDownMenu_AddButton(info, level)
			end
		end)
		function dropdowns.saturdayHourDropdown:SetValue(newValue)
			saturdayHour = newValue
			UIDropDownMenu_SetText(dropdowns.saturdayHourDropdown, saturdayHour)
			CloseDropDownMenus()
		end
		--Saturday Minute Dropdown
		dropdowns.saturdayMinuteDropdown = CreateFrame("Frame", "SaturdayMinuteDropdown", frames.saturdayFrame, "UIDropDownMenuTemplate")
		dropdowns.saturdayMinuteDropdown:SetPoint("CENTER", -35, -20)
		UIDropDownMenu_SetWidth(dropdowns.saturdayMinuteDropdown, 40)
		UIDropDownMenu_SetText(dropdowns.saturdayMinuteDropdown, saturdayMinute)
		UIDropDownMenu_Initialize(dropdowns.saturdayMinuteDropdown, function(self, level, menuList)
			local info = UIDropDownMenu_CreateInfo()
			for i = 0, 11 do
				info.text = string.format("%02d", (i * 5))
				info.checked = string.format("%02d", (i * 5)) == saturdayMinute
				info.func = self.SetValue
				info.arg1 = string.format("%02d", (i * 5))
				UIDropDownMenu_AddButton(info, level)
			end
		end)
		function dropdowns.saturdayMinuteDropdown:SetValue(newValue)
			saturdayMinute = newValue
			UIDropDownMenu_SetText(dropdowns.saturdayMinuteDropdown, saturdayMinute)
			CloseDropDownMenus()
		end
		--Saturday AMPM Dropdown
		dropdowns.saturdayAMPMDropdown = CreateFrame("Frame", "SaturdayAMPMDropdown", frames.saturdayFrame, "UIDropDownMenuTemplate")
		dropdowns.saturdayAMPMDropdown:SetPoint("CENTER", 25, -20)
		UIDropDownMenu_SetWidth(dropdowns.saturdayAMPMDropdown, 40)
		UIDropDownMenu_SetText(dropdowns.saturdayAMPMDropdown, saturdayAMPM)
		UIDropDownMenu_Initialize(dropdowns.saturdayAMPMDropdown, function(self, level, menuList)
			local info = UIDropDownMenu_CreateInfo()
			info.text = "AM"
			info.checked = info.text == saturdayAMPM
			info.func = self.SetValue
			info.arg1 = "AM"
			UIDropDownMenu_AddButton(info, level)
			
			info.text = "PM"
			info.checked = info.text == saturdayAMPM
			info.func = self.SetValue
			info.arg1 = "PM"
			UIDropDownMenu_AddButton(info, level)
		end)
		function dropdowns.saturdayAMPMDropdown:SetValue(newValue)
			saturdayAMPM = newValue
			UIDropDownMenu_SetText(dropdowns.saturdayAMPMDropdown, saturdayAMPM)
			CloseDropDownMenus()
		end

		--Sunday Frame
		frames.sundayFrame = CreateFrame("Frame", "sunFrame", frames.raidTimeScrollContent)
		frames.sundayFrame:SetSize(290, 80)
		frames.sundayFrame:SetPoint("TOPLEFT", 0, -350)
		--Sunday CheckButton
		checkButtons.sundayCheckButton = CreateFrame("CheckButton", "SundayCheckButton", frames.sundayFrame, "UICheckButtonTemplate")
		checkButtons.sundayCheckButton:SetPoint("CENTER", -110, 10)
		--Sunday Name
		fontStrings.sunString = frames.sundayFrame:CreateFontString("sunName")
		fontStrings.sunString:SetFont("Fonts\\FRIZQT__.ttf", 12)
		fontStrings.sunString:SetText("Sunday")
		fontStrings.sunString:SetJustifyH("LEFT")
		fontStrings.sunString:SetPoint("CENTER", -71, 11)
		--Sunday Dropdowns
		local sundayHour = 1
		local sundayMinute = "00"
		local sundayAMPM = "AM"
		--Sunday Hour Dropdown
		dropdowns.sundayHourDropdown = CreateFrame("Frame", "SundayHourDropdown", frames.sundayFrame, "UIDropDownMenuTemplate")
		dropdowns.sundayHourDropdown:SetPoint("CENTER", -95, -20)
		UIDropDownMenu_SetWidth(dropdowns.sundayHourDropdown, 40)
		UIDropDownMenu_SetText(dropdowns.sundayHourDropdown, sundayHour)
		UIDropDownMenu_Initialize(dropdowns.sundayHourDropdown, function(self, level, menuList)
			local info = UIDropDownMenu_CreateInfo()
			for i = 1, 12 do
				info.text = i
				info.checked = i == sundayHour
				info.func = self.SetValue
				info.arg1 = i
				UIDropDownMenu_AddButton(info, level)
			end
		end)
		function dropdowns.sundayHourDropdown:SetValue(newValue)
			sundayHour = newValue
			UIDropDownMenu_SetText(dropdowns.sundayHourDropdown, sundayHour)
			CloseDropDownMenus()
		end
		--Sunday Minute Dropdown
		dropdowns.sundayMinuteDropdown = CreateFrame("Frame", "SundayMinuteDropdown", frames.sundayFrame, "UIDropDownMenuTemplate")
		dropdowns.sundayMinuteDropdown:SetPoint("CENTER", -35, -20)
		UIDropDownMenu_SetWidth(dropdowns.sundayMinuteDropdown, 40)
		UIDropDownMenu_SetText(dropdowns.sundayMinuteDropdown, sundayMinute)
		UIDropDownMenu_Initialize(dropdowns.sundayMinuteDropdown, function(self, level, menuList)
			local info = UIDropDownMenu_CreateInfo()
			for i = 0, 11 do
				info.text = string.format("%02d", (i * 5))
				info.checked = string.format("%02d", (i * 5)) == sundayMinute
				info.func = self.SetValue
				info.arg1 = string.format("%02d", (i * 5))
				UIDropDownMenu_AddButton(info, level)
			end
		end)
		function dropdowns.sundayMinuteDropdown:SetValue(newValue)
			sundayMinute = newValue
			UIDropDownMenu_SetText(dropdowns.sundayMinuteDropdown, sundayMinute)
			CloseDropDownMenus()
		end
		--Sunday AMPM Dropdown
		dropdowns.sundayAMPMDropdown = CreateFrame("Frame", "SundayAMPMDropdown", frames.sundayFrame, "UIDropDownMenuTemplate")
		dropdowns.sundayAMPMDropdown:SetPoint("CENTER", 25, -20)
		UIDropDownMenu_SetWidth(dropdowns.sundayAMPMDropdown, 40)
		UIDropDownMenu_SetText(dropdowns.sundayAMPMDropdown, sundayAMPM)
		UIDropDownMenu_Initialize(dropdowns.sundayAMPMDropdown, function(self, level, menuList)
			local info = UIDropDownMenu_CreateInfo()
			info.text = "AM"
			info.checked = info.text == sundayAMPM
			info.func = self.SetValue
			info.arg1 = "AM"
			UIDropDownMenu_AddButton(info, level)
			
			info.text = "PM"
			info.checked = info.text == sundayAMPM
			info.func = self.SetValue
			info.arg1 = "PM"
			UIDropDownMenu_AddButton(info, level)
		end)
		function dropdowns.sundayAMPMDropdown:SetValue(newValue)
			sundayAMPM = newValue
			UIDropDownMenu_SetText(dropdowns.sundayAMPMDropdown, sundayAMPM)
			CloseDropDownMenus()
		end

		scrollFrames.raidTimeScrollFrame:SetScrollChild(frames.raidTimeScrollContent)

		--RaidTime Frame: Previous Button
		buttons.raidTimeFramePreviousButton = CreateFrame("Button", "RaidTimeFramePreviousButton", frames.raidTimeFrame, "UIPanelButtonTemplate")
		buttons.raidTimeFramePreviousButton:SetSize(100,30)
		buttons.raidTimeFramePreviousButton:SetPoint("CENTER", -100, -165)
		buttons.raidTimeFramePreviousButton:SetText("Previous")

		--RaidTime Frame: Next Button
		buttons.raidTimeFrameNextButton = CreateFrame("Button", "RaidTimeFrameNextButton", frames.raidTimeFrame, "UIPanelButtonTemplate")
		buttons.raidTimeFrameNextButton:SetSize(100,30)
		buttons.raidTimeFrameNextButton:SetPoint("CENTER", 100, -165)
		buttons.raidTimeFrameNextButton:SetText("Next")



		--Options Frame
		frames.optionsFrame = CreateFrame("Frame", "OptionsFrame", frames.RaidRConfig)
		frames.optionsFrame:SetSize(350,400)
		frames.optionsFrame:SetPoint("TOPLEFT")
		frames.optionsFrame:Hide()

		--Options Frame: String for instructions
		fontStrings.optionsString = frames.optionsFrame:CreateFontString("OptionsInstructions")
		fontStrings.optionsString:SetFont("Fonts\\FRIZQT__.ttf", 17, "OUTLINE")
		fontStrings.optionsString:SetText("Let's set up some final options")
		fontStrings.optionsString:SetJustifyH("CENTER")
		fontStrings.optionsString:SetPoint("CENTER", 0, 150)

		--Options Frame: Frame for making a border
		frames.optionsBorderFrame = CreateFrame("Frame", "OptionsBorderFrame", frames.optionsFrame)
		frames.optionsBorderFrame:SetBackdrop({
			bgFile="Interface\\DialogFrame\\UI-DialogBox-Background", 
			edgeFile="Interface\\DialogFrame\\UI-DialogBox-Border", 
			tile=1, tileSize=32, edgeSize=32, 
			insets={left=11, right=12, top=12, bottom=11}
		})
		frames.optionsBorderFrame:SetPoint("TOPLEFT", 20, -80)
		frames.optionsBorderFrame:SetPoint("BOTTOMRIGHT", -40, 60)

		--Options Frame: ScrollFrame for options list
		scrollFrames.optionsScrollFrame = CreateFrame("ScrollFrame", "OptionsScrollFrame", frames.optionsBorderFrame, "UIPanelScrollFrameTemplate")
		scrollFrames.optionsScrollFrame:SetPoint("TOPLEFT", 0, -10)
		scrollFrames.optionsScrollFrame:SetPoint("BOTTOMRIGHT", 0, 10)

		--Options Frame: Content container for options ScrollFrame
		frames.optionsScrollContent = CreateFrame("Frame", "OptionsScrollContent", scrollFrames.optionsScrollFrame)
		frames.optionsScrollContent:SetSize(290, 330)

		--Reminder Time Frame
		frames.reminderTimeFrame = CreateFrame("Frame", "rmtFrame", frames.optionsScrollContent)
		frames.reminderTimeFrame:SetSize(290, 75)
		frames.reminderTimeFrame:SetPoint("TOPLEFT", 0, 10)
		--Reminder Time String
		fontStrings.reminderTimeString = frames.reminderTimeFrame:CreateFontString("ReminderTimeString")
		fontStrings.reminderTimeString:SetFont("Fonts\\FRIZQT__.ttf", 10)
		fontStrings.reminderTimeString:SetText("Pre-raid alert: ")
		fontStrings.reminderTimeString:SetJustifyH("LEFT")
		fontStrings.reminderTimeString:SetPoint("CENTER", -85, 0)
		--Reminder Time Dropdown
		local reminderTimeString = "5 minutes"
		local reminderTimeValue = 5
		dropdowns.reminderTimeDropdown = CreateFrame("Frame", "ReminderTimeDropdown", frames.reminderTimeFrame, "UIDropDownMenuTemplate")
		dropdowns.reminderTimeDropdown:SetPoint("CENTER", 5, -3)
		UIDropDownMenu_SetWidth(dropdowns.reminderTimeDropdown, 80)
		UIDropDownMenu_SetText(dropdowns.reminderTimeDropdown, reminderTimeString)
		UIDropDownMenu_Initialize(dropdowns.reminderTimeDropdown, function(self, level, menuList)
			local info = UIDropDownMenu_CreateInfo()
			info.text = "5 minutes"
			info.checked = info.text == reminderTimeString
			info.value = 5
			info.func = self.SetValue
			info.arg1 = info.text
			info.arg2 = info.value
			UIDropDownMenu_AddButton(info, level)
			
			info.text = "10 minutes"
			info.checked = info.text == reminderTimeString
			info.value = 10
			info.func = self.SetValue
			info.arg1 = info.text
			info.arg2 = info.value
			UIDropDownMenu_AddButton(info, level)
			
			info.text = "15 minutes"
			info.checked = info.text == reminderTimeString
			info.value = 15
			info.func = self.SetValue
			info.arg1 = info.text
			info.arg2 = info.value
			UIDropDownMenu_AddButton(info, level)
			
			info.text = "30 minutes"
			info.checked = info.text == reminderTimeString
			info.value = 30
			info.func = self.SetValue
			info.arg1 = info.text
			info.arg2 = info.value
			UIDropDownMenu_AddButton(info, level)
			
			info.text = "45 minutes"
			info.checked = info.text == reminderTimeString
			info.value = 45
			info.func = self.SetValue
			info.arg1 = info.text
			info.arg2 = info.value
			UIDropDownMenu_AddButton(info, level)
			
			info.text = "1 hour"
			info.checked = info.text == reminderTimeString
			info.value = 60
			info.func = self.SetValue
			info.arg1 = info.text
			info.arg2 = info.value
			UIDropDownMenu_AddButton(info, level)
		end)
		function dropdowns.reminderTimeDropdown:SetValue(newString, newValue)
			reminderTimeString = newString
			reminderTimeValue = newValue
			UIDropDownMenu_SetText(dropdowns.reminderTimeDropdown, reminderTimeString)
			CloseDropDownMenus()
		end
		dropdowns.reminderTimeDropdown:SetScript("OnEnter", function(self)
			GameTooltip:SetOwner(self, "ANCHOR_CURSOR");
			GameTooltip:ClearLines()
			GameTooltip:SetText("How long before raid you would like\nRaidR to check your consumables")
			GameTooltip:Show()
		end)
		dropdowns.reminderTimeDropdown:SetScript("OnLeave", function(self)
			GameTooltip:Hide()
		end)

		--Bonus Roll Option Frame
		frames.bonusRollOptionFrame = CreateFrame("Frame", "broFrame", frames.optionsScrollContent)
		frames.bonusRollOptionFrame:SetSize(290, 75)
		frames.bonusRollOptionFrame:SetPoint("TOPLEFT", 0, -45)
		--Bonus Roll Option CheckButton
		checkButtons.broCheckButton = CreateFrame("CheckButton", "broCheckButton", frames.bonusRollOptionFrame, "UICheckButtonTemplate")
		checkButtons.broCheckButton:SetPoint("CENTER", -110, -2)
		checkButtons.broCheckButton:SetScript("OnEnter", function(self)
			GameTooltip:SetOwner(self, "ANCHOR_CURSOR");
			GameTooltip:ClearLines()
			GameTooltip:SetText("If checked, the reminder window will include a check\nto make sure you bought your Seals this week")
			GameTooltip:Show()
		end)
		checkButtons.broCheckButton:SetScript("OnLeave", function(self)
			GameTooltip:Hide()
		end)
		--Bonus Roll Option String
		fontStrings.broString = frames.bonusRollOptionFrame:CreateFontString("broString")
		fontStrings.broString:SetFont("Fonts\\FRIZQT__.ttf", 10)
		fontStrings.broString:SetText("Track bonus rolls")
		fontStrings.broString:SetJustifyH("LEFT")
		fontStrings.broString:SetPoint("CENTER", -50, 0)

		--Play Sound Option Frame
		frames.playSoundOptionFrame = CreateFrame("Frame", "psoFrame", frames.optionsScrollContent)
		frames.playSoundOptionFrame:SetSize(290, 75)
		frames.playSoundOptionFrame:SetPoint("TOPLEFT", 0, -100)
		--Play Sound Option CheckButton
		checkButtons.psoCheckButton = CreateFrame("CheckButton", "psoCheckButton", frames.playSoundOptionFrame, "UICheckButtonTemplate")
		checkButtons.psoCheckButton:SetPoint("CENTER", -110, -2)
		checkButtons.psoCheckButton:SetScript("OnEnter", function(self)
			GameTooltip:SetOwner(self, "ANCHOR_CURSOR");
			GameTooltip:ClearLines()
			GameTooltip:SetText("If checked, the reminder window will play a sound alert")
			GameTooltip:Show()
		end)
		checkButtons.psoCheckButton:SetScript("OnLeave", function(self)
			GameTooltip:Hide()
		end)
		--Play Sound Option String
		fontStrings.psoString = frames.playSoundOptionFrame:CreateFontString("psoString")
		fontStrings.psoString:SetFont("Fonts\\FRIZQT__.ttf", 10)
		fontStrings.psoString:SetText("Play Sound Alert")
		fontStrings.psoString:SetJustifyH("LEFT")
		fontStrings.psoString:SetPoint("CENTER", -51, 0)

		--Whisper Alert Option Frame
		frames.whisperAlertOptionFrame = CreateFrame("Frame", "waoFrame", frames.optionsScrollContent)
		frames.whisperAlertOptionFrame:SetSize(290, 75)
		frames.whisperAlertOptionFrame:SetPoint("TOPLEFT", 0, -155)
		--Whisper Alert Option CheckButton
		checkButtons.waoCheckButton = CreateFrame("CheckButton", "waoCheckButton", frames.whisperAlertOptionFrame, "UICheckButtonTemplate")
		checkButtons.waoCheckButton:SetPoint("CENTER", -110, -2)
		checkButtons.waoCheckButton:SetScript("OnEnter", function(self)
			GameTooltip:SetOwner(self, "ANCHOR_CURSOR");
			GameTooltip:ClearLines()
			GameTooltip:SetText("If checked, RaidR will whisper you if you enter a raid\nwith less than your desired item quantities")
			GameTooltip:Show()
		end)
		checkButtons.waoCheckButton:SetScript("OnLeave", function(self)
			GameTooltip:Hide()
		end)
		--Whisper Alert Option String
		fontStrings.waoString = frames.whisperAlertOptionFrame:CreateFontString("waoString")
		fontStrings.waoString:SetFont("Fonts\\FRIZQT__.ttf", 10)
		fontStrings.waoString:SetText("Whisper on Entering Raid")
		fontStrings.waoString:SetJustifyH("LEFT")
		fontStrings.waoString:SetPoint("CENTER", -29, 0)

		scrollFrames.optionsScrollFrame:SetScrollChild(frames.optionsScrollContent)

		--Options Frame: Previous Button
		buttons.optionsFramePreviousButton = CreateFrame("Button", "OptionsFramePreviousButton", frames.optionsFrame, "UIPanelButtonTemplate")
		buttons.optionsFramePreviousButton:SetSize(100,30)
		buttons.optionsFramePreviousButton:SetPoint("CENTER", -100, -165)
		buttons.optionsFramePreviousButton:SetText("Previous")

		--Options Frame: Next Button
		buttons.optionsFrameNextButton = CreateFrame("Button", "OptionsFrameNextButton", frames.optionsFrame, "UIPanelButtonTemplate")
		buttons.optionsFrameNextButton:SetSize(100,30)
		buttons.optionsFrameNextButton:SetPoint("CENTER", 100, -165)
		buttons.optionsFrameNextButton:SetText("Next")



		--Finalize Frame
		frames.finalizeFrame = CreateFrame("Frame", "FinalizeFrame", frames.RaidRConfig)
		frames.finalizeFrame:SetSize(350,400)
		frames.finalizeFrame:SetPoint("TOPLEFT")
		frames.finalizeFrame:Hide()

		--Finalize Frame: Title String
		fontStrings.finalizeTitleString = frames.finalizeFrame:CreateFontString("FinalizeTitle")
		fontStrings.finalizeTitleString:SetFont("Fonts\\FRIZQT__.ttf", 24, "OUTLINE")
		fontStrings.finalizeTitleString:SetText("And that's it!")
		fontStrings.finalizeTitleString:SetJustifyH("CENTER")
		fontStrings.finalizeTitleString:SetPoint("CENTER", 0, 130)

		--Finalize Frame: Instructions String
		fontStrings.finalizeString = frames.finalizeFrame:CreateFontString("Finalize")
		fontStrings.finalizeString:SetFont("Fonts\\FRIZQT__.ttf", 14, "OUTLINE")
		fontStrings.finalizeString:SetText("Click the button below to save your settings,\nor go back to edit your choices")
		fontStrings.finalizeString:SetJustifyH("CENTER")
		fontStrings.finalizeString:SetPoint("CENTER", 0, 90)

		--Finalize Frame: Next Button
		buttons.finalizeFrameNextButton = CreateFrame("Button", "FinalizeFrameNextButton", frames.finalizeFrame, "UIPanelButtonTemplate")
		buttons.finalizeFrameNextButton:SetSize(100,30)
		buttons.finalizeFrameNextButton:SetPoint("CENTER")
		buttons.finalizeFrameNextButton:SetText("Save my Settings")

		--Finalize Frame: Previous Button
		buttons.finalizeFramePreviousButton = CreateFrame("Button", "FinalizeFramePreviousButton", frames.finalizeFrame, "UIPanelButtonTemplate")
		buttons.finalizeFramePreviousButton:SetSize(100,30)
		buttons.finalizeFramePreviousButton:SetPoint("CENTER", -100, -165)
		buttons.finalizeFramePreviousButton:SetText("Previous")



		local function GreetingNext()
			frames.greetingFrame:Hide()
			frames.flaskFrame:Show()
		end
		buttons.greetingFrameNextButton:SetScript("OnClick", function(self, button)
			GreetingNext()
		end)

		local function GreetingSkip()
		
			if(raidrSetup ~= true) then
				raidrFlasks = {}
				for key, value in pairs(flasks) do
					flaskEditBoxName = "conEditBoxes" .. flasks[key]
					raidrFlasks[key] = editBoxes[flaskEditBoxName]:GetNumber()
				end
				
				raidrPotions = {}
				for key, value in pairs(potions) do
					potionEditBoxName = "conEditBoxes" .. potions[key]
					raidrPotions[key] = editBoxes[potionEditBoxName]:GetNumber()
				end
				
				raidrFood = {}
				for key, value in pairs(food) do
					foodEditBoxName = "conEditBoxes" .. food[key]
					raidrFood[key] = editBoxes[foodEditBoxName]:GetNumber()
				end
				
				raidrMisc = {}
				for key, value in pairs(misc) do
					miscEditBoxName = "conEditBoxes" .. misc[key]
					raidrMisc[key] = editBoxes[miscEditBoxName]:GetNumber()
				end
				
				raidrTimes = {}
				mondayTimeTable = {}
				mondayTimeTable["Active"] = checkButtons.mondayCheckButton:GetChecked()
				mondayTimeTable["Hour"] = mondayHour
				mondayTimeTable["Minute"] = tonumber(mondayMinute)
				mondayTimeTable["AMPM"] = mondayAMPM
				local mondayReminder = TimeDiff(mondayHour, tonumber(mondayMinute), mondayAMPM, reminderTimeValue)
				mondayTimeTable["RemH"] = mondayReminder["Hour"]
				mondayTimeTable["RemM"] = mondayReminder["Minute"]
				mondayTimeTable["RemAMPM"] = mondayReminder["AMPM"]
				tuesdayTimeTable = {}
				tuesdayTimeTable["Active"] = checkButtons.tuesdayCheckButton:GetChecked()
				tuesdayTimeTable["Hour"] = tuesdayHour
				tuesdayTimeTable["Minute"] = tonumber(tuesdayMinute)
				tuesdayTimeTable["AMPM"] = tuesdayAMPM
				local tuesdayReminder = TimeDiff(tuesdayHour, tonumber(tuesdayMinute), tuesdayAMPM, reminderTimeValue)
				tuesdayTimeTable["RemH"] = tuesdayReminder["Hour"]
				tuesdayTimeTable["RemM"] = tuesdayReminder["Minute"]
				tuesdayTimeTable["RemAMPM"] = tuesdayReminder["AMPM"]
				wednesdayTimeTable = {}
				wednesdayTimeTable["Active"] = checkButtons.wednesdayCheckButton:GetChecked()
				wednesdayTimeTable["Hour"] = wednesdayHour
				wednesdayTimeTable["Minute"] = tonumber(wednesdayMinute)
				wednesdayTimeTable["AMPM"] = wednesdayAMPM
				local wednesdayReminder = TimeDiff(wednesdayHour, tonumber(wednesdayMinute), wednesdayAMPM, reminderTimeValue)
				wednesdayTimeTable["RemH"] = wednesdayReminder["Hour"]
				wednesdayTimeTable["RemM"] = wednesdayReminder["Minute"]
				wednesdayTimeTable["RemAMPM"] = wednesdayReminder["AMPM"]
				thursdayTimeTable = {}
				thursdayTimeTable["Active"] = checkButtons.thursdayCheckButton:GetChecked()
				thursdayTimeTable["Hour"] = thursdayHour
				thursdayTimeTable["Minute"] = tonumber(thursdayMinute)
				thursdayTimeTable["AMPM"] = thursdayAMPM
				local thursdayReminder = TimeDiff(thursdayHour, tonumber(thursdayMinute), thursdayAMPM, reminderTimeValue)
				thursdayTimeTable["RemH"] = thursdayReminder["Hour"]
				thursdayTimeTable["RemM"] = thursdayReminder["Minute"]
				thursdayTimeTable["RemAMPM"] = thursdayReminder["AMPM"]
				fridayTimeTable = {}
				fridayTimeTable["Active"] = checkButtons.fridayCheckButton:GetChecked()
				fridayTimeTable["Hour"] = fridayHour
				fridayTimeTable["Minute"] = tonumber(fridayMinute)
				fridayTimeTable["AMPM"] = fridayAMPM
				local fridayReminder = TimeDiff(fridayHour, tonumber(fridayMinute), fridayAMPM, reminderTimeValue)
				fridayTimeTable["RemH"] = fridayReminder["Hour"]
				fridayTimeTable["RemM"] = fridayReminder["Minute"]
				fridayTimeTable["RemAMPM"] = fridayReminder["AMPM"]
				saturdayTimeTable = {}
				saturdayTimeTable["Active"] = checkButtons.saturdayCheckButton:GetChecked()
				saturdayTimeTable["Hour"] = saturdayHour
				saturdayTimeTable["Minute"] = tonumber(saturdayMinute)
				saturdayTimeTable["AMPM"] = saturdayAMPM
				local saturdayReminder = TimeDiff(saturdayHour, tonumber(saturdayMinute), saturdayAMPM, reminderTimeValue)
				saturdayTimeTable["RemH"] = saturdayReminder["Hour"]
				saturdayTimeTable["RemM"] = saturdayReminder["Minute"]
				saturdayTimeTable["RemAMPM"] = saturdayReminder["AMPM"]
				sundayTimeTable = {}
				sundayTimeTable["Active"] = checkButtons.sundayCheckButton:GetChecked()
				sundayTimeTable["Hour"] = sundayHour
				sundayTimeTable["Minute"] = tonumber(sundayMinute)
				sundayTimeTable["AMPM"] = sundayAMPM
				local sundayReminder = TimeDiff(sundayHour, tonumber(sundayMinute), sundayAMPM, reminderTimeValue)
				sundayTimeTable["RemH"] = sundayReminder["Hour"]
				sundayTimeTable["RemM"] = sundayReminder["Minute"]
				sundayTimeTable["RemAMPM"] = sundayReminder["AMPM"]
				
				raidrOptions = {}
				raidrOptions["Seals"] = checkButtons.broCheckButton:GetChecked()
				raidrOptions["PlaySound"] = checkButtons.psoCheckButton:GetChecked()
				raidrOptions["OnEnterWhisper"] = checkButtons.waoCheckButton:GetChecked()
				
				raidrTimes["Monday"] = mondayTimeTable
				raidrTimes["Tuesday"] = tuesdayTimeTable
				raidrTimes["Wednesday"] = wednesdayTimeTable
				raidrTimes["Thursday"] = thursdayTimeTable
				raidrTimes["Friday"] = fridayTimeTable
				raidrTimes["Saturday"] = saturdayTimeTable
				raidrTimes["Sunday"] = sundayTimeTable
				raidrTimes["ReminderTime"] = reminderTimeValue
			end
			
			frames.RaidRConfig:Hide()
			
			raidrSetup = true
		end
		buttons.greetingFrameSkipButton:SetScript("OnClick", function(self, button)
			GreetingSkip()
		end)

		local function FlaskPrevious()
			frames.flaskFrame:Hide()
			frames.greetingFrame:Show()
		end
		buttons.flaskFramePreviousButton:SetScript("OnClick", function(self, button)
			FlaskPrevious()
		end)

		local function FlaskNext()
			frames.flaskFrame:Hide()
			frames.potionFrame:Show()
		end
		buttons.flaskFrameNextButton:SetScript("OnClick", function(self, button)
			FlaskNext()
		end)

		local function PotionPrevious()
			frames.potionFrame:Hide()
			frames.flaskFrame:Show()
		end
		buttons.potionFramePreviousButton:SetScript("OnClick", function(self, button)
			PotionPrevious()
		end)

		local function PotionNext()
			frames.potionFrame:Hide()
			frames.foodFrame:Show()
		end
		buttons.potionFrameNextButton:SetScript("OnClick", function(self, button)
			PotionNext()
		end)

		local function FoodPrevious()
			frames.foodFrame:Hide()
			frames.potionFrame:Show()
		end
		buttons.foodFramePreviousButton:SetScript("OnClick", function(self, button)
			FoodPrevious()
		end)

		local function FoodNext()
			frames.foodFrame:Hide()
			frames.miscFrame:Show()
		end
		buttons.foodFrameNextButton:SetScript("OnClick", function(self, button)
			FoodNext()
		end)

		local function MiscPrevious()
			frames.miscFrame:Hide()
			frames.foodFrame:Show()
		end
		buttons.miscFramePreviousButton:SetScript("OnClick", function(self, button)
			MiscPrevious()
		end)

		local function MiscNext()
			frames.miscFrame:Hide()
			frames.raidTimeFrame:Show()
		end
		buttons.miscFrameNextButton:SetScript("OnClick", function(self, button)
			MiscNext()
		end)

		local function RaidTimePrevious()
			frames.raidTimeFrame:Hide()
			frames.miscFrame:Show()
		end
		buttons.raidTimeFramePreviousButton:SetScript("OnClick", function(self, button)
			RaidTimePrevious()
		end)

		local function RaidTimeNext()
			frames.raidTimeFrame:Hide()
			frames.optionsFrame:Show()
		end
		buttons.raidTimeFrameNextButton:SetScript("OnClick", function(self, button)
			RaidTimeNext()
		end)

		local function OptionsPrevious()
			frames.optionsFrame:Hide()
			frames.raidTimeFrame:Show()
		end
		buttons.optionsFramePreviousButton:SetScript("OnClick", function(self, button)
			OptionsPrevious()
		end)

		local function OptionsNext()
			frames.optionsFrame:Hide()
			frames.finalizeFrame:Show()
		end
		buttons.optionsFrameNextButton:SetScript("OnClick", function(self, button)
			OptionsNext()
		end)

		local function FinalizePrevious()
			frames.finalizeFrame:Hide()
			frames.optionsFrame:Show()
		end
		buttons.finalizeFramePreviousButton:SetScript("OnClick", function(self, button)
			FinalizePrevious()
		end)

		local function FinalizeSave()
			frames.finalizeFrame:Hide()
			raidrFlasks = {}
			for key, value in pairs(flasks) do
				flaskEditBoxName = "conEditBoxes" .. flasks[key]
				raidrFlasks[key] = editBoxes[flaskEditBoxName]:GetNumber()
			end
			
			raidrPotions = {}
			for key, value in pairs(potions) do
				potionEditBoxName = "conEditBoxes" .. potions[key]
				raidrPotions[key] = editBoxes[potionEditBoxName]:GetNumber()
			end
			
			raidrFood = {}
			for key, value in pairs(food) do
				foodEditBoxName = "conEditBoxes" .. food[key]
				raidrFood[key] = editBoxes[foodEditBoxName]:GetNumber()
			end
			
			raidrMisc = {}
			for key, value in pairs(misc) do
				miscEditBoxName = "conEditBoxes" .. misc[key]
				raidrMisc[key] = editBoxes[miscEditBoxName]:GetNumber()
			end
			
			raidrTimes = {}
			mondayTimeTable = {}
			mondayTimeTable["Active"] = checkButtons.mondayCheckButton:GetChecked()
			mondayTimeTable["Hour"] = mondayHour
			mondayTimeTable["Minute"] = tonumber(mondayMinute)
			mondayTimeTable["AMPM"] = mondayAMPM
			local mondayReminder = TimeDiff(mondayHour, tonumber(mondayMinute), mondayAMPM, reminderTimeValue)
			mondayTimeTable["RemH"] = mondayReminder["Hour"]
			mondayTimeTable["RemM"] = mondayReminder["Minute"]
			mondayTimeTable["RemAMPM"] = mondayReminder["AMPM"]
			tuesdayTimeTable = {}
			tuesdayTimeTable["Active"] = checkButtons.tuesdayCheckButton:GetChecked()
			tuesdayTimeTable["Hour"] = tuesdayHour
			tuesdayTimeTable["Minute"] = tonumber(tuesdayMinute)
			tuesdayTimeTable["AMPM"] = tuesdayAMPM
			local tuesdayReminder = TimeDiff(tuesdayHour, tonumber(tuesdayMinute), tuesdayAMPM, reminderTimeValue)
			tuesdayTimeTable["RemH"] = tuesdayReminder["Hour"]
			tuesdayTimeTable["RemM"] = tuesdayReminder["Minute"]
			tuesdayTimeTable["RemAMPM"] = tuesdayReminder["AMPM"]
			wednesdayTimeTable = {}
			wednesdayTimeTable["Active"] = checkButtons.wednesdayCheckButton:GetChecked()
			wednesdayTimeTable["Hour"] = wednesdayHour
			wednesdayTimeTable["Minute"] = tonumber(wednesdayMinute)
			wednesdayTimeTable["AMPM"] = wednesdayAMPM
			local wednesdayReminder = TimeDiff(wednesdayHour, tonumber(wednesdayMinute), wednesdayAMPM, reminderTimeValue)
			wednesdayTimeTable["RemH"] = wednesdayReminder["Hour"]
			wednesdayTimeTable["RemM"] = wednesdayReminder["Minute"]
			wednesdayTimeTable["RemAMPM"] = wednesdayReminder["AMPM"]
			thursdayTimeTable = {}
			thursdayTimeTable["Active"] = checkButtons.thursdayCheckButton:GetChecked()
			thursdayTimeTable["Hour"] = thursdayHour
			thursdayTimeTable["Minute"] = tonumber(thursdayMinute)
			thursdayTimeTable["AMPM"] = thursdayAMPM
			local thursdayReminder = TimeDiff(thursdayHour, tonumber(thursdayMinute), thursdayAMPM, reminderTimeValue)
			thursdayTimeTable["RemH"] = thursdayReminder["Hour"]
			thursdayTimeTable["RemM"] = thursdayReminder["Minute"]
			thursdayTimeTable["RemAMPM"] = thursdayReminder["AMPM"]
			fridayTimeTable = {}
			fridayTimeTable["Active"] = checkButtons.fridayCheckButton:GetChecked()
			fridayTimeTable["Hour"] = fridayHour
			fridayTimeTable["Minute"] = tonumber(fridayMinute)
			fridayTimeTable["AMPM"] = fridayAMPM
			local fridayReminder = TimeDiff(fridayHour, tonumber(fridayMinute), fridayAMPM, reminderTimeValue)
			fridayTimeTable["RemH"] = fridayReminder["Hour"]
			fridayTimeTable["RemM"] = fridayReminder["Minute"]
			fridayTimeTable["RemAMPM"] = fridayReminder["AMPM"]
			saturdayTimeTable = {}
			saturdayTimeTable["Active"] = checkButtons.saturdayCheckButton:GetChecked()
			saturdayTimeTable["Hour"] = saturdayHour
			saturdayTimeTable["Minute"] = tonumber(saturdayMinute)
			saturdayTimeTable["AMPM"] = saturdayAMPM
			local saturdayReminder = TimeDiff(saturdayHour, tonumber(saturdayMinute), saturdayAMPM, reminderTimeValue)
			saturdayTimeTable["RemH"] = saturdayReminder["Hour"]
			saturdayTimeTable["RemM"] = saturdayReminder["Minute"]
			saturdayTimeTable["RemAMPM"] = saturdayReminder["AMPM"]
			sundayTimeTable = {}
			sundayTimeTable["Active"] = checkButtons.sundayCheckButton:GetChecked()
			sundayTimeTable["Hour"] = sundayHour
			sundayTimeTable["Minute"] = tonumber(sundayMinute)
			sundayTimeTable["AMPM"] = sundayAMPM
			local sundayReminder = TimeDiff(sundayHour, tonumber(sundayMinute), sundayAMPM, reminderTimeValue)
			sundayTimeTable["RemH"] = sundayReminder["Hour"]
			sundayTimeTable["RemM"] = sundayReminder["Minute"]
			sundayTimeTable["RemAMPM"] = sundayReminder["AMPM"]
			
			raidrOptions = {}
			raidrOptions["Seals"] = checkButtons.broCheckButton:GetChecked()
			raidrOptions["PlaySound"] = checkButtons.psoCheckButton:GetChecked()
			raidrOptions["OnEnterWhisper"] = checkButtons.waoCheckButton:GetChecked()
			
			raidrTimes["Monday"] = mondayTimeTable
			raidrTimes["Tuesday"] = tuesdayTimeTable
			raidrTimes["Wednesday"] = wednesdayTimeTable
			raidrTimes["Thursday"] = thursdayTimeTable
			raidrTimes["Friday"] = fridayTimeTable
			raidrTimes["Saturday"] = saturdayTimeTable
			raidrTimes["Sunday"] = sundayTimeTable
			raidrTimes["ReminderTime"] = reminderTimeValue
			
			frames.RaidRConfig:Hide()
			
			raidrSetup = true
		end
		buttons.finalizeFrameNextButton:SetScript("OnClick", function(self, button)
			FinalizeSave()
		end)
		
		configCreated = true
	elseif(frames.RaidRReminder:IsVisible() == false and configCreated == true) then
		frames.RaidRConfig:Show()
		frames.greetingFrame:Show()
	end
end

--Runs the reminder window
local function RunReminder()
	if((raidrSetup == true) and (frames.RaidRConfig:IsVisible() == false) and (raidrRemind == true or raidrRemind == nil)) then
		frames.RaidRReminder = CreateFrame("Frame", "RaidRReminderFrame", UIParent)

		--Setup reminder frame
		frames.RaidRReminder:SetBackdrop({
			bgFile="Interface\\DialogFrame\\UI-DialogBox-Background", 
			edgeFile="Interface\\DialogFrame\\UI-DialogBox-Border", 
			tile=1, tileSize=32, edgeSize=32, 
			insets={left=11, right=12, top=12, bottom=11}
		})
		frames.RaidRReminder:SetSize(350, 400)
		frames.RaidRReminder:SetPoint("CENTER", 500, 0)
		frames.RaidRReminder:EnableMouse(true)
		frames.RaidRReminder:SetMovable(true)
		frames.RaidRReminder:RegisterForDrag("LeftButton")
		frames.RaidRReminder:SetScript("OnDragStart", function(self) self:StartMoving() end)
		frames.RaidRReminder:SetScript("OnDragStop", function(self) self:StopMovingOrSizing() end)
		frames.RaidRReminder:Show()
		
		
		
		--Item Display Frame
		frames.itemDisplayFrame = CreateFrame("Frame", "ItemDisplayFrame", frames.RaidRReminder)
		frames.itemDisplayFrame:SetSize(350,400)
		frames.itemDisplayFrame:SetPoint("TOPLEFT")

		--Item Display Frame: String for instructions 1
		fontStrings.itemDisplayString1 = frames.itemDisplayFrame:CreateFontString("ItemDisplayInstructions")
		fontStrings.itemDisplayString1:SetFont("Fonts\\FRIZQT__.ttf", 20, "OUTLINE")
		fontStrings.itemDisplayString1:SetText("It's almost raid time!")
		fontStrings.itemDisplayString1:SetJustifyH("CENTER")
		fontStrings.itemDisplayString1:SetPoint("CENTER", 0, 160)

		--Item Display Frame: String for instructions 2
		fontStrings.itemDisplayString2 = frames.itemDisplayFrame:CreateFontString("ItemDisplayInstructions")
		fontStrings.itemDisplayString2:SetFont("Fonts\\FRIZQT__.ttf", 15, "OUTLINE")
		fontStrings.itemDisplayString2:SetText("Go grab the consumables you don't have!")
		fontStrings.itemDisplayString2:SetJustifyH("CENTER")
		fontStrings.itemDisplayString2:SetPoint("CENTER", 0, 125)

		--Item Display Frame: Frame for making a border
		frames.itemDisplayBorderFrame = CreateFrame("Frame", "ItemDisplayBorderFrame", frames.itemDisplayFrame)
		frames.itemDisplayBorderFrame:SetBackdrop({
			bgFile="Interface\\DialogFrame\\UI-DialogBox-Background", 
			edgeFile="Interface\\DialogFrame\\UI-DialogBox-Border", 
			tile=1, tileSize=32, edgeSize=32, 
			insets={left=11, right=12, top=12, bottom=11}
		})
		frames.itemDisplayBorderFrame:SetPoint("TOPLEFT", 40, -100)
		frames.itemDisplayBorderFrame:SetPoint("BOTTOMRIGHT", -40, 60)

		--Item Display Frame: ScrollFrame for itemDisplay list
		scrollFrames.itemDisplayScrollFrame = CreateFrame("ScrollFrame", "ItemDisplayScrollFrame", frames.itemDisplayBorderFrame, "UIPanelScrollFrameTemplate")
		scrollFrames.itemDisplayScrollFrame:SetPoint("TOPLEFT", 0, -10)
		scrollFrames.itemDisplayScrollFrame:SetPoint("BOTTOMRIGHT", 0, 10)

		--Item Display Frame: Content container for itemDisplay ScrollFrame
		frames.itemDisplayScrollContent = CreateFrame("Frame", "ItemDisplayScrollContent", scrollFrames.itemDisplayScrollFrame)
		
		local fromTop = 10
		
		--Seals Display
		if(raidrOptions["Seals"] == true) then
			local _, __, sealsIcon = GetCurrencyInfo(1273)
			local sealsCount = GetSealsCount()
			--Seals Frame
			frames.sealsFrame = CreateFrame("Frame", "sealsFrame", frames.itemDisplayScrollContent)
			frames.sealsFrame:SetSize(290, 75)
			frames.sealsFrame:SetPoint("TOPLEFT", 0, fromTop)
			--Seals Count FontString
			fontStrings.sealsCountString = frames.sealsFrame:CreateFontString("SealsCountString")
			fontStrings.sealsCountString:SetFont("Fonts\\FRIZQT__.ttf", 10)
			fontStrings.sealsCountString:SetText(sealsCount .. "/" .. 3)
			fontStrings.sealsCountString:SetJustifyH("LEFT")
			fontStrings.sealsCountString:SetPoint("CENTER", -110, 0)
			if(sealsCount < 3) then
				fontStrings.sealsCountString:SetTextColor(1, 0, 0, 1)
			else
				fontStrings.sealsCountString:SetTextColor(0, 1, 0, 1)
			end
			--Seals Item Icon
			buttons.sealsItemIcon = CreateFrame("Button", "buttons.sealsItemIcon", frames.sealsFrame)
			buttons.sealsItemIcon:SetSize(40,40)
			buttons.sealsItemIcon:SetPoint("CENTER", -66, 0)
			buttons.sealsItemIcon:SetNormalTexture(sealsIcon)
			buttons.sealsItemIcon:SetScript("OnEnter", function(self)
				GameTooltip:SetOwner(self, "ANCHOR_CURSOR");
				GameTooltip:ClearLines()
				GameTooltip:SetCurrencyByID(1273)
				GameTooltip:Show()
			end)
			buttons.sealsItemIcon:SetScript("OnLeave", function(self)
				GameTooltip:Hide()
			end)
			--Seals Name
			fontStrings.sealsString = frames.sealsFrame:CreateFontString("sealsName")
			fontStrings.sealsString:SetFont("Fonts\\FRIZQT__.ttf", 10)
			fontStrings.sealsString:SetText("Seal of Broken Fate")
			fontStrings.sealsString:SetJustifyH("LEFT")
			fontStrings.sealsString:SetPoint("CENTER", 30, 0)
			
			fromTop = fromTop - 55
		end
		
		--Flask Display
		for key, value in pairs(raidrFlasks) do
			if(value ~= 0 and value ~= nil) then
				--Entry Frame
				flaskFrameName = "remFrame" .. flasks[key]
				frames[flaskFrameName] = CreateFrame("Frame", flaskFrameName, frames.itemDisplayScrollContent)
				frames[flaskFrameName]:SetSize(290, 75)
				frames[flaskFrameName]:SetPoint("TOPLEFT", 0, fromTop)
				--Entry Count FontString
				flaskCountStringName = "remFontString" .. flasks[key]
				fontStrings[flaskCountStringName] = frames[flaskFrameName]:CreateFontString(flaskCountStringName)
				fontStrings[flaskCountStringName]:SetFont("Fonts\\FRIZQT__.ttf", 10)
				fontStrings[flaskCountStringName]:SetText(GetItemCount(flasks[key]) .. "/" .. value)
				fontStrings[flaskCountStringName]:SetJustifyH("LEFT")
				fontStrings[flaskCountStringName]:SetPoint("CENTER", -110, 0)
				if(GetItemCount(flasks[key]) < value) then
					fontStrings[flaskCountStringName]:SetTextColor(1, 0, 0, 1)
				else
					fontStrings[flaskCountStringName]:SetTextColor(0, 1, 0, 1)
				end
				--Entry Item Icon
				flaskItemIconName = "remItemIcon" .. flasks[key]
				buttons[flaskItemIconName] = CreateFrame("Button", flaskItemIconName, frames[flaskFrameName])
				buttons[flaskItemIconName]:SetSize(40,40)
				buttons[flaskItemIconName]:SetPoint("CENTER", -65, 0)
				buttons[flaskItemIconName]:SetNormalTexture(GetItemIcon(flasks[key]))
				buttons[flaskItemIconName]:SetScript("OnEnter", function(self)
					GameTooltip:SetOwner(self, "ANCHOR_CURSOR")
					GameTooltip:ClearLines()
					GameTooltip:SetItemByID(flasks[key])
					GameTooltip:Show()
				end)
				buttons[flaskItemIconName]:SetScript("OnLeave", function(self)
					GameTooltip:Hide()
				end)
				--Entry Name
				flaskNameStringName = "remNameString" .. flasks[key]
				fontStrings[flaskNameStringName] = frames[flaskFrameName]:CreateFontString(flaskNameStringName)
				fontStrings[flaskNameStringName]:SetFont("Fonts\\FRIZQT__.ttf", 10)
				fontStrings[flaskNameStringName]:SetText(key)
				fontStrings[flaskNameStringName]:SetJustifyH("LEFT")
				fontStrings[flaskNameStringName]:SetPoint("CENTER", 35, 0)
				
				fromTop = fromTop - 55
			end
		end
		
		--Potion Display
		for key, value in pairs(raidrPotions) do
			if(value ~= 0 and value ~= nil) then
				--Entry Frame
				potionFrameName = "remFrame" .. potions[key]
				frames[potionFrameName] = CreateFrame("Frame", potionFrameName, frames.itemDisplayScrollContent)
				frames[potionFrameName]:SetSize(290, 75)
				frames[potionFrameName]:SetPoint("TOPLEFT", 0, fromTop)
				--Entry Count FontString
				potionCountStringName = "remFontString" .. potions[key]
				fontStrings[potionCountStringName] = frames[potionFrameName]:CreateFontString(potionCountStringName)
				fontStrings[potionCountStringName]:SetFont("Fonts\\FRIZQT__.ttf", 10)
				fontStrings[potionCountStringName]:SetText(GetItemCount(potions[key]) .. "/" .. value)
				fontStrings[potionCountStringName]:SetJustifyH("LEFT")
				fontStrings[potionCountStringName]:SetPoint("CENTER", -110, 0)
				if(GetItemCount(potions[key]) < value) then
					fontStrings[potionCountStringName]:SetTextColor(1, 0, 0, 1)
				else
					fontStrings[potionCountStringName]:SetTextColor(0, 1, 0, 1)
				end
				--Entry Item Icon
				potionItemIconName = "remItemIcon" .. potions[key]
				buttons[potionItemIconName] = CreateFrame("Button", potionItemIconName, frames[potionFrameName])
				buttons[potionItemIconName]:SetSize(40,40)
				buttons[potionItemIconName]:SetPoint("CENTER", -65, 0)
				buttons[potionItemIconName]:SetNormalTexture(GetItemIcon(potions[key]))
				buttons[potionItemIconName]:SetScript("OnEnter", function(self)
					GameTooltip:SetOwner(self, "ANCHOR_CURSOR")
					GameTooltip:ClearLines()
					GameTooltip:SetItemByID(potions[key])
					GameTooltip:Show()
				end)
				buttons[potionItemIconName]:SetScript("OnLeave", function(self)
					GameTooltip:Hide()
				end)
				--Entry Name
				potionNameStringName = "remNameString" .. potions[key]
				fontStrings[potionNameStringName] = frames[potionFrameName]:CreateFontString(potionNameStringName)
				fontStrings[potionNameStringName]:SetFont("Fonts\\FRIZQT__.ttf", 10)
				fontStrings[potionNameStringName]:SetText(key)
				fontStrings[potionNameStringName]:SetJustifyH("LEFT")
				fontStrings[potionNameStringName]:SetPoint("CENTER", 35, 0)
				
				fromTop = fromTop - 55
			end
		end
		
		--Food Display
		for key, value in pairs(raidrFood) do
			if(value ~= 0 and value ~= nil) then
				--Entry Frame
				foodFrameName = "remFrame" .. food[key]
				frames[foodFrameName] = CreateFrame("Frame", foodFrameName, frames.itemDisplayScrollContent)
				frames[foodFrameName]:SetSize(290, 75)
				frames[foodFrameName]:SetPoint("TOPLEFT", 0, fromTop)
				--Entry Count FontString
				foodCountStringName = "remFontString" .. food[key]
				fontStrings[foodCountStringName] = frames[foodFrameName]:CreateFontString(foodCountStringName)
				fontStrings[foodCountStringName]:SetFont("Fonts\\FRIZQT__.ttf", 10)
				fontStrings[foodCountStringName]:SetText(GetItemCount(food[key]) .. "/" .. value)
				fontStrings[foodCountStringName]:SetJustifyH("LEFT")
				fontStrings[foodCountStringName]:SetPoint("CENTER", -110, 0)
				if(GetItemCount(food[key]) < value) then
					fontStrings[foodCountStringName]:SetTextColor(1, 0, 0, 1)
				else
					fontStrings[foodCountStringName]:SetTextColor(0, 1, 0, 1)
				end
				--Entry Item Icon
				foodItemIconName = "remItemIcon" .. food[key]
				buttons[foodItemIconName] = CreateFrame("Button", foodItemIconName, frames[foodFrameName])
				buttons[foodItemIconName]:SetSize(40,40)
				buttons[foodItemIconName]:SetPoint("CENTER", -65, 0)
				buttons[foodItemIconName]:SetNormalTexture(GetItemIcon(food[key]))
				buttons[foodItemIconName]:SetScript("OnEnter", function(self)
					GameTooltip:SetOwner(self, "ANCHOR_CURSOR")
					GameTooltip:ClearLines()
					GameTooltip:SetItemByID(food[key])
					GameTooltip:Show()
				end)
				buttons[foodItemIconName]:SetScript("OnLeave", function(self)
					GameTooltip:Hide()
				end)
				--Entry Name
				foodNameStringName = "remNameString" .. food[key]
				fontStrings[foodNameStringName] = frames[foodFrameName]:CreateFontString(foodNameStringName)
				fontStrings[foodNameStringName]:SetFont("Fonts\\FRIZQT__.ttf", 10)
				fontStrings[foodNameStringName]:SetText(key)
				fontStrings[foodNameStringName]:SetJustifyH("LEFT")
				fontStrings[foodNameStringName]:SetPoint("CENTER", 35, 0)
				
				fromTop = fromTop - 55
			end
		end
		
		--Misc Display
		for key, value in pairs(raidrMisc) do
			if(value ~= 0 and value ~= nil) then
				--Entry Frame
				miscFrameName = "remFrame" .. misc[key]
				frames[miscFrameName] = CreateFrame("Frame", miscFrameName, frames.itemDisplayScrollContent)
				frames[miscFrameName]:SetSize(290, 75)
				frames[miscFrameName]:SetPoint("TOPLEFT", 0, fromTop)
				--Entry Count FontString
				miscCountStringName = "remFontString" .. misc[key]
				fontStrings[miscCountStringName] = frames[miscFrameName]:CreateFontString(miscCountStringName)
				fontStrings[miscCountStringName]:SetFont("Fonts\\FRIZQT__.ttf", 10)
				fontStrings[miscCountStringName]:SetText(GetItemCount(misc[key]) .. "/" .. value)
				fontStrings[miscCountStringName]:SetJustifyH("LEFT")
				fontStrings[miscCountStringName]:SetPoint("CENTER", -110, 0)
				if(GetItemCount(misc[key]) < value) then
					fontStrings[miscCountStringName]:SetTextColor(1, 0, 0, 1)
				else
					fontStrings[miscCountStringName]:SetTextColor(0, 1, 0, 1)
				end
				--Entry Item Icon
				miscItemIconName = "remItemIcon" .. misc[key]
				buttons[miscItemIconName] = CreateFrame("Button", miscItemIconName, frames[miscFrameName])
				buttons[miscItemIconName]:SetSize(40,40)
				buttons[miscItemIconName]:SetPoint("CENTER", -65, 0)
				buttons[miscItemIconName]:SetNormalTexture(GetItemIcon(misc[key]))
				buttons[miscItemIconName]:SetScript("OnEnter", function(self)
					GameTooltip:SetOwner(self, "ANCHOR_CURSOR")
					GameTooltip:ClearLines()
					GameTooltip:SetItemByID(misc[key])
					GameTooltip:Show()
				end)
				buttons[miscItemIconName]:SetScript("OnLeave", function(self)
					GameTooltip:Hide()
				end)
				--Entry Name
				miscNameStringName = "remNameString" .. misc[key]
				fontStrings[miscNameStringName] = frames[miscFrameName]:CreateFontString(miscNameStringName)
				fontStrings[miscNameStringName]:SetFont("Fonts\\FRIZQT__.ttf", 10)
				fontStrings[miscNameStringName]:SetText(key)
				fontStrings[miscNameStringName]:SetJustifyH("LEFT")
				fontStrings[miscNameStringName]:SetPoint("CENTER", 35, 0)
				
				fromTop = fromTop - 55
			end
		end
		
		fromTop = (fromTop + 45) * -1
		frames.itemDisplayScrollContent:SetSize(290, fromTop)
		scrollFrames.itemDisplayScrollFrame:SetScrollChild(frames.itemDisplayScrollContent)
		
		--Updates the count of each consumable whenever the inventory changes
		frames.itemDisplayFrame:SetScript("OnEvent", function(self,event)
			if(event == "BAG_UPDATE" or event == "CHAT_MSG_CURRENCY") then
				if(raidrOptions["Seals"] == true) then
				sealsCount = GetSealsCount()
					fontStrings.sealsCountString:SetText(sealsCount .. "/" .. 3)
					if(sealsCount < 3) then
						fontStrings.sealsCountString:SetTextColor(1, 0, 0, 1)
					else
						fontStrings.sealsCountString:SetTextColor(0, 1, 0, 1)
					end
				end
				for key, value in pairs(raidrFlasks) do
					if(value ~= 0 and value ~= nil) then
						fontStrings[flaskCountStringName]:SetText(GetItemCount(flasks[key]) .. "/" .. value)
						if(GetItemCount(flasks[key]) < value) then
							fontStrings[flaskCountStringName]:SetTextColor(1, 0, 0, 1)
						else
							fontStrings[flaskCountStringName]:SetTextColor(0, 1, 0, 1)
						end
					end
				end
				for key, value in pairs(raidrPotions) do
					if(value ~= 0 and value ~= nil) then
						fontStrings[potionCountStringName]:SetText(GetItemCount(potions[key]) .. "/" .. value)
						if(GetItemCount(potions[key]) < value) then
							fontStrings[potionCountStringName]:SetTextColor(1, 0, 0, 1)
						else
							fontStrings[potionCountStringName]:SetTextColor(0, 1, 0, 1)
						end
					end
				end
				for key, value in pairs(raidrFood) do
					if(value ~= 0 and value ~= nil) then
						fontStrings[foodCountStringName]:SetText(GetItemCount(food[key]) .. "/" .. value)
						if(GetItemCount(food[key]) < value) then
							fontStrings[foodCountStringName]:SetTextColor(1, 0, 0, 1)
						else
							fontStrings[foodCountStringName]:SetTextColor(0, 1, 0, 1)
						end
					end
				end
				for key, value in pairs(raidrMisc) do
					if(value ~= 0 and value ~= nil) then
						fontStrings[miscCountStringName]:SetText(GetItemCount(misc[key]) .. "/" .. value)
						if(GetItemCount(misc[key]) < value) then
							fontStrings[miscCountStringName]:SetTextColor(1, 0, 0, 1)
						else
							fontStrings[miscCountStringName]:SetTextColor(0, 1, 0, 1)
						end
					end
				end
			end
		end)
		frames.itemDisplayFrame:RegisterEvent("BAG_UPDATE")
		frames.itemDisplayFrame:RegisterEvent("CHAT_MSG_CURRENCY")
		
		--Item Display Frame: Remind Me Later
		buttons.itemDisplayRemindButton = CreateFrame("Button", "itemDisplayRemindButton", frames.itemDisplayFrame, "UIPanelButtonTemplate")
		buttons.itemDisplayRemindButton:SetSize(100,30)
		buttons.itemDisplayRemindButton:SetPoint("CENTER", -100, -165)
		buttons.itemDisplayRemindButton:SetText("Remind Me Later")

		--Item Display Frame: Close Button
		buttons.itemDisplayFrameCloseButton = CreateFrame("Button", "ItemDisplayFrameCloseButton", frames.itemDisplayFrame, "UIPanelButtonTemplate")
		buttons.itemDisplayFrameCloseButton:SetSize(100,30)
		buttons.itemDisplayFrameCloseButton:SetPoint("CENTER", 100, -165)
		buttons.itemDisplayFrameCloseButton:SetText("Close")
		
		local function ReminderFrameRemindMeLater()
			raidrRemind = true
			frames.RaidRReminder:Hide()
		end
		buttons.itemDisplayRemindButton:SetScript("OnClick", function(self, button)
			ReminderFrameRemindMeLater()
		end)
		
		local function ReminderFrameClose()
			raidrRemind = false
			frames.RaidRReminder:Hide()
		end
		buttons.itemDisplayFrameCloseButton:SetScript("OnClick", function(self, button)
			ReminderFrameClose()
		end)
	end
end

--Checks if the current time is within range for a reminder to fire
local function ReminderCheck()
	local thisHour, raidHour
	local thisDate = date("*t")
	if(raidrTimes[today]["RemAMPM"] == "PM") then 
		thisHour = 12 + raidrTimes[today]["RemH"]
	else
		thisHour = raidTimes[today]["RemH"]
	end
	if(raidrTimes[today]["AMPM"] == "PM") then 
		raidHour = 12 + raidrTimes[today]["Hour"]
	else
		raidHour = raidTimes[today]["Hour"]
	end
	if((thisDate.hour == thisHour and thisDate.min >= raidrTimes[today]["RemM"]) and (thisDate.hour == raidHour) and thisDate.min < raidrTimes[today]["Minute"]) then
		if(raidrOptions["PlaySound"] and frames.RaidRReminder:IsVisible() == false and raidrRemind == true) then
			PlaySound(8960)
		end
		RunReminder()
	end
end

--Checks to see if there is a raid today
local function RaidDayCheck()
	if(today ~= GetDay()) then
		today = GetDay()
		raidrRemind = true
	end
	if(raidrTimes ~= nil) then 
		for day, dayTable in pairs(raidrTimes) do
			if((day == today) and (dayTable["Active"] == true)) then
				return true
			end
		end
	end
	return false
end

--Runs ReminderCheck() every five minutes
local timer = 300
local function onUpdate(self,elapsed)
    timer = timer + elapsed
    if timer >= 300 then
		timer = 0
		if(RaidDayCheck()) then
			ReminderCheck()
		end
    end
end

--Runs the loop that checks the time and runs a reminder when it's time for one
local function RunReminderLoop()
	local loopFrame = CreateFrame("Frame")
	loopFrame:SetScript("OnUpdate", onUpdate)
end

local function RegisterInterfaceOptionsPanel()
	RaidR = {}
	RaidR.panel = CreateFrame("Frame", "RaidRPanel", UIParent)
	RaidR.panel.name = "RaidR"
	InterfaceOptions_AddCategory(RaidR.panel)
	
	--Interface Options Frame 1
	frames.intOpt1Frame = CreateFrame("Frame", "IntOptFrame", RaidR.panel)
	frames.intOpt1Frame:SetPoint("TOPLEFT")
	frames.intOpt1Frame:SetPoint("BOTTOMRIGHT")

	--Interface Options Frame 1: Frame for making a border
	frames.intOpt1BorderFrame = CreateFrame("Frame", "IntOptBorderFrame", frames.intOpt1Frame)
	frames.intOpt1BorderFrame:SetBackdrop({
		bgFile="Interface\\DialogFrame\\UI-Tooltip-Background", 
		edgeFile="Interface\\DialogFrame\\UI-Tooltip-Border", 
		tile=1, tileSize=32, edgeSize=1, 
		insets={left=0, right=0, top=0, bottom=0}
	})
	frames.intOpt1BorderFrame:SetBackdropColor(0,0,0,0.2)
	frames.intOpt1BorderFrame:SetBackdropBorderColor(0,0,0,1)
	frames.intOpt1BorderFrame:SetPoint("TOPLEFT", 10, -10)
	frames.intOpt1BorderFrame:SetPoint("BOTTOMRIGHT", -300, 10)

	--Interface Options Frame 1: ScrollFrame for intOpt list
	scrollFrames.intOpt1ScrollFrame = CreateFrame("ScrollFrame", "IntOptScrollFrame", frames.intOpt1BorderFrame, "UIPanelScrollFrameTemplate")
	scrollFrames.intOpt1ScrollFrame:SetBackdrop({
		bgFile="Interface\\DialogFrame\\UI-Tooltip-Background", 
		edgeFile="Interface\\DialogFrame\\UI-Tooltip-Border", 
		tile=1, tileSize=32, edgeSize=1, 
		insets={left=0, right=0, top=0, bottom=0}
	})
	scrollFrames.intOpt1ScrollFrame:SetBackdropColor(0,0,0,0)
	scrollFrames.intOpt1ScrollFrame:SetBackdropBorderColor(0,0,0,1)
	scrollFrames.intOpt1ScrollFrame:SetPoint("TOPLEFT", 10, -10)
	scrollFrames.intOpt1ScrollFrame:SetPoint("BOTTOMRIGHT", -30, 10)

	--Interface Options Frame: Content container for intOpt ScrollFrame
	frames.intOpt1ScrollContent = CreateFrame("Frame", "IntOptScrollContent", scrollFrames.intOpt1ScrollFrame)
	
	local fromTop = 10
	
	--Flask Display
	for key, value in pairs(flasks) do
		if(value ~= 0 and value ~= nil) then
			--Entry Frame
			flaskFrameName = "intOptFrame" .. flasks[key]
			frames[flaskFrameName] = CreateFrame("Frame", flaskFrameName, frames.intOpt1ScrollContent)
			frames[flaskFrameName]:SetSize(290, 75)
			frames[flaskFrameName]:SetPoint("TOPLEFT", 0, fromTop)
			--Entry EditBox
			flaskEditBoxName = "intOptEditBoxes" .. flasks[key]
			editBoxes[flaskEditBoxName] = CreateFrame("EditBox", flaskEditBoxName, frames[flaskFrameName], "InputBoxTemplate")
			editBoxes[flaskEditBoxName]:SetAutoFocus(false)
			editBoxes[flaskEditBoxName]:SetSize(25,30)
			editBoxes[flaskEditBoxName]:SetPoint("CENTER", -110, 0)
			editBoxes[flaskEditBoxName]:SetNumeric(true)
			editBoxes[flaskEditBoxName]:SetMaxLetters(3)
			if(raidrFlasks ~= nil and raidrFlasks[key] ~= nil) then
				editBoxes[flaskEditBoxName]:SetText(raidrFlasks[key])
			else
				editBoxes[flaskEditBoxName]:SetText("0")
			end
			editBoxes[flaskEditBoxName]:SetCursorPosition(0)
			editBoxes[flaskEditBoxName]:SetJustifyH("LEFT")
			editBoxes[flaskEditBoxName]:SetScript("OnEnterPressed",function(s)
				s:ClearFocus()
			end)
			editBoxes[flaskEditBoxName]:SetScript("OnEditFocusLost",function(s)
				if(s:GetText() == "") then
					s:SetNumber(0)
				end
			end)
			--Entry Item Icon
			flaskItemIconName = "intOptItemIcon" .. flasks[key]
			buttons[flaskItemIconName] = CreateFrame("Button", flaskItemIconName, frames[flaskFrameName])
			buttons[flaskItemIconName]:SetSize(40,40)
			buttons[flaskItemIconName]:SetPoint("CENTER", -65, 0)
			buttons[flaskItemIconName]:SetNormalTexture(GetItemIcon(flasks[key]))
			buttons[flaskItemIconName]:SetScript("OnEnter", function(self)
				GameTooltip:SetOwner(self, "ANCHOR_CURSOR")
				GameTooltip:ClearLines()
				GameTooltip:SetItemByID(flasks[key])
				GameTooltip:Show()
			end)
			buttons[flaskItemIconName]:SetScript("OnLeave", function(self)
				GameTooltip:Hide()
			end)
			--Entry Name
			flaskNameStringName = "intOptNameString" .. flasks[key]
			fontStrings[flaskNameStringName] = frames[flaskFrameName]:CreateFontString(flaskNameStringName)
			fontStrings[flaskNameStringName]:SetFont("Fonts\\FRIZQT__.ttf", 10)
			fontStrings[flaskNameStringName]:SetText(key)
			fontStrings[flaskNameStringName]:SetJustifyH("LEFT")
			fontStrings[flaskNameStringName]:SetPoint("CENTER", 35, 0)
			
			fromTop = fromTop - 55
		end
	end
	
	--Potion Display
	for key, value in pairs(potions) do
		if(value ~= 0 and value ~= nil) then
			--Entry Frame
			potionFrameName = "intOptFrame" .. potions[key]
			frames[potionFrameName] = CreateFrame("Frame", potionFrameName, frames.intOpt1ScrollContent)
			frames[potionFrameName]:SetSize(290, 75)
			frames[potionFrameName]:SetPoint("TOPLEFT", 0, fromTop)
			--Entry EditBox
			potionEditBoxName = "intOptEditBoxes" .. potions[key]
			editBoxes[potionEditBoxName] = CreateFrame("EditBox", potionEditBoxName, frames[potionFrameName], "InputBoxTemplate")
			editBoxes[potionEditBoxName]:SetAutoFocus(false)
			editBoxes[potionEditBoxName]:SetSize(25,30)
			editBoxes[potionEditBoxName]:SetPoint("CENTER", -110, 0)
			editBoxes[potionEditBoxName]:SetNumeric(true)
			editBoxes[potionEditBoxName]:SetMaxLetters(3)
			if(raidrPotions ~= nil and raidrPotions[key] ~= nil) then
				editBoxes[potionEditBoxName]:SetText(raidrPotions[key])
			else
				editBoxes[potionEditBoxName]:SetText("0")
			end
			editBoxes[potionEditBoxName]:SetCursorPosition(0)
			editBoxes[potionEditBoxName]:SetJustifyH("LEFT")
			editBoxes[potionEditBoxName]:SetScript("OnEnterPressed",function(s)
				s:ClearFocus()
			end)
			editBoxes[potionEditBoxName]:SetScript("OnEditFocusLost",function(s)
				if(s:GetText() == "") then
					s:SetNumber(0)
				end
			end)
			--Entry Item Icon
			potionItemIconName = "intOptItemIcon" .. potions[key]
			buttons[potionItemIconName] = CreateFrame("Button", potionItemIconName, frames[potionFrameName])
			buttons[potionItemIconName]:SetSize(40,40)
			buttons[potionItemIconName]:SetPoint("CENTER", -65, 0)
			buttons[potionItemIconName]:SetNormalTexture(GetItemIcon(potions[key]))
			buttons[potionItemIconName]:SetScript("OnEnter", function(self)
				GameTooltip:SetOwner(self, "ANCHOR_CURSOR")
				GameTooltip:ClearLines()
				GameTooltip:SetItemByID(potions[key])
				GameTooltip:Show()
			end)
			buttons[potionItemIconName]:SetScript("OnLeave", function(self)
				GameTooltip:Hide()
			end)
			--Entry Name
			potionNameStringName = "intOptNameString" .. potions[key]
			fontStrings[potionNameStringName] = frames[potionFrameName]:CreateFontString(potionNameStringName)
			fontStrings[potionNameStringName]:SetFont("Fonts\\FRIZQT__.ttf", 10)
			fontStrings[potionNameStringName]:SetText(key)
			fontStrings[potionNameStringName]:SetJustifyH("LEFT")
			fontStrings[potionNameStringName]:SetPoint("CENTER", 35, 0)
			
			fromTop = fromTop - 55
		end
	end
	
	--Food Display
	for key, value in pairs(food) do
		if(value ~= 0 and value ~= nil) then
			--Entry Frame
			foodFrameName = "intOptFrame" .. food[key]
			frames[foodFrameName] = CreateFrame("Frame", foodFrameName, frames.intOpt1ScrollContent)
			frames[foodFrameName]:SetSize(290, 75)
			frames[foodFrameName]:SetPoint("TOPLEFT", 0, fromTop)
			--Entry EditBox
			foodEditBoxName = "intOptEditBoxes" .. food[key]
			editBoxes[foodEditBoxName] = CreateFrame("EditBox", foodEditBoxName, frames[foodFrameName], "InputBoxTemplate")
			editBoxes[foodEditBoxName]:SetAutoFocus(false)
			editBoxes[foodEditBoxName]:SetSize(25,30)
			editBoxes[foodEditBoxName]:SetPoint("CENTER", -110, 0)
			editBoxes[foodEditBoxName]:SetNumeric(true)
			editBoxes[foodEditBoxName]:SetMaxLetters(3)
			if(raidrFood ~= nil and raidrFood[key] ~= nil) then
				editBoxes[foodEditBoxName]:SetText(raidrFood[key])
			else
				editBoxes[foodEditBoxName]:SetText("0")
			end
			editBoxes[foodEditBoxName]:SetCursorPosition(0)
			editBoxes[foodEditBoxName]:SetJustifyH("LEFT")
			editBoxes[foodEditBoxName]:SetScript("OnEnterPressed",function(s)
				s:ClearFocus()
			end)
			editBoxes[foodEditBoxName]:SetScript("OnEditFocusLost",function(s)
				if(s:GetText() == "") then
					s:SetNumber(0)
				end
			end)
			--Entry Item Icon
			foodItemIconName = "intOptItemIcon" .. food[key]
			buttons[foodItemIconName] = CreateFrame("Button", foodItemIconName, frames[foodFrameName])
			buttons[foodItemIconName]:SetSize(40,40)
			buttons[foodItemIconName]:SetPoint("CENTER", -65, 0)
			buttons[foodItemIconName]:SetNormalTexture(GetItemIcon(food[key]))
			buttons[foodItemIconName]:SetScript("OnEnter", function(self)
				GameTooltip:SetOwner(self, "ANCHOR_CURSOR")
				GameTooltip:ClearLines()
				GameTooltip:SetItemByID(food[key])
				GameTooltip:Show()
			end)
			buttons[foodItemIconName]:SetScript("OnLeave", function(self)
				GameTooltip:Hide()
			end)
			--Entry Name
			foodNameStringName = "intOptNameString" .. food[key]
			fontStrings[foodNameStringName] = frames[foodFrameName]:CreateFontString(foodNameStringName)
			fontStrings[foodNameStringName]:SetFont("Fonts\\FRIZQT__.ttf", 10)
			fontStrings[foodNameStringName]:SetText(key)
			fontStrings[foodNameStringName]:SetJustifyH("LEFT")
			fontStrings[foodNameStringName]:SetPoint("CENTER", 35, 0)
			
			fromTop = fromTop - 55
		end
	end
	
	--Misc Display
	for key, value in pairs(misc) do
		if(value ~= 0 and value ~= nil) then
			--Entry Frame
			miscFrameName = "intOptFrame" .. misc[key]
			frames[miscFrameName] = CreateFrame("Frame", miscFrameName, frames.intOpt1ScrollContent)
			frames[miscFrameName]:SetSize(290, 75)
			frames[miscFrameName]:SetPoint("TOPLEFT", 0, fromTop)
			--Entry EditBox
			miscEditBoxName = "intOptEditBoxes" .. misc[key]
			editBoxes[miscEditBoxName] = CreateFrame("EditBox", miscEditBoxName, frames[miscFrameName], "InputBoxTemplate")
			editBoxes[miscEditBoxName]:SetAutoFocus(false)
			editBoxes[miscEditBoxName]:SetSize(25,30)
			editBoxes[miscEditBoxName]:SetPoint("CENTER", -110, 0)
			editBoxes[miscEditBoxName]:SetNumeric(true)
			editBoxes[miscEditBoxName]:SetMaxLetters(3)
			if(raidrMisc ~= nil and raidrMisc[key] ~= nil) then
				editBoxes[miscEditBoxName]:SetText(raidrMisc[key])
			else
				editBoxes[miscEditBoxName]:SetText("0")
			end
			editBoxes[miscEditBoxName]:SetCursorPosition(0)
			editBoxes[miscEditBoxName]:SetJustifyH("LEFT")
			editBoxes[miscEditBoxName]:SetScript("OnEnterPressed",function(s)
				s:ClearFocus()
			end)
			editBoxes[miscEditBoxName]:SetScript("OnEditFocusLost",function(s)
				if(s:GetText() == "") then
					s:SetNumber(0)
				end
			end)
			--Entry Item Icon
			miscItemIconName = "intOptItemIcon" .. misc[key]
			buttons[miscItemIconName] = CreateFrame("Button", miscItemIconName, frames[miscFrameName])
			buttons[miscItemIconName]:SetSize(40,40)
			buttons[miscItemIconName]:SetPoint("CENTER", -65, 0)
			buttons[miscItemIconName]:SetNormalTexture(GetItemIcon(misc[key]))
			buttons[miscItemIconName]:SetScript("OnEnter", function(self)
				GameTooltip:SetOwner(self, "ANCHOR_CURSOR")
				GameTooltip:ClearLines()
				GameTooltip:SetItemByID(misc[key])
				GameTooltip:Show()
			end)
			buttons[miscItemIconName]:SetScript("OnLeave", function(self)
				GameTooltip:Hide()
			end)
			--Entry Name
			miscNameStringName = "intOptNameString" .. misc[key]
			fontStrings[miscNameStringName] = frames[miscFrameName]:CreateFontString(miscNameStringName)
			fontStrings[miscNameStringName]:SetFont("Fonts\\FRIZQT__.ttf", 10)
			fontStrings[miscNameStringName]:SetText(key)
			fontStrings[miscNameStringName]:SetJustifyH("LEFT")
			fontStrings[miscNameStringName]:SetPoint("CENTER", 35, 0)
			
			fromTop = fromTop - 55
		end
	end
	
	fromTop = (fromTop + 45) * -1
	frames.intOpt1ScrollContent:SetSize(290, fromTop)
	scrollFrames.intOpt1ScrollFrame:SetScrollChild(frames.intOpt1ScrollContent)

	--Interface Options RaidTime Frame
	frames.intOptRaidTimeFrame = CreateFrame("Frame", "intOptRaidTimeFrame", RaidR.panel)
	frames.intOptRaidTimeFrame:SetPoint("TOPRIGHT")
	frames.intOptRaidTimeFrame:SetPoint("BOTTOMLEFT")

	--RaidTime Frame: Frame for making a border
	frames.intOptRaidTimeBorderFrame = CreateFrame("Frame", "intOptRaidTimeBorderFrame", frames.intOptRaidTimeFrame)
	frames.intOptRaidTimeBorderFrame:SetBackdrop({
		bgFile="Interface\\DialogFrame\\UI-Tooltip-Background", 
		edgeFile="Interface\\DialogFrame\\UI-Tooltip-Border", 
		tile=1, tileSize=32, edgeSize=1, 
		insets={left=0, right=0, top=0, bottom=0}
	})
	frames.intOptRaidTimeBorderFrame:SetBackdropColor(0,0,0,0.2)
	frames.intOptRaidTimeBorderFrame:SetBackdropBorderColor(0,0,0,1)
	frames.intOptRaidTimeBorderFrame:SetPoint("TOPRIGHT", -25, -10)
	frames.intOptRaidTimeBorderFrame:SetPoint("BOTTOMLEFT", 350, 250)

	--RaidTime Frame: ScrollFrame for intOptRaidTime list
	scrollFrames.intOptRaidTimeScrollFrame = CreateFrame("ScrollFrame", "intOptRaidTimeScrollFrame", frames.intOptRaidTimeBorderFrame, "UIPanelScrollFrameTemplate")
	scrollFrames.intOptRaidTimeScrollFrame:SetBackdrop({
		bgFile="Interface\\DialogFrame\\UI-Tooltip-Background", 
		edgeFile="Interface\\DialogFrame\\UI-Tooltip-Border", 
		tile=1, tileSize=32, edgeSize=1, 
		insets={left=0, right=0, top=0, bottom=0}
	})
	scrollFrames.intOptRaidTimeScrollFrame:SetBackdropColor(0,0,0,0)
	scrollFrames.intOptRaidTimeScrollFrame:SetBackdropBorderColor(0,0,0,1)
	scrollFrames.intOptRaidTimeScrollFrame:SetPoint("TOPLEFT", 10, -10)
	scrollFrames.intOptRaidTimeScrollFrame:SetPoint("BOTTOMRIGHT", -30, 10)

	--RaidTime Frame: Content container for intOptRaidTime ScrollFrame
	frames.intOptRaidTimeScrollContent = CreateFrame("Frame", "intOptRaidTimeScrollContent", scrollFrames.intOptRaidTimeScrollFrame)
	frames.intOptRaidTimeScrollContent:SetSize(100, 300)

	--Monday Frame
	frames.intOptMondayFrame = CreateFrame("Frame", "intOptMonFrame", frames.intOptRaidTimeScrollContent)
	frames.intOptMondayFrame:SetSize(290, 80)
	frames.intOptMondayFrame:SetPoint("TOPLEFT", -10, 10)
	--Monday CheckButton
	checkButtons.intOptMondayCheckButton = CreateFrame("CheckButton", "intOptMondayCheckButton", frames.intOptMondayFrame, "UICheckButtonTemplate")
	checkButtons.intOptMondayCheckButton:SetPoint("CENTER", -110, 10)
	if(raidrTimes ~= nil and raidrTimes["Monday"] ~= nil and raidrTimes["Monday"]["Active"] ~= nil) then
		checkButtons.intOptMondayCheckButton:SetChecked(raidrTimes["Monday"]["Active"])
	end
	--Monday Name
	fontStrings.intOptMonString = frames.intOptMondayFrame:CreateFontString("intOptMonName")
	fontStrings.intOptMonString:SetFont("Fonts\\FRIZQT__.ttf", 12)
	fontStrings.intOptMonString:SetText("Monday")
	fontStrings.intOptMonString:SetJustifyH("LEFT")
	fontStrings.intOptMonString:SetPoint("CENTER", -70, 11)
	--Monday Dropdowns
	local intOptMondayHour = 1
	local intOptMondayMinute = "00"
	local intOptMondayAMPM = "AM"
	--Monday Hour Dropdown
	dropdowns.intOptMondayHourDropdown = CreateFrame("Frame", "intOptMondayHourDropdown", frames.intOptMondayFrame, "UIDropDownMenuTemplate")
	dropdowns.intOptMondayHourDropdown:SetPoint("CENTER", -95, -20)
	UIDropDownMenu_SetWidth(dropdowns.intOptMondayHourDropdown, 40)
	UIDropDownMenu_SetText(dropdowns.intOptMondayHourDropdown, intOptMondayHour)
	UIDropDownMenu_Initialize(dropdowns.intOptMondayHourDropdown, function(self, level, menuList)
		local info = UIDropDownMenu_CreateInfo()
		for i = 1, 12 do
			info.text = i
			info.checked = i == intOptMondayHour
			info.func = self.SetValue
			info.arg1 = i
			UIDropDownMenu_AddButton(info, level)
		end
	end)
	function dropdowns.intOptMondayHourDropdown:SetValue(newValue)
		intOptMondayHour = newValue
		UIDropDownMenu_SetText(dropdowns.intOptMondayHourDropdown, intOptMondayHour)
		CloseDropDownMenus()
	end
	if(raidrTimes ~= nil and raidrTimes["Monday"] ~= nil and raidrTimes["Monday"]["Hour"] ~= nil) then
		dropdowns.intOptMondayHourDropdown:SetValue(raidrTimes["Monday"]["Hour"])
	end
	--Monday Minute Dropdown
	dropdowns.intOptMondayMinuteDropdown = CreateFrame("Frame", "intOptMondayMinuteDropdown", frames.intOptMondayFrame, "UIDropDownMenuTemplate")
	dropdowns.intOptMondayMinuteDropdown:SetPoint("CENTER", -35, -20)
	UIDropDownMenu_SetWidth(dropdowns.intOptMondayMinuteDropdown, 40)
	UIDropDownMenu_SetText(dropdowns.intOptMondayMinuteDropdown, intOptMondayMinute)
	UIDropDownMenu_Initialize(dropdowns.intOptMondayMinuteDropdown, function(self, level, menuList)
		local info = UIDropDownMenu_CreateInfo()
		for i = 0, 11 do
			info.text = string.format("%02d", (i * 5))
			info.checked = string.format("%02d", (i * 5)) == intOptMondayMinute
			info.func = self.SetValue
			info.arg1 = string.format("%02d", (i * 5))
			UIDropDownMenu_AddButton(info, level)
		end
	end)
	function dropdowns.intOptMondayMinuteDropdown:SetValue(newValue)
		intOptMondayMinute = string.format("%02d", newValue)
		UIDropDownMenu_SetText(dropdowns.intOptMondayMinuteDropdown, intOptMondayMinute)
		CloseDropDownMenus()
	end
	if(raidrTimes ~= nil and raidrTimes["Monday"] ~= nil and raidrTimes["Monday"]["Minute"] ~= nil) then
		dropdowns.intOptMondayMinuteDropdown:SetValue(raidrTimes["Monday"]["Minute"])
	end
	--Monday AMPM Dropdown
	dropdowns.intOptMondayAMPMDropdown = CreateFrame("Frame", "intOptMondayAMPMDropdown", frames.intOptMondayFrame, "UIDropDownMenuTemplate")
	dropdowns.intOptMondayAMPMDropdown:SetPoint("CENTER", 25, -20)
	UIDropDownMenu_SetWidth(dropdowns.intOptMondayAMPMDropdown, 40)
	UIDropDownMenu_SetText(dropdowns.intOptMondayAMPMDropdown, intOptMondayAMPM)
	UIDropDownMenu_Initialize(dropdowns.intOptMondayAMPMDropdown, function(self, level, menuList)
		local info = UIDropDownMenu_CreateInfo()
		info.text = "AM"
		info.checked = info.text == intOptMondayAMPM
		info.func = self.SetValue
		info.arg1 = "AM"
		UIDropDownMenu_AddButton(info, level)
		
		info.text = "PM"
		info.checked = info.text == intOptMondayAMPM
		info.func = self.SetValue
		info.arg1 = "PM"
		UIDropDownMenu_AddButton(info, level)
	end)
	function dropdowns.intOptMondayAMPMDropdown:SetValue(newValue)
		intOptMondayAMPM = newValue
		UIDropDownMenu_SetText(dropdowns.intOptMondayAMPMDropdown, intOptMondayAMPM)
		CloseDropDownMenus()
	end
	if(raidrTimes ~= nil and raidrTimes["Monday"] ~= nil and raidrTimes["Monday"]["AMPM"] ~= nil) then
		dropdowns.intOptMondayAMPMDropdown:SetValue(raidrTimes["Monday"]["AMPM"])
	end

	--Tuesday Frame
	frames.intOptTuesdayFrame = CreateFrame("Frame", "intOptTuesFrame", frames.intOptRaidTimeScrollContent)
	frames.intOptTuesdayFrame:SetSize(290, 80)
	frames.intOptTuesdayFrame:SetPoint("TOPLEFT", -10, -50)
	--Tuesday CheckButton
	checkButtons.intOptTuesdayCheckButton = CreateFrame("CheckButton", "IntOptTuesdayCheckButton", frames.intOptTuesdayFrame, "UICheckButtonTemplate")
	checkButtons.intOptTuesdayCheckButton:SetPoint("CENTER", -110, 10)
	if(raidrTimes ~= nil and raidrTimes["Tuesday"] ~= nil and raidrTimes["Tuesday"]["Active"] ~= nil) then
		checkButtons.intOptTuesdayCheckButton:SetChecked(raidrTimes["Tuesday"]["Active"])
	end
	--Tuesday Name
	fontStrings.intOptTuesString = frames.intOptTuesdayFrame:CreateFontString("intOptTuesName")
	fontStrings.intOptTuesString:SetFont("Fonts\\FRIZQT__.ttf", 12)
	fontStrings.intOptTuesString:SetText("Tuesday")
	fontStrings.intOptTuesString:SetJustifyH("LEFT")
	fontStrings.intOptTuesString:SetPoint("CENTER", -70, 11)
	--Tuesday Dropdowns
	local intOptTuesdayHour = 1
	local intOptTuesdayMinute = "00"
	local intOptTuesdayAMPM = "AM"
	--Tuesday Hour Dropdown
	dropdowns.intOptTuesdayHourDropdown = CreateFrame("Frame", "IntOptTuesdayHourDropdown", frames.intOptTuesdayFrame, "UIDropDownMenuTemplate")
	dropdowns.intOptTuesdayHourDropdown:SetPoint("CENTER", -95, -20)
	UIDropDownMenu_SetWidth(dropdowns.intOptTuesdayHourDropdown, 40)
	UIDropDownMenu_SetText(dropdowns.intOptTuesdayHourDropdown, intOptTuesdayHour)
	UIDropDownMenu_Initialize(dropdowns.intOptTuesdayHourDropdown, function(self, level, menuList)
		local info = UIDropDownMenu_CreateInfo()
		for i = 1, 12 do
			info.text = i
			info.checked = i == intOptTuesdayHour
			info.func = self.SetValue
			info.arg1 = i
			UIDropDownMenu_AddButton(info, level)
		end
	end)
	function dropdowns.intOptTuesdayHourDropdown:SetValue(newValue)
		intOptTuesdayHour = newValue
		UIDropDownMenu_SetText(dropdowns.intOptTuesdayHourDropdown, intOptTuesdayHour)
		CloseDropDownMenus()
	end
	if(raidrTimes ~= nil and raidrTimes["Tuesday"] ~= nil and raidrTimes["Tuesday"]["Hour"] ~= nil) then
		dropdowns.intOptTuesdayHourDropdown:SetValue(raidrTimes["Tuesday"]["Hour"])
	end
	--Tuesday Minute Dropdown
	dropdowns.intOptTuesdayMinuteDropdown = CreateFrame("Frame", "IntOptTuesdayMinuteDropdown", frames.intOptTuesdayFrame, "UIDropDownMenuTemplate")
	dropdowns.intOptTuesdayMinuteDropdown:SetPoint("CENTER", -35, -20)
	UIDropDownMenu_SetWidth(dropdowns.intOptTuesdayMinuteDropdown, 40)
	UIDropDownMenu_SetText(dropdowns.intOptTuesdayMinuteDropdown, intOptTuesdayMinute)
	UIDropDownMenu_Initialize(dropdowns.intOptTuesdayMinuteDropdown, function(self, level, menuList)
		local info = UIDropDownMenu_CreateInfo()
		for i = 0, 11 do
			info.text = string.format("%02d", (i * 5))
			info.checked = string.format("%02d", (i * 5)) == intOptTuesdayMinute
			info.func = self.SetValue
			info.arg1 = string.format("%02d", (i * 5))
			UIDropDownMenu_AddButton(info, level)
		end
	end)
	function dropdowns.intOptTuesdayMinuteDropdown:SetValue(newValue)
		intOptTuesdayMinute = string.format("%02d", newValue)
		UIDropDownMenu_SetText(dropdowns.intOptTuesdayMinuteDropdown, intOptTuesdayMinute)
		CloseDropDownMenus()
	end
	if(raidrTimes ~= nil and raidrTimes["Tuesday"] ~= nil and raidrTimes["Tuesday"]["Minute"] ~= nil) then
		dropdowns.intOptTuesdayMinuteDropdown:SetValue(raidrTimes["Tuesday"]["Minute"])
	end
	--Tuesday AMPM Dropdown
	dropdowns.intOptTuesdayAMPMDropdown = CreateFrame("Frame", "IntOptTuesdayAMPMDropdown", frames.intOptTuesdayFrame, "UIDropDownMenuTemplate")
	dropdowns.intOptTuesdayAMPMDropdown:SetPoint("CENTER", 25, -20)
	UIDropDownMenu_SetWidth(dropdowns.intOptTuesdayAMPMDropdown, 40)
	UIDropDownMenu_SetText(dropdowns.intOptTuesdayAMPMDropdown, intOptTuesdayAMPM)
	UIDropDownMenu_Initialize(dropdowns.intOptTuesdayAMPMDropdown, function(self, level, menuList)
		local info = UIDropDownMenu_CreateInfo()
		info.text = "AM"
		info.checked = info.text == intOptTuesdayAMPM
		info.func = self.SetValue
		info.arg1 = "AM"
		UIDropDownMenu_AddButton(info, level)
		
		info.text = "PM"
		info.checked = info.text == intOptTuesdayAMPM
		info.func = self.SetValue
		info.arg1 = "PM"
		UIDropDownMenu_AddButton(info, level)
	end)
	function dropdowns.intOptTuesdayAMPMDropdown:SetValue(newValue)
		intOptTuesdayAMPM = newValue
		UIDropDownMenu_SetText(dropdowns.intOptTuesdayAMPMDropdown, intOptTuesdayAMPM)
		CloseDropDownMenus()
	end
	if(raidrTimes ~= nil and raidrTimes["Tuesday"] ~= nil and raidrTimes["Tuesday"]["AMPM"] ~= nil) then
		dropdowns.intOptTuesdayAMPMDropdown:SetValue(raidrTimes["Tuesday"]["AMPM"])
	end

	--Wednesday Frame
	frames.intOptWednesdayFrame = CreateFrame("Frame", "intOptWedFrame", frames.intOptRaidTimeScrollContent)
	frames.intOptWednesdayFrame:SetSize(290, 80)
	frames.intOptWednesdayFrame:SetPoint("TOPLEFT", -10, -110)
	--Wednesday CheckButton
	checkButtons.intOptWednesdayCheckButton = CreateFrame("CheckButton", "IntOptWednesdayCheckButton", frames.intOptWednesdayFrame, "UICheckButtonTemplate")
	checkButtons.intOptWednesdayCheckButton:SetPoint("CENTER", -110, 10)
	if(raidrTimes ~= nil and raidrTimes["Wednesday"] ~= nil and raidrTimes["Wednesday"]["Active"] ~= nil) then
		checkButtons.intOptWednesdayCheckButton:SetChecked(raidrTimes["Wednesday"]["Active"])
	end
	--Wednesday Name
	fontStrings.intOptWedString = frames.intOptWednesdayFrame:CreateFontString("intOptWedName")
	fontStrings.intOptWedString:SetFont("Fonts\\FRIZQT__.ttf", 12)
	fontStrings.intOptWedString:SetText("Wednesday")
	fontStrings.intOptWedString:SetJustifyH("LEFT")
	fontStrings.intOptWedString:SetPoint("CENTER", -60, 11)
	--Wednesday Dropdowns
	local intOptWednesdayHour = 1
	local intOptWednesdayMinute = "00"
	local intOptWednesdayAMPM = "AM"
	--Wednesday Hour Dropdown
	dropdowns.intOptWednesdayHourDropdown = CreateFrame("Frame", "IntOptWednesdayHourDropdown", frames.intOptWednesdayFrame, "UIDropDownMenuTemplate")
	dropdowns.intOptWednesdayHourDropdown:SetPoint("CENTER", -95, -20)
	UIDropDownMenu_SetWidth(dropdowns.intOptWednesdayHourDropdown, 40)
	UIDropDownMenu_SetText(dropdowns.intOptWednesdayHourDropdown, intOptWednesdayHour)
	UIDropDownMenu_Initialize(dropdowns.intOptWednesdayHourDropdown, function(self, level, menuList)
		local info = UIDropDownMenu_CreateInfo()
		for i = 1, 12 do
			info.text = i
			info.checked = i == intOptWednesdayHour
			info.func = self.SetValue
			info.arg1 = i
			UIDropDownMenu_AddButton(info, level)
		end
	end)
	function dropdowns.intOptWednesdayHourDropdown:SetValue(newValue)
		intOptWednesdayHour = newValue
		UIDropDownMenu_SetText(dropdowns.intOptWednesdayHourDropdown, intOptWednesdayHour)
		CloseDropDownMenus()
	end
	if(raidrTimes ~= nil and raidrTimes["Wednesday"] ~= nil and raidrTimes["Wednesday"]["Hour"] ~= nil) then
		dropdowns.intOptWednesdayHourDropdown:SetValue(raidrTimes["Wednesday"]["Hour"])
	end
	--Wednesday Minute Dropdown
	dropdowns.intOptWednesdayMinuteDropdown = CreateFrame("Frame", "IntOptWednesdayMinuteDropdown", frames.intOptWednesdayFrame, "UIDropDownMenuTemplate")
	dropdowns.intOptWednesdayMinuteDropdown:SetPoint("CENTER", -35, -20)
	UIDropDownMenu_SetWidth(dropdowns.intOptWednesdayMinuteDropdown, 40)
	UIDropDownMenu_SetText(dropdowns.intOptWednesdayMinuteDropdown, intOptWednesdayMinute)
	UIDropDownMenu_Initialize(dropdowns.intOptWednesdayMinuteDropdown, function(self, level, menuList)
		local info = UIDropDownMenu_CreateInfo()
		for i = 0, 11 do
			info.text = string.format("%02d", (i * 5))
			info.checked = string.format("%02d", (i * 5)) == intOptWednesdayMinute
			info.func = self.SetValue
			info.arg1 = string.format("%02d", (i * 5))
			UIDropDownMenu_AddButton(info, level)
		end
	end)
	function dropdowns.intOptWednesdayMinuteDropdown:SetValue(newValue)
		intOptWednesdayMinute = string.format("%02d", newValue)
		UIDropDownMenu_SetText(dropdowns.intOptWednesdayMinuteDropdown, intOptWednesdayMinute)
		CloseDropDownMenus()
	end
	if(raidrTimes ~= nil and raidrTimes["Wednesday"] ~= nil and raidrTimes["Wednesday"]["Minute"] ~= nil) then
		dropdowns.intOptWednesdayMinuteDropdown:SetValue(raidrTimes["Wednesday"]["Minute"])
	end
	--Wednesday AMPM Dropdown
	dropdowns.intOptWednesdayAMPMDropdown = CreateFrame("Frame", "IntOptWednesdayAMPMDropdown", frames.intOptWednesdayFrame, "UIDropDownMenuTemplate")
	dropdowns.intOptWednesdayAMPMDropdown:SetPoint("CENTER", 25, -20)
	UIDropDownMenu_SetWidth(dropdowns.intOptWednesdayAMPMDropdown, 40)
	UIDropDownMenu_SetText(dropdowns.intOptWednesdayAMPMDropdown, intOptWednesdayAMPM)
	UIDropDownMenu_Initialize(dropdowns.intOptWednesdayAMPMDropdown, function(self, level, menuList)
		local info = UIDropDownMenu_CreateInfo()
		info.text = "AM"
		info.checked = info.text == intOptWednesdayAMPM
		info.func = self.SetValue
		info.arg1 = "AM"
		UIDropDownMenu_AddButton(info, level)
		
		info.text = "PM"
		info.checked = info.text == intOptWednesdayAMPM
		info.func = self.SetValue
		info.arg1 = "PM"
		UIDropDownMenu_AddButton(info, level)
	end)
	function dropdowns.intOptWednesdayAMPMDropdown:SetValue(newValue)
		intOptWednesdayAMPM = newValue
		UIDropDownMenu_SetText(dropdowns.intOptWednesdayAMPMDropdown, intOptWednesdayAMPM)
		CloseDropDownMenus()
	end
	if(raidrTimes ~= nil and raidrTimes["Wednesday"] ~= nil and raidrTimes["Wednesday"]["AMPM"] ~= nil) then
		dropdowns.intOptWednesdayAMPMDropdown:SetValue(raidrTimes["Wednesday"]["AMPM"])
	end

	--Thursday Frame
	frames.intOptThursdayFrame = CreateFrame("Frame", "intOptThursFrame", frames.intOptRaidTimeScrollContent)
	frames.intOptThursdayFrame:SetSize(290, 80)
	frames.intOptThursdayFrame:SetPoint("TOPLEFT", -10, -170)
	--Thursday CheckButton
	checkButtons.intOptThursdayCheckButton = CreateFrame("CheckButton", "IntOptThursdayCheckButton", frames.intOptThursdayFrame, "UICheckButtonTemplate")
	checkButtons.intOptThursdayCheckButton:SetPoint("CENTER", -110, 10)
	if(raidrTimes ~= nil and raidrTimes["Thursday"] ~= nil and raidrTimes["Thursday"]["Active"] ~= nil) then
		checkButtons.intOptThursdayCheckButton:SetChecked(raidrTimes["Thursday"]["Active"])
	end
	--Thursday Name
	fontStrings.intOptThursString = frames.intOptThursdayFrame:CreateFontString("intOptThursName")
	fontStrings.intOptThursString:SetFont("Fonts\\FRIZQT__.ttf", 12)
	fontStrings.intOptThursString:SetText("Thursday")
	fontStrings.intOptThursString:SetJustifyH("LEFT")
	fontStrings.intOptThursString:SetPoint("CENTER", -66, 11)
	--Thursday Dropdowns
	local intOptThursdayHour = 1
	local intOptThursdayMinute = "00"
	local intOptThursdayAMPM = "AM"
	--Thursday Hour Dropdown
	dropdowns.intOptThursdayHourDropdown = CreateFrame("Frame", "IntOptThursdayHourDropdown", frames.intOptThursdayFrame, "UIDropDownMenuTemplate")
	dropdowns.intOptThursdayHourDropdown:SetPoint("CENTER", -95, -20)
	UIDropDownMenu_SetWidth(dropdowns.intOptThursdayHourDropdown, 40)
	UIDropDownMenu_SetText(dropdowns.intOptThursdayHourDropdown, intOptThursdayHour)
	UIDropDownMenu_Initialize(dropdowns.intOptThursdayHourDropdown, function(self, level, menuList)
		local info = UIDropDownMenu_CreateInfo()
		for i = 1, 12 do
			info.text = i
			info.checked = i == intOptThursdayHour
			info.func = self.SetValue
			info.arg1 = i
			UIDropDownMenu_AddButton(info, level)
		end
	end)
	function dropdowns.intOptThursdayHourDropdown:SetValue(newValue)
		intOptThursdayHour = newValue
		UIDropDownMenu_SetText(dropdowns.intOptThursdayHourDropdown, intOptThursdayHour)
		CloseDropDownMenus()
	end
	if(raidrTimes ~= nil and raidrTimes["Thursday"] ~= nil and raidrTimes["Thursday"]["Hour"] ~= nil) then
		dropdowns.intOptThursdayHourDropdown:SetValue(raidrTimes["Thursday"]["Hour"])
	end
	--Thursday Minute Dropdown
	dropdowns.intOptThursdayMinuteDropdown = CreateFrame("Frame", "IntOptThursdayMinuteDropdown", frames.intOptThursdayFrame, "UIDropDownMenuTemplate")
	dropdowns.intOptThursdayMinuteDropdown:SetPoint("CENTER", -35, -20)
	UIDropDownMenu_SetWidth(dropdowns.intOptThursdayMinuteDropdown, 40)
	UIDropDownMenu_SetText(dropdowns.intOptThursdayMinuteDropdown, intOptThursdayMinute)
	UIDropDownMenu_Initialize(dropdowns.intOptThursdayMinuteDropdown, function(self, level, menuList)
		local info = UIDropDownMenu_CreateInfo()
		for i = 0, 11 do
			info.text = string.format("%02d", (i * 5))
			info.checked = string.format("%02d", (i * 5)) == intOptThursdayMinute
			info.func = self.SetValue
			info.arg1 = string.format("%02d", (i * 5))
			UIDropDownMenu_AddButton(info, level)
		end
	end)
	function dropdowns.intOptThursdayMinuteDropdown:SetValue(newValue)
		intOptThursdayMinute = string.format("%02d", newValue)
		UIDropDownMenu_SetText(dropdowns.intOptThursdayMinuteDropdown, intOptThursdayMinute)
		CloseDropDownMenus()
	end
	if(raidrTimes ~= nil and raidrTimes["Thursday"] ~= nil and raidrTimes["Thursday"]["Minute"] ~= nil) then
		dropdowns.intOptThursdayMinuteDropdown:SetValue(raidrTimes["Thursday"]["Minute"])
	end
	--Thursday AMPM Dropdown
	dropdowns.intOptThursdayAMPMDropdown = CreateFrame("Frame", "IntOptThursdayAMPMDropdown", frames.intOptThursdayFrame, "UIDropDownMenuTemplate")
	dropdowns.intOptThursdayAMPMDropdown:SetPoint("CENTER", 25, -20)
	UIDropDownMenu_SetWidth(dropdowns.intOptThursdayAMPMDropdown, 40)
	UIDropDownMenu_SetText(dropdowns.intOptThursdayAMPMDropdown, intOptThursdayAMPM)
	UIDropDownMenu_Initialize(dropdowns.intOptThursdayAMPMDropdown, function(self, level, menuList)
		local info = UIDropDownMenu_CreateInfo()
		info.text = "AM"
		info.checked = info.text == intOptThursdayAMPM
		info.func = self.SetValue
		info.arg1 = "AM"
		UIDropDownMenu_AddButton(info, level)
		
		info.text = "PM"
		info.checked = info.text == intOptThursdayAMPM
		info.func = self.SetValue
		info.arg1 = "PM"
		UIDropDownMenu_AddButton(info, level)
	end)
	function dropdowns.intOptThursdayAMPMDropdown:SetValue(newValue)
		intOptThursdayAMPM = newValue
		UIDropDownMenu_SetText(dropdowns.intOptThursdayAMPMDropdown, intOptThursdayAMPM)
		CloseDropDownMenus()
	end
	if(raidrTimes ~= nil and raidrTimes["Thursday"] ~= nil and raidrTimes["Thursday"]["AMPM"] ~= nil) then
		dropdowns.intOptThursdayAMPMDropdown:SetValue(raidrTimes["Thursday"]["AMPM"])
	end

	--Friday Frame
	frames.intOptFridayFrame = CreateFrame("Frame", "intOptFriFrame", frames.intOptRaidTimeScrollContent)
	frames.intOptFridayFrame:SetSize(290, 80)
	frames.intOptFridayFrame:SetPoint("TOPLEFT", -10, -230)
	--Friday CheckButton
	checkButtons.intOptFridayCheckButton = CreateFrame("CheckButton", "IntOptFridayCheckButton", frames.intOptFridayFrame, "UICheckButtonTemplate")
	checkButtons.intOptFridayCheckButton:SetPoint("CENTER", -110, 10)
	if(raidrTimes ~= nil and raidrTimes["Friday"] ~= nil and raidrTimes["Friday"]["Active"] ~= nil) then
		checkButtons.intOptFridayCheckButton:SetChecked(raidrTimes["Friday"]["Active"])
	end
	--Friday Name
	fontStrings.intOptFriString = frames.intOptFridayFrame:CreateFontString("intOptFriName")
	fontStrings.intOptFriString:SetFont("Fonts\\FRIZQT__.ttf", 12)
	fontStrings.intOptFriString:SetText("Friday")
	fontStrings.intOptFriString:SetJustifyH("LEFT")
	fontStrings.intOptFriString:SetPoint("CENTER", -75, 11)
	--Friday Dropdowns
	local intOptFridayHour = 1
	local intOptFridayMinute = "00"
	local intOptFridayAMPM = "AM"
	--Friday Hour Dropdown
	dropdowns.intOptFridayHourDropdown = CreateFrame("Frame", "IntOptFridayHourDropdown", frames.intOptFridayFrame, "UIDropDownMenuTemplate")
	dropdowns.intOptFridayHourDropdown:SetPoint("CENTER", -95, -20)
	UIDropDownMenu_SetWidth(dropdowns.intOptFridayHourDropdown, 40)
	UIDropDownMenu_SetText(dropdowns.intOptFridayHourDropdown, intOptFridayHour)
	UIDropDownMenu_Initialize(dropdowns.intOptFridayHourDropdown, function(self, level, menuList)
		local info = UIDropDownMenu_CreateInfo()
		for i = 1, 12 do
			info.text = i
			info.checked = i == intOptFridayHour
			info.func = self.SetValue
			info.arg1 = i
			UIDropDownMenu_AddButton(info, level)
		end
	end)
	function dropdowns.intOptFridayHourDropdown:SetValue(newValue)
		intOptFridayHour = newValue
		UIDropDownMenu_SetText(dropdowns.intOptFridayHourDropdown, intOptFridayHour)
		CloseDropDownMenus()
	end
	if(raidrTimes ~= nil and raidrTimes["Friday"] ~= nil and raidrTimes["Friday"]["Hour"] ~= nil) then
		dropdowns.intOptFridayHourDropdown:SetValue(raidrTimes["Friday"]["Hour"])
	end
	--Friday Minute Dropdown
	dropdowns.intOptFridayMinuteDropdown = CreateFrame("Frame", "IntOptFridayMinuteDropdown", frames.intOptFridayFrame, "UIDropDownMenuTemplate")
	dropdowns.intOptFridayMinuteDropdown:SetPoint("CENTER", -35, -20)
	UIDropDownMenu_SetWidth(dropdowns.intOptFridayMinuteDropdown, 40)
	UIDropDownMenu_SetText(dropdowns.intOptFridayMinuteDropdown, intOptFridayMinute)
	UIDropDownMenu_Initialize(dropdowns.intOptFridayMinuteDropdown, function(self, level, menuList)
		local info = UIDropDownMenu_CreateInfo()
		for i = 0, 11 do
			info.text = string.format("%02d", (i * 5))
			info.checked = string.format("%02d", (i * 5)) == intOptFridayMinute
			info.func = self.SetValue
			info.arg1 = string.format("%02d", (i * 5))
			UIDropDownMenu_AddButton(info, level)
		end
	end)
	function dropdowns.intOptFridayMinuteDropdown:SetValue(newValue)
		intOptFridayMinute = string.format("%02d", newValue)
		UIDropDownMenu_SetText(dropdowns.intOptFridayMinuteDropdown, intOptFridayMinute)
		CloseDropDownMenus()
	end
	if(raidrTimes ~= nil and raidrTimes["Friday"] ~= nil and raidrTimes["Friday"]["Minute"] ~= nil) then
		dropdowns.intOptFridayMinuteDropdown:SetValue(raidrTimes["Friday"]["Minute"])
	end
	--Friday AMPM Dropdown
	dropdowns.intOptFridayAMPMDropdown = CreateFrame("Frame", "IntOptFridayAMPMDropdown", frames.intOptFridayFrame, "UIDropDownMenuTemplate")
	dropdowns.intOptFridayAMPMDropdown:SetPoint("CENTER", 25, -20)
	UIDropDownMenu_SetWidth(dropdowns.intOptFridayAMPMDropdown, 40)
	UIDropDownMenu_SetText(dropdowns.intOptFridayAMPMDropdown, intOptFridayAMPM)
	UIDropDownMenu_Initialize(dropdowns.intOptFridayAMPMDropdown, function(self, level, menuList)
		local info = UIDropDownMenu_CreateInfo()
		info.text = "AM"
		info.checked = info.text == intOptFridayAMPM
		info.func = self.SetValue
		info.arg1 = "AM"
		UIDropDownMenu_AddButton(info, level)
		
		info.text = "PM"
		info.checked = info.text == intOptFridayAMPM
		info.func = self.SetValue
		info.arg1 = "PM"
		UIDropDownMenu_AddButton(info, level)
	end)
	function dropdowns.intOptFridayAMPMDropdown:SetValue(newValue)
		intOptFridayAMPM = newValue
		UIDropDownMenu_SetText(dropdowns.intOptFridayAMPMDropdown, intOptFridayAMPM)
		CloseDropDownMenus()
	end
	if(raidrTimes ~= nil and raidrTimes["Friday"] ~= nil and raidrTimes["Friday"]["AMPM"] ~= nil) then
		dropdowns.intOptFridayAMPMDropdown:SetValue(raidrTimes["Friday"]["AMPM"])
	end

	--Saturday Frame
	frames.intOptSaturdayFrame = CreateFrame("Frame", "intOptSatFrame", frames.intOptRaidTimeScrollContent)
	frames.intOptSaturdayFrame:SetSize(290, 80)
	frames.intOptSaturdayFrame:SetPoint("TOPLEFT", -10, -290)
	--Saturday CheckButton
	checkButtons.intOptSaturdayCheckButton = CreateFrame("CheckButton", "IntOptSaturdayCheckButton", frames.intOptSaturdayFrame, "UICheckButtonTemplate")
	checkButtons.intOptSaturdayCheckButton:SetPoint("CENTER", -110, 10)
	if(raidrTimes ~= nil and raidrTimes["Saturday"] ~= nil and raidrTimes["Saturday"]["Active"] ~= nil) then
		checkButtons.intOptSaturdayCheckButton:SetChecked(raidrTimes["Saturday"]["Active"])
	end
	--Saturday Name
	fontStrings.intOptSatString = frames.intOptSaturdayFrame:CreateFontString("intOptSatName")
	fontStrings.intOptSatString:SetFont("Fonts\\FRIZQT__.ttf", 12)
	fontStrings.intOptSatString:SetText("Saturday")
	fontStrings.intOptSatString:SetJustifyH("LEFT")
	fontStrings.intOptSatString:SetPoint("CENTER", -67, 11)
	--Saturday Dropdowns
	local intOptSaturdayHour = 1
	local intOptSaturdayMinute = "00"
	local intOptSaturdayAMPM = "AM"
	--Saturday Hour Dropdown
	dropdowns.intOptSaturdayHourDropdown = CreateFrame("Frame", "IntOptSaturdayHourDropdown", frames.intOptSaturdayFrame, "UIDropDownMenuTemplate")
	dropdowns.intOptSaturdayHourDropdown:SetPoint("CENTER", -95, -20)
	UIDropDownMenu_SetWidth(dropdowns.intOptSaturdayHourDropdown, 40)
	UIDropDownMenu_SetText(dropdowns.intOptSaturdayHourDropdown, intOptSaturdayHour)
	UIDropDownMenu_Initialize(dropdowns.intOptSaturdayHourDropdown, function(self, level, menuList)
		local info = UIDropDownMenu_CreateInfo()
		for i = 1, 12 do
			info.text = i
			info.checked = i == intOptSaturdayHour
			info.func = self.SetValue
			info.arg1 = i
			UIDropDownMenu_AddButton(info, level)
		end
	end)
	function dropdowns.intOptSaturdayHourDropdown:SetValue(newValue)
		intOptSaturdayHour = newValue
		UIDropDownMenu_SetText(dropdowns.intOptSaturdayHourDropdown, intOptSaturdayHour)
		CloseDropDownMenus()
	end
	if(raidrTimes ~= nil and raidrTimes["Saturday"] ~= nil and raidrTimes["Saturday"]["Hour"] ~= nil) then
		dropdowns.intOptSaturdayHourDropdown:SetValue(raidrTimes["Saturday"]["Hour"])
	end
	--Saturday Minute Dropdown
	dropdowns.intOptSaturdayMinuteDropdown = CreateFrame("Frame", "IntOptSaturdayMinuteDropdown", frames.intOptSaturdayFrame, "UIDropDownMenuTemplate")
	dropdowns.intOptSaturdayMinuteDropdown:SetPoint("CENTER", -35, -20)
	UIDropDownMenu_SetWidth(dropdowns.intOptSaturdayMinuteDropdown, 40)
	UIDropDownMenu_SetText(dropdowns.intOptSaturdayMinuteDropdown, intOptSaturdayMinute)
	UIDropDownMenu_Initialize(dropdowns.intOptSaturdayMinuteDropdown, function(self, level, menuList)
		local info = UIDropDownMenu_CreateInfo()
		for i = 0, 11 do
			info.text = string.format("%02d", (i * 5))
			info.checked = string.format("%02d", (i * 5)) == intOptSaturdayMinute
			info.func = self.SetValue
			info.arg1 = string.format("%02d", (i * 5))
			UIDropDownMenu_AddButton(info, level)
		end
	end)
	function dropdowns.intOptSaturdayMinuteDropdown:SetValue(newValue)
		intOptSaturdayMinute = string.format("%02d", newValue)
		UIDropDownMenu_SetText(dropdowns.intOptSaturdayMinuteDropdown, intOptSaturdayMinute)
		CloseDropDownMenus()
	end
	if(raidrTimes ~= nil and raidrTimes["Saturday"] ~= nil and raidrTimes["Saturday"]["Minute"] ~= nil) then
		dropdowns.intOptSaturdayMinuteDropdown:SetValue(raidrTimes["Saturday"]["Minute"])
	end
	--Saturday AMPM Dropdown
	dropdowns.intOptSaturdayAMPMDropdown = CreateFrame("Frame", "IntOptSaturdayAMPMDropdown", frames.intOptSaturdayFrame, "UIDropDownMenuTemplate")
	dropdowns.intOptSaturdayAMPMDropdown:SetPoint("CENTER", 25, -20)
	UIDropDownMenu_SetWidth(dropdowns.intOptSaturdayAMPMDropdown, 40)
	UIDropDownMenu_SetText(dropdowns.intOptSaturdayAMPMDropdown, intOptSaturdayAMPM)
	UIDropDownMenu_Initialize(dropdowns.intOptSaturdayAMPMDropdown, function(self, level, menuList)
		local info = UIDropDownMenu_CreateInfo()
		info.text = "AM"
		info.checked = info.text == intOptSaturdayAMPM
		info.func = self.SetValue
		info.arg1 = "AM"
		UIDropDownMenu_AddButton(info, level)
		
		info.text = "PM"
		info.checked = info.text == intOptSaturdayAMPM
		info.func = self.SetValue
		info.arg1 = "PM"
		UIDropDownMenu_AddButton(info, level)
	end)
	function dropdowns.intOptSaturdayAMPMDropdown:SetValue(newValue)
		intOptSaturdayAMPM = newValue
		UIDropDownMenu_SetText(dropdowns.intOptSaturdayAMPMDropdown, intOptSaturdayAMPM)
		CloseDropDownMenus()
	end
	if(raidrTimes ~= nil and raidrTimes["Saturday"] ~= nil and raidrTimes["Saturday"]["AMPM"] ~= nil) then
		dropdowns.intOptSaturdayAMPMDropdown:SetValue(raidrTimes["Saturday"]["AMPM"])
	end

	--Sunday Frame
	frames.intOptSundayFrame = CreateFrame("Frame", "intOptSunFrame", frames.intOptRaidTimeScrollContent)
	frames.intOptSundayFrame:SetSize(290, 80)
	frames.intOptSundayFrame:SetPoint("TOPLEFT", -10, -350)
	--Sunday CheckButton
	checkButtons.intOptSundayCheckButton = CreateFrame("CheckButton", "IntOptSundayCheckButton", frames.intOptSundayFrame, "UICheckButtonTemplate")
	checkButtons.intOptSundayCheckButton:SetPoint("CENTER", -110, 10)
	if(raidrTimes ~= nil and raidrTimes["Sunday"] ~= nil and raidrTimes["Sunday"]["Active"] ~= nil) then
		checkButtons.intOptSundayCheckButton:SetChecked(raidrTimes["Sunday"]["Active"])
	end
	--Sunday Name
	fontStrings.intOptSunString = frames.intOptSundayFrame:CreateFontString("intOptSunName")
	fontStrings.intOptSunString:SetFont("Fonts\\FRIZQT__.ttf", 12)
	fontStrings.intOptSunString:SetText("Sunday")
	fontStrings.intOptSunString:SetJustifyH("LEFT")
	fontStrings.intOptSunString:SetPoint("CENTER", -71, 11)
	--Sunday Dropdowns
	local intOptSundayHour = 1
	local intOptSundayMinute = "00"
	local intOptSundayAMPM = "AM"
	--Sunday Hour Dropdown
	dropdowns.intOptSundayHourDropdown = CreateFrame("Frame", "IntOptSundayHourDropdown", frames.intOptSundayFrame, "UIDropDownMenuTemplate")
	dropdowns.intOptSundayHourDropdown:SetPoint("CENTER", -95, -20)
	UIDropDownMenu_SetWidth(dropdowns.intOptSundayHourDropdown, 40)
	UIDropDownMenu_SetText(dropdowns.intOptSundayHourDropdown, intOptSundayHour)
	UIDropDownMenu_Initialize(dropdowns.intOptSundayHourDropdown, function(self, level, menuList)
		local info = UIDropDownMenu_CreateInfo()
		for i = 1, 12 do
			info.text = i
			info.checked = i == intOptSundayHour
			info.func = self.SetValue
			info.arg1 = i
			UIDropDownMenu_AddButton(info, level)
		end
	end)
	function dropdowns.intOptSundayHourDropdown:SetValue(newValue)
		intOptSundayHour = newValue
		UIDropDownMenu_SetText(dropdowns.intOptSundayHourDropdown, intOptSundayHour)
		CloseDropDownMenus()
	end
	if(raidrTimes ~= nil and raidrTimes["Sunday"] ~= nil and raidrTimes["Sunday"]["Hour"] ~= nil) then
		dropdowns.intOptSundayHourDropdown:SetValue(raidrTimes["Sunday"]["Hour"])
	end
	--Sunday Minute Dropdown
	dropdowns.intOptSundayMinuteDropdown = CreateFrame("Frame", "IntOptSundayMinuteDropdown", frames.intOptSundayFrame, "UIDropDownMenuTemplate")
	dropdowns.intOptSundayMinuteDropdown:SetPoint("CENTER", -35, -20)
	UIDropDownMenu_SetWidth(dropdowns.intOptSundayMinuteDropdown, 40)
	UIDropDownMenu_SetText(dropdowns.intOptSundayMinuteDropdown, intOptSundayMinute)
	UIDropDownMenu_Initialize(dropdowns.intOptSundayMinuteDropdown, function(self, level, menuList)
		local info = UIDropDownMenu_CreateInfo()
		for i = 0, 11 do
			info.text = string.format("%02d", (i * 5))
			info.checked = string.format("%02d", (i * 5)) == intOptSundayMinute
			info.func = self.SetValue
			info.arg1 = string.format("%02d", (i * 5))
			UIDropDownMenu_AddButton(info, level)
		end
	end)
	function dropdowns.intOptSundayMinuteDropdown:SetValue(newValue)
		intOptSundayMinute = string.format("%02d", newValue)
		UIDropDownMenu_SetText(dropdowns.intOptSundayMinuteDropdown, intOptSundayMinute)
		CloseDropDownMenus()
	end
	if(raidrTimes ~= nil and raidrTimes["Sunday"] ~= nil and raidrTimes["Sunday"]["Minute"] ~= nil) then
		dropdowns.intOptSundayMinuteDropdown:SetValue(raidrTimes["Sunday"]["Minute"])
	end
	--Sunday AMPM Dropdown
	dropdowns.intOptSundayAMPMDropdown = CreateFrame("Frame", "IntOptSundayAMPMDropdown", frames.intOptSundayFrame, "UIDropDownMenuTemplate")
	dropdowns.intOptSundayAMPMDropdown:SetPoint("CENTER", 25, -20)
	UIDropDownMenu_SetWidth(dropdowns.intOptSundayAMPMDropdown, 40)
	UIDropDownMenu_SetText(dropdowns.intOptSundayAMPMDropdown, intOptSundayAMPM)
	UIDropDownMenu_Initialize(dropdowns.intOptSundayAMPMDropdown, function(self, level, menuList)
		local info = UIDropDownMenu_CreateInfo()
		info.text = "AM"
		info.checked = info.text == intOptSundayAMPM
		info.func = self.SetValue
		info.arg1 = "AM"
		UIDropDownMenu_AddButton(info, level)
		
		info.text = "PM"
		info.checked = info.text == intOptSundayAMPM
		info.func = self.SetValue
		info.arg1 = "PM"
		UIDropDownMenu_AddButton(info, level)
	end)
	function dropdowns.intOptSundayAMPMDropdown:SetValue(newValue)
		intOptSundayAMPM = newValue
		UIDropDownMenu_SetText(dropdowns.intOptSundayAMPMDropdown, intOptSundayAMPM)
		CloseDropDownMenus()
	end
	if(raidrTimes ~= nil and raidrTimes["Sunday"] ~= nil and raidrTimes["Sunday"]["AMPM"] ~= nil) then
		dropdowns.intOptSundayAMPMDropdown:SetValue(raidrTimes["Sunday"]["AMPM"])
	end

	scrollFrames.intOptRaidTimeScrollFrame:SetScrollChild(frames.intOptRaidTimeScrollContent)

	--Options Frame
	frames.intOptOptionsFrame = CreateFrame("Frame", "intOptOptionsFrame", RaidR.panel)
	frames.intOptOptionsFrame:SetPoint("TOPLEFT", 350, -325)
	frames.intOptOptionsFrame:SetPoint("BOTTOMRIGHT")

	--Reminder Time Frame
	frames.intOptReminderTimeFrame = CreateFrame("Frame", "intOptRmtFrame", frames.intOptOptionsFrame)
	frames.intOptReminderTimeFrame:SetSize(290, 75)
	frames.intOptReminderTimeFrame:SetPoint("TOPLEFT", 0, 10)
	--Reminder Time String
	fontStrings.intOptReminderTimeString = frames.intOptReminderTimeFrame:CreateFontString("intOptReminderTimeString")
	fontStrings.intOptReminderTimeString:SetFont("Fonts\\FRIZQT__.ttf", 10)
	fontStrings.intOptReminderTimeString:SetText("Pre-raid alert: ")
	fontStrings.intOptReminderTimeString:SetJustifyH("LEFT")
	fontStrings.intOptReminderTimeString:SetPoint("CENTER", -85, 0)
	--Reminder Time Dropdown
	local intOptReminderTimeString = "5 minutes"
	local intOptReminderTimeValue = 5
	dropdowns.intOptReminderTimeDropdown = CreateFrame("Frame", "intOptReminderTimeDropdown", frames.intOptReminderTimeFrame, "UIDropDownMenuTemplate")
	dropdowns.intOptReminderTimeDropdown:SetPoint("CENTER", 5, -3)
	UIDropDownMenu_SetWidth(dropdowns.intOptReminderTimeDropdown, 80)
	UIDropDownMenu_SetText(dropdowns.intOptReminderTimeDropdown, intOptReminderTimeString)
	UIDropDownMenu_Initialize(dropdowns.intOptReminderTimeDropdown, function(self, level, menuList)
		local info = UIDropDownMenu_CreateInfo()
		info.text = "5 minutes"
		info.checked = info.text == intOptReminderTimeString
		info.value = 5
		info.func = self.SetValue
		info.arg1 = info.text
		info.arg2 = info.value
		UIDropDownMenu_AddButton(info, level)
		
		info.text = "10 minutes"
		info.checked = info.text == intOptReminderTimeString
		info.value = 10
		info.func = self.SetValue
		info.arg1 = info.text
		info.arg2 = info.value
		UIDropDownMenu_AddButton(info, level)
		
		info.text = "15 minutes"
		info.checked = info.text == intOptReminderTimeString
		info.value = 15
		info.func = self.SetValue
		info.arg1 = info.text
		info.arg2 = info.value
		UIDropDownMenu_AddButton(info, level)
		
		info.text = "30 minutes"
		info.checked = info.text == intOptReminderTimeString
		info.value = 30
		info.func = self.SetValue
		info.arg1 = info.text
		info.arg2 = info.value
		UIDropDownMenu_AddButton(info, level)
		
		info.text = "45 minutes"
		info.checked = info.text == intOptReminderTimeString
		info.value = 45
		info.func = self.SetValue
		info.arg1 = info.text
		info.arg2 = info.value
		UIDropDownMenu_AddButton(info, level)
		
		info.text = "1 hour"
		info.checked = info.text == intOptReminderTimeString
		info.value = 60
		info.func = self.SetValue
		info.arg1 = info.text
		info.arg2 = info.value
		UIDropDownMenu_AddButton(info, level)
	end)
	function dropdowns.intOptReminderTimeDropdown:SetValue(newString, newValue)
		intOptReminderTimeString = newString
		intOptReminderTimeValue = newValue
		UIDropDownMenu_SetText(dropdowns.intOptReminderTimeDropdown, intOptReminderTimeString)
		CloseDropDownMenus()
	end
	if(raidrTimes ~= nil and raidrTimes["ReminderTime"] ~= nil) then
		if(raidrTimes["ReminderTime"] == 60) then
			dropdowns.intOptReminderTimeDropdown:SetValue("1 hour", 60)
		else
			dropdowns.intOptReminderTimeDropdown:SetValue(raidrTimes["ReminderTime"] .. " minutes", raidrTimes["ReminderTime"])
		end
	end
	dropdowns.intOptReminderTimeDropdown:SetScript("OnEnter", function(self)
		GameTooltip:SetOwner(self, "ANCHOR_CURSOR");
		GameTooltip:ClearLines()
		GameTooltip:SetText("How long before raid you would like\nRaidR to check your consumables")
		GameTooltip:Show()
	end)
	dropdowns.intOptReminderTimeDropdown:SetScript("OnLeave", function(self)
		GameTooltip:Hide()
	end)

	--Bonus Roll Option Frame
	frames.intOptBonusRollOptionFrame = CreateFrame("Frame", "intOptBroFrame", frames.intOptOptionsFrame)
	frames.intOptBonusRollOptionFrame:SetSize(290, 75)
	frames.intOptBonusRollOptionFrame:SetPoint("TOPLEFT", 0, -45)
	--Bonus Roll Option CheckButton
	checkButtons.intOptBroCheckButton = CreateFrame("CheckButton", "intOptBroCheckButton", frames.intOptBonusRollOptionFrame, "UICheckButtonTemplate")
	checkButtons.intOptBroCheckButton:SetPoint("CENTER", -110, -2)
	if(raidrOptions ~= nil and raidrOptions["Seals"] ~= nil) then
		checkButtons.intOptBroCheckButton:SetChecked(raidrOptions["Seals"])
	end
	checkButtons.intOptBroCheckButton:SetScript("OnEnter", function(self)
		GameTooltip:SetOwner(self, "ANCHOR_CURSOR");
		GameTooltip:ClearLines()
		GameTooltip:SetText("If checked, the reminder window will include a check\nto make sure you bought your Seals this week")
		GameTooltip:Show()
	end)
	checkButtons.intOptBroCheckButton:SetScript("OnLeave", function(self)
		GameTooltip:Hide()
	end)
	--Bonus Roll Option String
	fontStrings.intOptBroString = frames.intOptBonusRollOptionFrame:CreateFontString("intOptBroString")
	fontStrings.intOptBroString:SetFont("Fonts\\FRIZQT__.ttf", 10)
	fontStrings.intOptBroString:SetText("Track Bonus rolls")
	fontStrings.intOptBroString:SetJustifyH("LEFT")
	fontStrings.intOptBroString:SetPoint("CENTER", -50, 0)

	--Play Sound Option Frame
	frames.intOptPlaySoundOptionFrame = CreateFrame("Frame", "intOptPsoFrame", frames.intOptOptionsFrame)
	frames.intOptPlaySoundOptionFrame:SetSize(290, 75)
	frames.intOptPlaySoundOptionFrame:SetPoint("TOPLEFT", 0, -100)
	--Play Sound Option CheckButton
	checkButtons.intOptPsoCheckButton = CreateFrame("CheckButton", "intOptPsoCheckButton", frames.intOptPlaySoundOptionFrame, "UICheckButtonTemplate")
	checkButtons.intOptPsoCheckButton:SetPoint("CENTER", -110, -2)
	if(raidrOptions ~= nil and raidrOptions["PlaySound"] ~= nil) then
		checkButtons.intOptPsoCheckButton:SetChecked(raidrOptions["PlaySound"])
	end
	checkButtons.intOptPsoCheckButton:SetScript("OnEnter", function(self)
		GameTooltip:SetOwner(self, "ANCHOR_CURSOR");
		GameTooltip:ClearLines()
		GameTooltip:SetText("If checked, the reminder window will intOptPlay a sound alert")
		GameTooltip:Show()
	end)
	checkButtons.intOptPsoCheckButton:SetScript("OnLeave", function(self)
		GameTooltip:Hide()
	end)
	--Play Sound Option String
	fontStrings.intOptPsoString = frames.intOptPlaySoundOptionFrame:CreateFontString("intOptPsoString")
	fontStrings.intOptPsoString:SetFont("Fonts\\FRIZQT__.ttf", 10)
	fontStrings.intOptPsoString:SetText("Play Sound Alert")
	fontStrings.intOptPsoString:SetJustifyH("LEFT")
	fontStrings.intOptPsoString:SetPoint("CENTER", -51, 0)

	--Whisper Alert Option Frame
	frames.intOptWhisperAlertOptionFrame = CreateFrame("Frame", "intOptWaoFrame", frames.intOptOptionsFrame)
	frames.intOptWhisperAlertOptionFrame:SetSize(290, 75)
	frames.intOptWhisperAlertOptionFrame:SetPoint("TOPLEFT", 0, -155)
	--Whisper Alert Option CheckButton
	checkButtons.intOptWaoCheckButton = CreateFrame("CheckButton", "intOptWaoCheckButton", frames.intOptWhisperAlertOptionFrame, "UICheckButtonTemplate")
	checkButtons.intOptWaoCheckButton:SetPoint("CENTER", -110, -2)
	if(raidrOptions ~= nil and raidrOptions["OnEnterWhisper"] ~= nil) then
		checkButtons.intOptWaoCheckButton:SetChecked(raidrOptions["OnEnterWhisper"])
	end
	checkButtons.intOptWaoCheckButton:SetScript("OnEnter", function(self)
		GameTooltip:SetOwner(self, "ANCHOR_CURSOR");
		GameTooltip:ClearLines()
		GameTooltip:SetText("If checked, RaidR will intOptWhisper you if you enter a raid\nwith less than your desired item quantities")
		GameTooltip:Show()
	end)
	checkButtons.intOptWaoCheckButton:SetScript("OnLeave", function(self)
		GameTooltip:Hide()
	end)
	--Whisper Alert Option String
	fontStrings.intOptWaoString = frames.intOptWhisperAlertOptionFrame:CreateFontString("intOptWaoString")
	fontStrings.intOptWaoString:SetFont("Fonts\\FRIZQT__.ttf", 10)
	fontStrings.intOptWaoString:SetText("Whisper on Entering Raid")
	fontStrings.intOptWaoString:SetJustifyH("LEFT")
	fontStrings.intOptWaoString:SetPoint("CENTER", -29, 0)
	
	RaidR.panel.okay = function (self)
		raidrFlasks = {}
		for key, value in pairs(flasks) do
			flaskEditBoxName = "intOptEditBoxes" .. flasks[key]
			raidrFlasks[key] = editBoxes[flaskEditBoxName]:GetNumber()
		end
		
		raidrPotions = {}
		for key, value in pairs(potions) do
			potionEditBoxName = "intOptEditBoxes" .. potions[key]
			raidrPotions[key] = editBoxes[potionEditBoxName]:GetNumber()
		end
		
		raidrFood = {}
		for key, value in pairs(food) do
			foodEditBoxName = "intOptEditBoxes" .. food[key]
			raidrFood[key] = editBoxes[foodEditBoxName]:GetNumber()
		end
		
		raidrMisc = {}
		for key, value in pairs(misc) do
			miscEditBoxName = "intOptEditBoxes" .. misc[key]
			raidrMisc[key] = editBoxes[miscEditBoxName]:GetNumber()
		end
		
		raidrTimes = {}
		intOptMondayTimeTable = {}
		intOptMondayTimeTable["Active"] = checkButtons.intOptMondayCheckButton:GetChecked()
		intOptMondayTimeTable["Hour"] = intOptMondayHour
		intOptMondayTimeTable["Minute"] = tonumber(intOptMondayMinute)
		intOptMondayTimeTable["AMPM"] = intOptMondayAMPM
		local intOptMondayReminder = TimeDiff(intOptMondayHour, tonumber(intOptMondayMinute), intOptMondayAMPM, intOptReminderTimeValue)
		intOptMondayTimeTable["RemH"] = intOptMondayReminder["Hour"]
		intOptMondayTimeTable["RemM"] = intOptMondayReminder["Minute"]
		intOptMondayTimeTable["RemAMPM"] = intOptMondayReminder["AMPM"]
		intOptTuesdayTimeTable = {}
		intOptTuesdayTimeTable["Active"] = checkButtons.intOptTuesdayCheckButton:GetChecked()
		intOptTuesdayTimeTable["Hour"] = intOptTuesdayHour
		intOptTuesdayTimeTable["Minute"] = tonumber(intOptTuesdayMinute)
		intOptTuesdayTimeTable["AMPM"] = intOptTuesdayAMPM
		local intOptTuesdayReminder = TimeDiff(intOptTuesdayHour, tonumber(intOptTuesdayMinute), intOptTuesdayAMPM, intOptReminderTimeValue)
		intOptTuesdayTimeTable["RemH"] = intOptTuesdayReminder["Hour"]
		intOptTuesdayTimeTable["RemM"] = intOptTuesdayReminder["Minute"]
		intOptTuesdayTimeTable["RemAMPM"] = intOptTuesdayReminder["AMPM"]
		intOptWednesdayTimeTable = {}
		intOptWednesdayTimeTable["Active"] = checkButtons.intOptWednesdayCheckButton:GetChecked()
		intOptWednesdayTimeTable["Hour"] = intOptWednesdayHour
		intOptWednesdayTimeTable["Minute"] = tonumber(intOptWednesdayMinute)
		intOptWednesdayTimeTable["AMPM"] = intOptWednesdayAMPM
		local intOptWednesdayReminder = TimeDiff(intOptWednesdayHour, tonumber(intOptWednesdayMinute), intOptWednesdayAMPM, intOptReminderTimeValue)
		intOptWednesdayTimeTable["RemH"] = intOptWednesdayReminder["Hour"]
		intOptWednesdayTimeTable["RemM"] = intOptWednesdayReminder["Minute"]
		intOptWednesdayTimeTable["RemAMPM"] = intOptWednesdayReminder["AMPM"]
		intOptThursdayTimeTable = {}
		intOptThursdayTimeTable["Active"] = checkButtons.intOptThursdayCheckButton:GetChecked()
		intOptThursdayTimeTable["Hour"] = intOptThursdayHour
		intOptThursdayTimeTable["Minute"] = tonumber(intOptThursdayMinute)
		intOptThursdayTimeTable["AMPM"] = intOptThursdayAMPM
		local intOptThursdayReminder = TimeDiff(intOptThursdayHour, tonumber(intOptThursdayMinute), intOptThursdayAMPM, intOptReminderTimeValue)
		intOptThursdayTimeTable["RemH"] = intOptThursdayReminder["Hour"]
		intOptThursdayTimeTable["RemM"] = intOptThursdayReminder["Minute"]
		intOptThursdayTimeTable["RemAMPM"] = intOptThursdayReminder["AMPM"]
		intOptFridayTimeTable = {}
		intOptFridayTimeTable["Active"] = checkButtons.intOptFridayCheckButton:GetChecked()
		intOptFridayTimeTable["Hour"] = intOptFridayHour
		intOptFridayTimeTable["Minute"] = tonumber(intOptFridayMinute)
		intOptFridayTimeTable["AMPM"] = intOptFridayAMPM
		local intOptFridayReminder = TimeDiff(intOptFridayHour, tonumber(intOptFridayMinute), intOptFridayAMPM, intOptReminderTimeValue)
		intOptFridayTimeTable["RemH"] = intOptFridayReminder["Hour"]
		intOptFridayTimeTable["RemM"] = intOptFridayReminder["Minute"]
		intOptFridayTimeTable["RemAMPM"] = intOptFridayReminder["AMPM"]
		intOptSaturdayTimeTable = {}
		intOptSaturdayTimeTable["Active"] = checkButtons.intOptSaturdayCheckButton:GetChecked()
		intOptSaturdayTimeTable["Hour"] = intOptSaturdayHour
		intOptSaturdayTimeTable["Minute"] = tonumber(intOptSaturdayMinute)
		intOptSaturdayTimeTable["AMPM"] = intOptSaturdayAMPM
		local intOptSaturdayReminder = TimeDiff(intOptSaturdayHour, tonumber(intOptSaturdayMinute), intOptSaturdayAMPM, intOptReminderTimeValue)
		intOptSaturdayTimeTable["RemH"] = intOptSaturdayReminder["Hour"]
		intOptSaturdayTimeTable["RemM"] = intOptSaturdayReminder["Minute"]
		intOptSaturdayTimeTable["RemAMPM"] = intOptSaturdayReminder["AMPM"]
		intOptSundayTimeTable = {}
		intOptSundayTimeTable["Active"] = checkButtons.intOptSundayCheckButton:GetChecked()
		intOptSundayTimeTable["Hour"] = intOptSundayHour
		intOptSundayTimeTable["Minute"] = tonumber(intOptSundayMinute)
		intOptSundayTimeTable["AMPM"] = intOptSundayAMPM
		local intOptSundayReminder = TimeDiff(intOptSundayHour, tonumber(intOptSundayMinute), intOptSundayAMPM, intOptReminderTimeValue)
		intOptSundayTimeTable["RemH"] = intOptSundayReminder["Hour"]
		intOptSundayTimeTable["RemM"] = intOptSundayReminder["Minute"]
		intOptSundayTimeTable["RemAMPM"] = intOptSundayReminder["AMPM"]
		
		raidrOptions = {}
		raidrOptions["Seals"] = checkButtons.intOptBroCheckButton:GetChecked()
		raidrOptions["PlaySound"] = checkButtons.intOptPsoCheckButton:GetChecked()
		raidrOptions["OnEnterWhisper"] = checkButtons.intOptWaoCheckButton:GetChecked()
		
		raidrTimes["Monday"] = intOptMondayTimeTable
		raidrTimes["Tuesday"] = intOptTuesdayTimeTable
		raidrTimes["Wednesday"] = intOptWednesdayTimeTable
		raidrTimes["Thursday"] = intOptThursdayTimeTable
		raidrTimes["Friday"] = intOptFridayTimeTable
		raidrTimes["Saturday"] = intOptSaturdayTimeTable
		raidrTimes["Sunday"] = intOptSundayTimeTable
		raidrTimes["ReminderTime"] = intOptReminderTimeValue
		
		raidrSetup = true
	end
	
	RaidR.panel.cancel = function (self)
		for key, value in pairs(flasks) do
			flaskEditBoxName = "intOptEditBoxes" .. flasks[key]
			if(raidrFlasks ~= nil and raidrFlasks[key] ~= nil) then
				editBoxes[flaskEditBoxName]:SetText(raidrFlasks[key])
			else
				editBoxes[flaskEditBoxName]:SetText("0")
			end
		end
		for key, value in pairs(potions) do
			potionEditBoxName = "intOptEditBoxes" .. potions[key]
			if(raidrPotions ~= nil and raidrPotions[key] ~= nil) then
				editBoxes[potionEditBoxName]:SetText(raidrPotions[key])
			else
				editBoxes[potionEditBoxName]:SetText("0")
			end
		end
		for key, value in pairs(food) do
			foodEditBoxName = "intOptEditBoxes" .. food[key]
			if(raidrFood ~= nil and raidrFood[key] ~= nil) then
				editBoxes[foodEditBoxName]:SetText(raidrFood[key])
			else
				editBoxes[foodEditBoxName]:SetText("0")
			end
		end
		for key, value in pairs(misc) do
			miscEditBoxName = "intOptEditBoxes" .. misc[key]
			if(raidrMisc ~= nil and raidrMisc[key] ~= nil) then
				editBoxes[miscEditBoxName]:SetText(raidrMisc[key])
			else
				editBoxes[miscEditBoxName]:SetText("0")
			end
		end
		
		if(raidrTimes ~= nil and raidrTimes["Monday"] ~= nil and raidrTimes["Monday"]["Active"] ~= nil) then
			checkButtons.intOptMondayCheckButton:SetChecked(raidrTimes["Monday"]["Active"])
		else
			checkButtons.intOptMondayCheckButton:SetChecked(false)
		end
		if(raidrTimes ~= nil and raidrTimes["Monday"] ~= nil and raidrTimes["Monday"]["Hour"] ~= nil) then
			dropdowns.intOptMondayHourDropdown:SetValue(raidrTimes["Monday"]["Hour"])
		else
			dropdowns.intOptMondayHourDropdown:SetValue(1)
		end
		if(raidrTimes ~= nil and raidrTimes["Monday"] ~= nil and raidrTimes["Monday"]["Minute"] ~= nil) then
			dropdowns.intOptMondayMinuteDropdown:SetValue(raidrTimes["Monday"]["Minute"])
		else
			dropdowns.intOptMondayMinuteDropdown:SetValue(0)
		end
		if(raidrTimes ~= nil and raidrTimes["Monday"] ~= nil and raidrTimes["Monday"]["AMPM"] ~= nil) then
			dropdowns.intOptMondayAMPMDropdown:SetValue(raidrTimes["Monday"]["AMPM"])
		else
			dropdowns.intOptMondayAMPMDropdown:SetValue("AM")
		end
		
		if(raidrTimes ~= nil and raidrTimes["Tuesday"] ~= nil and raidrTimes["Tuesday"]["Active"] ~= nil) then
			checkButtons.intOptTuesdayCheckButton:SetChecked(raidrTimes["Tuesday"]["Active"])
		else
			checkButtons.intOptTuesdayCheckButton:SetChecked(false)
		end
		if(raidrTimes ~= nil and raidrTimes["Tuesday"] ~= nil and raidrTimes["Tuesday"]["Hour"] ~= nil) then
			dropdowns.intOptTuesdayHourDropdown:SetValue(raidrTimes["Tuesday"]["Hour"])
		else
			dropdowns.intOptTuesdayHourDropdown:SetValue(1)
		end
		if(raidrTimes ~= nil and raidrTimes["Tuesday"] ~= nil and raidrTimes["Tuesday"]["Minute"] ~= nil) then
			dropdowns.intOptTuesdayMinuteDropdown:SetValue(raidrTimes["Tuesday"]["Minute"])
		else
			dropdowns.intOptTuesdayMinuteDropdown:SetValue(0)
		end
		if(raidrTimes ~= nil and raidrTimes["Tuesday"] ~= nil and raidrTimes["Tuesday"]["AMPM"] ~= nil) then
			dropdowns.intOptTuesdayAMPMDropdown:SetValue(raidrTimes["Tuesday"]["AMPM"])
		else
			dropdowns.intOptTuesdayAMPMDropdown:SetValue("AM")
		end
		
		if(raidrTimes ~= nil and raidrTimes["Wednesday"] ~= nil and raidrTimes["Wednesday"]["Active"] ~= nil) then
			checkButtons.intOptWednesdayCheckButton:SetChecked(raidrTimes["Wednesday"]["Active"])
		else
			checkButtons.intOptWednesdayCheckButton:SetChecked(false)
		end
		if(raidrTimes ~= nil and raidrTimes["Wednesday"] ~= nil and raidrTimes["Wednesday"]["Hour"] ~= nil) then
			dropdowns.intOptWednesdayHourDropdown:SetValue(raidrTimes["Wednesday"]["Hour"])
		else
			dropdowns.intOptWednesdayHourDropdown:SetValue(1)
		end
		if(raidrTimes ~= nil and raidrTimes["Wednesday"] ~= nil and raidrTimes["Wednesday"]["Minute"] ~= nil) then
			dropdowns.intOptWednesdayMinuteDropdown:SetValue(raidrTimes["Wednesday"]["Minute"])
		else
			dropdowns.intOptWednesdayMinuteDropdown:SetValue(0)
		end
		if(raidrTimes ~= nil and raidrTimes["Wednesday"] ~= nil and raidrTimes["Wednesday"]["AMPM"] ~= nil) then
			dropdowns.intOptWednesdayAMPMDropdown:SetValue(raidrTimes["Wednesday"]["AMPM"])
		else
			dropdowns.intOptWednesdayAMPMDropdown:SetValue("AM")
		end
		
		if(raidrTimes ~= nil and raidrTimes["Thursday"] ~= nil and raidrTimes["Thursday"]["Active"] ~= nil) then
			checkButtons.intOptThursdayCheckButton:SetChecked(raidrTimes["Thursday"]["Active"])
		else
			checkButtons.intOptThursdayCheckButton:SetChecked(false)
		end
		if(raidrTimes ~= nil and raidrTimes["Thursday"] ~= nil and raidrTimes["Thursday"]["Hour"] ~= nil) then
			dropdowns.intOptThursdayHourDropdown:SetValue(raidrTimes["Thursday"]["Hour"])
		else
			dropdowns.intOptThursdayHourDropdown:SetValue(1)
		end
		if(raidrTimes ~= nil and raidrTimes["Thursday"] ~= nil and raidrTimes["Thursday"]["Minute"] ~= nil) then
			dropdowns.intOptThursdayMinuteDropdown:SetValue(raidrTimes["Thursday"]["Minute"])
		else
			dropdowns.intOptThursdayMinuteDropdown:SetValue(0)
		end
		if(raidrTimes ~= nil and raidrTimes["Thursday"] ~= nil and raidrTimes["Thursday"]["AMPM"] ~= nil) then
			dropdowns.intOptThursdayAMPMDropdown:SetValue(raidrTimes["Thursday"]["AMPM"])
		else
			dropdowns.intOptThursdayAMPMDropdown:SetValue("AM")
		end
		
		if(raidrTimes ~= nil and raidrTimes["Friday"] ~= nil and raidrTimes["Friday"]["Active"] ~= nil) then
			checkButtons.intOptFridayCheckButton:SetChecked(raidrTimes["Friday"]["Active"])
		else
			checkButtons.intOptFridayCheckButton:SetChecked(false)
		end
		if(raidrTimes ~= nil and raidrTimes["Friday"] ~= nil and raidrTimes["Friday"]["Hour"] ~= nil) then
			dropdowns.intOptFridayHourDropdown:SetValue(raidrTimes["Friday"]["Hour"])
		else
			dropdowns.intOptFridayHourDropdown:SetValue(1)
		end
		if(raidrTimes ~= nil and raidrTimes["Friday"] ~= nil and raidrTimes["Friday"]["Minute"] ~= nil) then
			dropdowns.intOptFridayMinuteDropdown:SetValue(raidrTimes["Friday"]["Minute"])
		else
			dropdowns.intOptFridayMinuteDropdown:SetValue(0)
		end
		if(raidrTimes ~= nil and raidrTimes["Friday"] ~= nil and raidrTimes["Friday"]["AMPM"] ~= nil) then
			dropdowns.intOptFridayAMPMDropdown:SetValue(raidrTimes["Friday"]["AMPM"])
		else
			dropdowns.intOptFridayAMPMDropdown:SetValue("AM")
		end
		
		if(raidrTimes ~= nil and raidrTimes["Saturday"] ~= nil and raidrTimes["Saturday"]["Active"] ~= nil) then
			checkButtons.intOptSaturdayCheckButton:SetChecked(raidrTimes["Saturday"]["Active"])
		else
			checkButtons.intOptSaturdayCheckButton:SetChecked(false)
		end
		if(raidrTimes ~= nil and raidrTimes["Saturday"] ~= nil and raidrTimes["Saturday"]["Hour"] ~= nil) then
			dropdowns.intOptSaturdayHourDropdown:SetValue(raidrTimes["Saturday"]["Hour"])
		else
			dropdowns.intOptSaturdayHourDropdown:SetValue(1)
		end
		if(raidrTimes ~= nil and raidrTimes["Saturday"] ~= nil and raidrTimes["Saturday"]["Minute"] ~= nil) then
			dropdowns.intOptSaturdayMinuteDropdown:SetValue(raidrTimes["Saturday"]["Minute"])
		else
			dropdowns.intOptSaturdayMinuteDropdown:SetValue(0)
		end
		if(raidrTimes ~= nil and raidrTimes["Saturday"] ~= nil and raidrTimes["Saturday"]["AMPM"] ~= nil) then
			dropdowns.intOptSaturdayAMPMDropdown:SetValue(raidrTimes["Saturday"]["AMPM"])
		else
			dropdowns.intOptSaturdayAMPMDropdown:SetValue("AM")
		end
		
		if(raidrTimes ~= nil and raidrTimes["Sunday"] ~= nil and raidrTimes["Sunday"]["Active"] ~= nil) then
			checkButtons.intOptSundayCheckButton:SetChecked(raidrTimes["Sunday"]["Active"])
		else
			checkButtons.intOptSundayCheckButton:SetChecked(false)
		end
		if(raidrTimes ~= nil and raidrTimes["Sunday"] ~= nil and raidrTimes["Sunday"]["Hour"] ~= nil) then
			dropdowns.intOptSundayHourDropdown:SetValue(raidrTimes["Sunday"]["Hour"])
		else
			dropdowns.intOptSundayHourDropdown:SetValue(1)
		end
		if(raidrTimes ~= nil and raidrTimes["Sunday"] ~= nil and raidrTimes["Sunday"]["Minute"] ~= nil) then
			dropdowns.intOptSundayMinuteDropdown:SetValue(raidrTimes["Sunday"]["Minute"])
		else
			dropdowns.intOptSundayMinuteDropdown:SetValue(0)
		end
		if(raidrTimes ~= nil and raidrTimes["Sunday"] ~= nil and raidrTimes["Sunday"]["AMPM"] ~= nil) then
			dropdowns.intOptSundayAMPMDropdown:SetValue(raidrTimes["Sunday"]["AMPM"])
		else
			dropdowns.intOptSundayAMPMDropdown:SetValue("AM")
		end
		
		if(raidrTimes ~= nil and raidrTimes["ReminderTime"] ~= nil) then
			if(raidrTimes["ReminderTime"] == 60) then
				dropdowns.intOptReminderTimeDropdown:SetValue("1 hour", 60)
			else
				dropdowns.intOptReminderTimeDropdown:SetValue(raidrTimes["ReminderTime"] .. " minutes", raidrTimes["ReminderTime"])
			end
		else
			dropdowns.intOptReminderTimeDropdown:SetValue("5 minutes", 5)
		end
		
		if(raidrOptions ~= nil and raidrOptions["Seals"] ~= nil) then
			checkButtons.intOptBroCheckButton:SetChecked(raidrOptions["Seals"])
		else
			checkButtons.intOptBroCheckButton:SetChecked(false)
		end
		
		if(raidrOptions ~= nil and raidrOptions["PlaySound"] ~= nil) then
			checkButtons.intOptPsoCheckButton:SetChecked(raidrOptions["PlaySound"])
		else
			checkButtons.intOptPsoCheckButton:SetChecked(false)
		end
		
		if(raidrOptions ~= nil and raidrOptions["OnEnterWhisper"] ~= nil) then
			checkButtons.intOptWaoCheckButton:SetChecked(raidrOptions["OnEnterWhisper"])
		else
			checkButtons.intOptWaoCheckButton:SetChecked(false)
		end
	end
	
	RaidR.panel.default = function (self)
		for key, value in pairs(flasks) do
			flaskEditBoxName = "intOptEditBoxes" .. flasks[key]
			editBoxes[flaskEditBoxName]:SetText("0")
		end
		for key, value in pairs(potions) do
			potionEditBoxName = "intOptEditBoxes" .. potions[key]
			editBoxes[potionEditBoxName]:SetText("0")
		end
		for key, value in pairs(food) do
			foodEditBoxName = "intOptEditBoxes" .. food[key]
			editBoxes[foodEditBoxName]:SetText("0")
		end
		for key, value in pairs(misc) do
			miscEditBoxName = "intOptEditBoxes" .. misc[key]
			editBoxes[miscEditBoxName]:SetText("0")
		end
		checkButtons.intOptMondayCheckButton:SetChecked(false)
		dropdowns.intOptMondayHourDropdown:SetValue(1)
		dropdowns.intOptMondayMinuteDropdown:SetValue(0)
		dropdowns.intOptMondayAMPMDropdown:SetValue("AM")
		checkButtons.intOptTuesdayCheckButton:SetChecked(false)
		dropdowns.intOptTuesdayHourDropdown:SetValue(1)
		dropdowns.intOptTuesdayMinuteDropdown:SetValue(0)
		dropdowns.intOptTuesdayAMPMDropdown:SetValue("AM")
		checkButtons.intOptWednesdayCheckButton:SetChecked(false)
		dropdowns.intOptWednesdayHourDropdown:SetValue(1)
		dropdowns.intOptWednesdayMinuteDropdown:SetValue(0)
		dropdowns.intOptWednesdayAMPMDropdown:SetValue("AM")
		checkButtons.intOptThursdayCheckButton:SetChecked(false)
		dropdowns.intOptThursdayHourDropdown:SetValue(1)
		dropdowns.intOptThursdayMinuteDropdown:SetValue(0)
		dropdowns.intOptThursdayAMPMDropdown:SetValue("AM")
		checkButtons.intOptFridayCheckButton:SetChecked(false)
		dropdowns.intOptFridayHourDropdown:SetValue(1)
		dropdowns.intOptFridayMinuteDropdown:SetValue(0)
		dropdowns.intOptFridayAMPMDropdown:SetValue("AM")
		checkButtons.intOptSaturdayCheckButton:SetChecked(false)
		dropdowns.intOptSaturdayHourDropdown:SetValue(1)
		dropdowns.intOptSaturdayMinuteDropdown:SetValue(0)
		dropdowns.intOptSaturdayAMPMDropdown:SetValue("AM")
		checkButtons.intOptSundayCheckButton:SetChecked(false)
		dropdowns.intOptSundayHourDropdown:SetValue(1)
		dropdowns.intOptSundayMinuteDropdown:SetValue(0)
		dropdowns.intOptSundayAMPMDropdown:SetValue("AM")
		dropdowns.intOptReminderTimeDropdown:SetValue("5 minutes", 5)
		checkButtons.intOptBroCheckButton:SetChecked(false)
		checkButtons.intOptPsoCheckButton:SetChecked(false)
		checkButtons.intOptWaoCheckButton:SetChecked(false)
	end
end

--Main addon frame
raidrMainFrame = CreateFrame("Frame")
raidrMainFrame:SetScript("OnEvent",function(self,event)
	if(event == "PLAYER_ENTERING_WORLD") then
		if((raidrSetup == nil) or (raidrSetup == false)) then
			RunInitialConfig()
		end
		RegisterInterfaceOptionsPanel()
		RunReminderLoop()
		
		local isInstance, instanceType = IsInInstance()
		if(isInstance == true and instanceType == "raid") then
			local haveAll = true
			if(raidrOptions["Seals"] == true) then
				local _, sealsCount = GetCurrencyInfo(1273)
				if(sealsCount < 3) then
					haveAll = false
				end
			end
			for key, value in pairs(raidrFlasks) do
				if(GetItemCount(flasks[key]) < value) then
					haveAll = false
				end
			end
			for key, value in pairs(raidrPotions) do
				if(GetItemCount(potions[key]) < value) then
					haveAll = false
				end
			end
			for key, value in pairs(raidrFood) do
				if(GetItemCount(food[key]) < value) then
					haveAll = false
				end
			end
			for key, value in pairs(raidrMisc) do
				if(GetItemCount(misc[key]) < value) then
					haveAll = false
				end
			end
			if(haveAll == false) then
				PlaySound(3081)
				print("|cffff80ff[RaidR] whispers: Hey! You just entered a raid without all the items you told me you wanted. Type '/raidr scan' to see which ones. (Or type '/raidr notell' and I won't bother you like this again)")
			end
		end
	end
end)
raidrMainFrame:RegisterEvent("PLAYER_ENTERING_WORLD")

--Register slash commands
SLASH_RAIDR1 = "/raidr"
SlashCmdList["RAIDR"] = function(msg)
	if(msg == "config") then
		InterfaceOptionsFrame_OpenToCategory("RaidR")
		InterfaceOptionsFrame_OpenToCategory("RaidR")
	elseif(msg == "scan") then
		raidrRemind = true
		RunReminder()
	elseif(msg == "notell") then
		raidrOptions["OnEnterWhisper"] = false
	elseif(msg == "debug") then
		RunReminderLoop()
	elseif(msg == "debug2") then
		RunInitialConfig()
	elseif(msg == "" or msg == "help") then
		print("|cffff80ff[RaidR] whispers: To open the config, type '/raidr config'\nTo have me check your bags, type '/raidr scan'\nTo disable alerts on entering raid, type '/raidr notell'")
	else
		print("|cffffff00Type '/help' for a listing of a few commands.") --Default UI message for unknown slash commands
	end
end